<?php

namespace App\Actions\Fortify;

use App\Models\User;
use Illuminate\Support\Facades\{Hash, Validator};
use Laravel\Fortify\Contracts\UpdatesUserPasswords;

class UpdateUserPassword implements UpdatesUserPasswords
{
    use PasswordValidationRules;

    /**
     * Validate and update the user's password.
     *
     * @param  array<string, string>  $input
     */
    public function update(User $user, array $input): void
    {
        Validator::make($input, [
            'current_password' => ['required', 'string', 'current_password:web'],
            'password'         => $this->passwordRules(),
        ], [
            'current_password.current_password' => __('The provided password does not match your current password.'),
        ])->validateWithBag('updatePassword');

        if (demo()) {
            session()->flash('error', __('This feature is disabled on demo.'));
        } else {
            $user->forceFill([
                'password' => Hash::make($input['password']),
            ])->save();
        }
    }
}
