<?php

// Get Settings
if (! function_exists('get_settings')) {
    function get_settings($key = null)
    {
        $json_fields = ['paypal', 'stripe'];
        if ($key) {
            if (in_array($key, $json_fields)) {
                return json_decode(optional(\App\Models\Setting::where('tec_key', $key)->first())->tec_value);
            }

            return optional(\App\Models\Setting::where('tec_key', $key)->first())->tec_value;
        }

        return \App\Models\Setting::all()->pluck('tec_value', 'tec_key')->merge(['baseUrl' => url('/')])->transform(function ($value, $key) use ($json_fields) {
            return in_array($key, $json_fields) ? json_decode($value) : $value;
        });
    }
}

// Log Activity
if (! function_exists('log_activity')) {
    function log_activity($activity, $properties = null, $model = null, $name = null)
    {
        return activity($name)->performedOn($model)->withProperties($properties)->log($activity);
    }
}

// Format Decimal
if (! function_exists('formatDecimal')) {
    function formatDecimal($number, $decimals = 2, $ds = '.', $ts = '')
    {
        return number_format($number, $decimals, $ds, $ts);
    }
}

// Format Number
if (! function_exists('formatNumber')) {
    function formatNumber($number, $decimals = 2, $ds = '.', $ts = ',')
    {
        return number_format($number, $decimals, $ds, $ts);
    }
}

// Is Demo Enabled
if (! function_exists('demo')) {
    function demo()
    {
        return env('DEMO', false);
    }
}

// Json translation with choice replace
if (! function_exists('__choice')) {
    function __choice($key, array $replace = [], $number = null)
    {
        return trans_choice($key, $number, $replace);
    }
}

// Get account id
if (! function_exists('getAccountId')) {
    function getAccountId($account_id = null)
    {
        return session('account_id', $account_id ?? optional(auth()->user())->account_id);
    }
}

// Get UUID v1
if (! function_exists('uuid1')) {
    function uuid1()
    {
        $nodeProvider = new \Ramsey\Uuid\Provider\Node\RandomNodeProvider();

        return \Ramsey\Uuid\Uuid::uuid1($nodeProvider->getNode());
    }
}

// Get UUID v4
if (! function_exists('uuid4')) {
    function uuid4()
    {
        return \Ramsey\Uuid\Uuid::uuid4();
    }
}

// Get ULID
if (! function_exists('ulid')) {
    function ulid()
    {
        return (string) \Ulid\Ulid::generate(true);
    }
}

// Get get next id
if (! function_exists('get_next_id')) {
    function get_next_id($model)
    {
        return collect(\Illuminate\Support\Facades\DB::select("show table status like '{$model->getTable()}'"))->first()->Auto_increment;
    }
}

// Get reference
if (! function_exists('get_reference')) {
    function get_reference($model)
    {
        $format = get_settings('reference');

        return match ($format) {
            'ai'     => get_next_id($model),
            'ulid'   => ulid(),
            'uuid'   => uuid4(),
            'uniqid' => uniqid(),
            default  => ulid(),
        };
    }
}

// Calculate Discount
if (! function_exists('calculateDiscount')) {
    function calculateDiscount($discount = 0, $amount = 0)
    {
        if ($discount && $amount) {
            if (str($discount)->contains('%')) {
                $dv = explode('%', $discount);
                $discount = number_format((($amount * (float) $dv[0]) / 100), 2, '.', '');
            }
        }

        return $discount;
    }
}

// Calculate Taxes
if (! function_exists('calculateTax')) {
    function calculateTax(App\Models\TaxRate $tax, $amount = null, $tax_method = 'exclusive')
    {
        if ($tax && $amount) {
            if ($tax->fixed) {
                return formatDecimal($tax->rate);
            }
            if ('inclusive' == $tax_method) {
                return formatDecimal(($amount * $tax->rate) / (100 + $tax->rate));
            }

            return formatDecimal($amount * $tax->rate / 100);
        }

        return 0;
    }
}

// Calculate Taxes
if (! function_exists('calculateTaxes')) {
    function calculateTaxes($taxes, $amount, $tax_method = 'exclusive')
    {
        $tax_amount = 0;
        if (! empty($taxes)) {
            foreach ($taxes as $tax) {
                $tax_amount += calculateTax($tax, $amount, $tax_method);
            }
        }

        return $tax_amount;
    }
}

// Order Custom Fields
if (! function_exists('orderCustomFields')) {
    function orderCustomFields($data, $ofModel)
    {
        $extra_attributes = [];
        $fields = \App\Models\Field::where('show', 1)->ofModel($ofModel)->pluck('name');
        if ($fields) {
            foreach ($fields as $field) {
                $extra_attributes[$field] = $data['extra_attributes'][$field] ?? '';
            }
        }

        return $extra_attributes;
    }
}

// Calculate Gateway Fees
if (! function_exists('calculate_gateway_fees')) {
    function calculate_gateway_fees($amount, $data, $same_country)
    {
        $fees = 0;
        if ($data?->fixed ?? null) {
            $fees += $data->fixed;
        }
        if ($same_country && ($data?->same_country ?? null)) {
            $fees += $amount * ($data->same_country / 100);
        }
        if (! $same_country && ($data?->other_countries ?? null)) {
            $fees += $amount * ($data->other_countries / 100);
        }

        return $fees;
    }
}

// Is safe email
if (! function_exists('safe_email')) {
    function safe_email($email = '')
    {
        $contains = str($email)->contains('@example.');

        return $email && ! $contains;
    }
}
