<?php

namespace App\Http\Controllers;

use Inertia\Inertia;
use Illuminate\Http\Request;
use App\Models\{Invoice, Payment, Quotation};

class NotificationController extends Controller
{
    public function invoice(Request $request, $id, $hash)
    {
        abort_unless($request->hasValidSignature(), 401);
        $invoice = Invoice::withoutGlobalScopes()->findOrFail($id);
        if ($invoice->hash != $hash) {
            abort(404);
        }
        return Inertia::render('Invoice/Details', [
            'accept_payment' => true,
            'settings'       => get_settings(),
            'invoice'        => $invoice->load(['company', 'customer', 'items', 'user', 'taxes', 'items.taxes']),
        ]);
    }

    public function invoiceNotification(Invoice $invoice)
    {
        if (safe_email($invoice->customer->email)) {
            $invoice->customer->notify(new \App\Notifications\InvoiceCreated($invoice));
            return back()->with('message', __choice('{record} has been {action}.', ['record' => __('Email'), 'action' => __('sent')]));
        }
        return back()->with('error', __choice('{record} has been {action}.', ['record' => __('Email'), 'action' => __('failed')]));
    }

    public function payment(Request $request, $id, $hash)
    {
        abort_unless($request->hasValidSignature(), 401);
        $payment = Payment::withoutGlobalScopes()->findOrFail($id);
        if ($payment->hash != $hash) {
            abort(404);
        }
        return Inertia::render('Payment/Details', [
            'settings' => get_settings(),
            'payment'  => $payment->load(['company', 'customer', 'user']),
        ]);
    }

    public function paymentNotification(Payment $payment)
    {
        if (safe_email($payment->customer->email)) {
            $payment->customer->notify(new \App\Notifications\PaymentCreated($payment));
            return back()->with('message', __choice('{record} has been {action}.', ['record' => __('Email'), 'action' => __('sent')]));
        }
        return back()->with('error', __choice('{record} has been {action}.', ['record' => __('Email'), 'action' => __('failed')]));
    }

    public function quotation(Request $request, $id, $hash)
    {
        abort_unless($request->hasValidSignature(), 401);
        $quotation = Quotation::withoutGlobalScopes()->findOrFail($id);
        if ($quotation->hash != $hash) {
            abort(404);
        }
        return Inertia::render('Quotation/Details', [
            'settings'  => get_settings(),
            'quotation' => $quotation->load(['company', 'customer', 'items', 'user', 'taxes', 'items.taxes']),
        ]);
    }

    public function quotationNotification(Quotation $quotation)
    {
        if (safe_email($quotation->customer->email)) {
            $quotation->customer->notify(new \App\Notifications\QuotationCreated($quotation));
            return back()->with('message', __choice('{record} has been {action}.', ['record' => __('Email'), 'action' => __('sent')]));
        }
        return back()->with('error', __choice('{record} has been {action}.', ['record' => __('Email'), 'action' => __('failed')]));
    }
}
