<?php

namespace App\Http\Controllers;

use Inertia\Inertia;
use Illuminate\Http\Request;
use App\Http\Requests\PaymentRequest;
use App\Http\Resources\PaymentCollection;
use App\Models\{Company, Field, Note, Payment, TaxRate};

class PaymentController extends Controller
{
    public function destroy(Request $request, Payment $payment)
    {
        if ($payment->{$request->force ? 'forceDelete' : 'delete'}()) {
            return redirect()->route('payments.index')->with('message', __choice('{record} has been {action}.', ['record' => __('Payment'), 'action' => __('deleted')]));
        }
        return back()->with('error', __('The record can not be deleted.'));
    }

    public function destroyMany(Request $request)
    {
        $count = $failed = 0;
        foreach (Payment::whereIn('id', $request->selection)->get() as $payment) {
            if ($payment->{$request->force ? 'forceDelete' : 'delete'}()) {
                $count++;
            } else {
                $failed++;
            }
        }
        return back()->with('message', __('The task has completed, {count} deleted and {failed} failed.', ['count' => $count, 'failed' => $failed]));
    }

    public function destroyPermanently(Payment $payment)
    {
        if ($payment->forceDelete()) {
            return redirect()->route('payments.index')->with('message', __choice('{record} has been {action}.', ['record' => __('Payment'), 'action' => __('permanently deleted')]));
        }
        return back()->with('error', __('The record can not be deleted.'));
    }

    public function index(Request $request)
    {
        $filters = $request->all('search', 'start_date', 'end_date', 'trashed');

        return Inertia::render('Payment/List', [
            'filters'  => $filters,
            'fields'   => Field::ofModel('payment')->get(),
            'payments' => new PaymentCollection(
                Payment::with(['company', 'customer', 'user'])->filter($filters)->orderByDesc('date')->latest()->paginate()->onEachSide(2)->withQueryString()
            ),
        ]);
    }

    public function restore(Payment $payment)
    {
        $payment->restore();
        return back()->with('message', __choice('{record} has been {action}.', ['record' => __('Payment'), 'action' => __('restored')]));
    }

    public function show(Payment $payment)
    {
        return Inertia::render('Payment/Details', [
            'payment' => $payment->load(['company', 'customer', 'user']),
        ]);
    }

    public function store(PaymentRequest $request)
    {
        $payment = Payment::create($request->validated());
        if ('yes' == $request->is_ajax) {
            return response()->json($payment);
        }
        return redirect()->route('payments.index')->with('message', __choice('{record} has been {action}.', ['record' => __('Payment'), 'action' => __('created')]));
    }

    public function update(PaymentRequest $request, Payment $payment)
    {
        $payment->update($request->validated());
        if ('yes' == $request->is_ajax) {
            return response()->json($payment);
        }
        return redirect()->route('payments.index')->with('message', __choice('{record} has been {action}.', ['record' => __('Payment'), 'action' => __('updated')]));
    }
}
