<?php

namespace App\Http\Controllers;

use Inertia\Inertia;
use Illuminate\Http\Request;
use App\Actions\Tec\PrepareOrder;
use App\Http\Requests\QuotationRequest;
use App\Http\Resources\QuotationCollection;
use App\Models\{Company, Field, Note, Quotation, TaxRate};

class QuotationController extends Controller
{
    public function create()
    {
        return Inertia::render('Quotation/Form', [
            'customer_fields' => Field::ofModel('customer')->get(),
            'item_fields'     => Field::ofModel('quotationitem')->get(),
            'fields'          => Field::ofModel('mainquotation')->get(),
            'note'            => Note::where('default_quote', 1)->first(),
            'companies'       => Company::get(['id as value', 'name as label']),
            'tax_rates'       => TaxRate::all(['id as value', 'name as label', 'id', 'rate', 'fixed']),
        ]);
    }

    public function destroy(Request $request, Quotation $quotation)
    {
        if ($quotation->{$request->force ? 'forceDelete' : 'delete'}()) {
            return redirect()->route('quotations.index')->with('message', __choice('{record} has been {action}.', ['record' => __('Quotation'), 'action' => __('deleted')]));
        }
        return back()->with('error', __('The record can not be deleted.'));
    }

    public function destroyMany(Request $request)
    {
        $count = $failed = 0;
        foreach (Quotation::whereIn('id', $request->selection)->get() as $quotation) {
            if ($quotation->{$request->force ? 'forceDelete' : 'delete'}()) {
                $count++;
            } else {
                $failed++;
            }
        }
        return back()->with('message', __('The task has completed, {count} deleted and {failed} failed.', ['count' => $count, 'failed' => $failed]));
    }

    public function destroyPermanently(Quotation $quotation)
    {
        if ($quotation->forceDelete()) {
            return redirect()->route('quotations.index')->with('message', __choice('{record} has been {action}.', ['record' => __('Quotation'), 'action' => __('permanently deleted')]));
        }
        return back()->with('error', __('The record can not be deleted.'));
    }

    public function edit(Quotation $quotation)
    {
        return Inertia::render('Quotation/Form', [
            'customer_fields' => Field::ofModel('customer')->get(),
            'item_fields'     => Field::ofModel('quotationitem')->get(),
            'fields'          => Field::ofModel('mainquotation')->get(),
            'note'            => Note::where('default_quote', 1)->first(),
            'companies'       => Company::get(['id as value', 'name as label']),
            'tax_rates'       => TaxRate::all(['id as value', 'name as label', 'id', 'rate', 'fixed']),
            'edit'            => ['data' => $quotation->load(['company', 'customer', 'items', 'user', 'taxes', 'items.taxes'])],
        ]);
    }

    public function index(Request $request)
    {
        $filters = $request->all('search', 'start_date', 'end_date', 'trashed');

        return Inertia::render('Quotation/List', [
            'filters'    => $filters,
            'quotations' => new QuotationCollection(
                Quotation::with(['company', 'customer', 'items', 'user'])->filter($filters)->orderByDesc('date')->latest()->paginate()->onEachSide(2)->withQueryString()
            ),
        ]);
    }

    public function restore(Quotation $quotation)
    {
        $quotation->restore();
        $quotation->items->each->restore();
        return back()->with('message', __choice('{record} has been {action}.', ['record' => __('Quotation'), 'action' => __('restored')]));
    }

    public function show(Request $request, Quotation $quotation)
    {
        return Inertia::render('Quotation/Details', [
            'quotation' => $quotation->load(['company', 'customer', 'items', 'user', 'taxes', 'items.taxes']),
        ]);
    }

    public function store(QuotationRequest $request)
    {
        $form = $request->validated();
        $quotation = (new PrepareOrder($form, new Quotation()))->save();
        $quotation->saveAttachments($request->file('attachments'));
        return redirect()->route('quotations.index')
            ->with('message', __choice('{record} has been {action}.', ['record' => __('Quotation'), 'action' => __('created')]));
    }

    public function update(QuotationRequest $request, Quotation $quotation)
    {
        $form = $request->validated();
        $quotation = (new PrepareOrder($form, $quotation, true))->save();
        $quotation->saveAttachments($request->file('attachments'));
        return redirect()->route('quotations.index')
            ->with('message', __choice('{record} has been {action}.', ['record' => __('Quotation'), 'action' => __('updated')]));
    }
}
