<?php

namespace App\Http\Requests;

use App\Rules\ExtraAttributes;
use Illuminate\Foundation\Http\FormRequest;

class CompanyRequest extends FormRequest
{
    public function authorize()
    {
        return true;
    }

    public function rules()
    {
        return [
            'name'             => 'required',
            'contact_person'   => 'nullable',
            'address'          => 'nullable',
            'city'             => 'nullable',
            'postal_code'      => 'nullable',
            'state'            => 'nullable',
            'country'          => 'nullable',
            'email'            => 'nullable|email',
            'phone'            => 'nullable|required_without:email',
            'logo'             => 'nullable|mimes:png,jpg,jpeg,svg',
            'ss_image'         => 'nullable|mimes:png,jpg,jpeg,svg',
            'extra_attributes' => ['nullable', new ExtraAttributes('company')],
        ];
    }

    public function validated($key = null, $default = null)
    {
        $data = $this->validator->validated();
        if ($this->has('logo') && $this->logo) {
            $data['logo'] = asset($this->logo->store('/images', 'public'));
        } else {
            unset($data['logo']);
        }
        return $data;
    }
}
