<?php

namespace App\Models;

use App\Helpers\Notifiable;
use App\Traits\HasSchemalessAttributes;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class Company extends Model
{
    use HasFactory;
    use HasSchemalessAttributes;
    use Notifiable;

    public $fillable = [
        'name', 'contact_person', 'email', 'phone', 'address', 'city', 'postal_code', 'state',
        'country', 'active', 'ss_image', 'logo',  'account_id', 'extra_attributes',
    ];

    public function checkins()
    {
        return $this->hasMany(Checkin::class);
    }

    public function delete()
    {
        if ($this->checkins()->exists()) {
            return false;
        }

        return parent::delete();
    }

    public function forceDelete()
    {
        if ($this->checkins()->exists()) {
            return false;
        }

        log_activity(__choice('delete_text', ['record' => __('Supplier')]), $this, $this, 'Supplier');
        return parent::forceDelete();
    }

    public function scopeFilter($query, array $filters)
    {
        $query->when($filters['trashed'] ?? null, fn ($q, $t) => $q->{$t . 'Trashed'}())
            ->when($filters['search'] ?? null, fn ($query, $search) => $query->search($search));
    }

    public function scopeSearch($query, $s)
    {
        $query->where(fn ($q) => $q->where('name', 'like', "%{$s}%")->orWhere('email', 'like', "%{$s}%")->orWhere('phone', 'like', "%{$s}%"));
    }
}
