<?php

namespace App\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Support\Facades\URL;
use Illuminate\Notifications\Notification;
use Illuminate\Notifications\Messages\MailMessage;

class InvoiceCreated extends Notification
{
    use Queueable;

    public $invoice;

    public function __construct($invoice)
    {
        $this->invoice = $invoice;
    }

    public function toMail($notifiable)
    {
        $url = URL::signedRoute('invoice.view', ['id' => $this->invoice->id, 'hash' => $this->invoice->hash]);
        return (new MailMessage())
            ->subject(__('Invoice # {number} ({company})', ['number' => $this->invoice->id, 'company' => $this->invoice->company->name]))
            ->greeting('Hello ' . $this->invoice->customer->name . ',')
            ->line(__choice('New invoice # {number} (Reference: {reference}) has been created.', ['number' => $this->invoice->id, 'reference' => $this->invoice->reference]))
            ->line(__choice('You can view the {x} by clicking the following button', ['x' => __('Invoice')]))
            ->action(__('View Invoice'), $url)
            ->line(__('Thank you for your business!'));
    }

    public function via($notifiable)
    {
        return ['mail'];
    }
}
