<?php

namespace App\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Support\Facades\URL;
use Illuminate\Notifications\Notification;
use Illuminate\Notifications\Messages\MailMessage;

class InvoiceDue extends Notification
{
    use Queueable;

    public $invoice;

    public function __construct($invoice)
    {
        $this->invoice = $invoice;
    }

    public function toMail($notifiable)
    {
        $url = URL::signedRoute('invoice.view', ['id' => $this->invoice->id, 'hash' => $this->invoice->hash]);
        return (new MailMessage())
            ->subject(__('Invoice Due'))
            ->greeting('Hello ' . $this->invoice->customer->name . ',')
            ->line(__choice('I am checking in on Invoice # {number} (Reference: {reference}) due today {due_date}.', ['number' => $this->invoice->id, 'reference' => $this->invoice->reference, 'due_date' => $this->invoice->due_date ?? now()->toDateString()]))
            ->line(__choice('You can make payment by clicking the following button', ['x' => __('Invoice')]))
            ->action(__('Make Payment'), $url)
            ->line(__('If payment has already been made please let me know the date and reference. If payment is still pending we can extend a day grace period to help get that settled.'))
            ->line(__('Thank you!'));
    }

    public function via($notifiable)
    {
        return ['mail'];
    }
}
