<?php

namespace App\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Support\Facades\URL;
use Illuminate\Notifications\Notification;
use Illuminate\Notifications\Messages\MailMessage;

class InvoiceOverdue extends Notification
{
    use Queueable;

    public $invoice;

    public function __construct($invoice)
    {
        $this->invoice = $invoice;
    }

    public function toMail($notifiable)
    {
        $url = URL::signedRoute('invoice.view', ['id' => $this->invoice->id, 'hash' => $this->invoice->hash]);
        return (new MailMessage())
            ->error()
            ->subject(__('Invoice Overdue'))
            ->greeting('Hello ' . $this->invoice->customer->name . ',')
            ->line(__choice('Invoice # {number} (Reference: {reference}) is past due as of {due_date}.', ['number' => $this->invoice->id, 'reference' => $this->invoice->reference, 'due_date' => $this->invoice->due_date ?? now()->toDateString()]))
            ->line(__choice('You can make payment by clicking the following button', ['x' => __('Invoice')]))
            ->action(__('Make Payment'), $url)
            ->line(__('If there has been an error please let me know so we can resolve that together.'))
            ->line(__('Thank you!'));
    }

    public function via($notifiable)
    {
        return ['mail'];
    }
}
