<?php

namespace App\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Support\Facades\URL;
use Illuminate\Notifications\Notification;
use Illuminate\Notifications\Messages\MailMessage;

class PaymentCreated extends Notification
{
    use Queueable;

    public $payment;

    public function __construct($payment)
    {
        $this->payment = $payment;
    }

    public function toMail($notifiable)
    {
        $url = URL::signedRoute('payment.view', ['id' => $this->payment->id, 'hash' => $this->payment->hash]);
        return (new MailMessage())
            ->subject(__('Payment # {number} ({company})', ['number' => $this->payment->id, 'company' => $this->payment->company->name]))
            ->greeting('Hello ' . $this->payment->customer->name . ',')
            ->line(__choice('New payment # {number} (Reference: {reference}) has been created.', ['number' => $this->payment->id, 'reference' => $this->payment->reference]))
            ->line(__choice('You can view the {x} by clicking the following button', ['x' => __('Payment')]))
            ->action(__('View Payment'), $url)
            ->line(__('Thank you for your business!'));
    }

    public function via($notifiable)
    {
        return ['mail'];
    }
}
