<?php

namespace App\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Support\Facades\URL;
use Illuminate\Notifications\Notification;
use Illuminate\Notifications\Messages\MailMessage;

class QuotationCreated extends Notification
{
    use Queueable;

    public $quotation;

    public function __construct($quotation)
    {
        $this->quotation = $quotation;
    }

    public function toMail($notifiable)
    {
        $url = URL::signedRoute('quotation.view', ['id' => $this->quotation->id, 'hash' => $this->quotation->hash]);
        return (new MailMessage())
            ->subject(__('Quotation # {number} ({company})', ['number' => $this->quotation->id, 'company' => $this->quotation->company->name]))
            ->greeting('Hello ' . $this->quotation->customer->name . ',')
            ->line(__choice('New quotation # {number} (Reference: {reference}) has been created.', ['number' => $this->quotation->id, 'reference' => $this->quotation->reference]))
            ->line(__choice('You can view the {x} by clicking the following button', ['x' => __('Quotation')]))
            ->action(__('View Quotation'), $url)
            ->line(__('Thank you!'));
    }

    public function via($notifiable)
    {
        return ['mail'];
    }
}
