<?php

namespace App\Providers;

use Laravel\Jetstream\Jetstream;
use Illuminate\Support\ServiceProvider;
use App\Actions\Jetstream\{AddTeamMember, CreateTeam, DeleteTeam, DeleteUser, InviteTeamMember, RemoveTeamMember, UpdateTeamName};

class JetstreamServiceProvider extends ServiceProvider
{
    public function boot(): void
    {
        $this->configurePermissions();

        Jetstream::createTeamsUsing(CreateTeam::class);
        Jetstream::deleteTeamsUsing(DeleteTeam::class);
        Jetstream::deleteUsersUsing(DeleteUser::class);
        Jetstream::addTeamMembersUsing(AddTeamMember::class);
        Jetstream::updateTeamNamesUsing(UpdateTeamName::class);
        Jetstream::inviteTeamMembersUsing(InviteTeamMember::class);
        Jetstream::removeTeamMembersUsing(RemoveTeamMember::class);
    }

    public function register(): void
    {
        //
    }

    protected function configurePermissions(): void
    {
        Jetstream::defaultApiTokenPermissions(['read']);

        Jetstream::role('admin', 'Administrator', ['create', 'read', 'update', 'delete'])
            ->description('Administrator users can perform any action.');

        Jetstream::role('editor', 'Editor', ['read', 'create', 'update'])
            ->description('Editor users have the ability to read, create, and update.');
    }
}
