<?php

namespace App\Rules;

use App\Models\Field;
use Illuminate\Contracts\Validation\DataAwareRule;
use Illuminate\Contracts\Validation\InvokableRule;
use Illuminate\Contracts\Validation\ValidatorAwareRule;

class ExtraAttributes implements DataAwareRule, InvokableRule, ValidatorAwareRule
{
    protected $data = [];
    protected $fieldsOf;
    protected $validator;

    public function __construct($fieldsOf)
    {
        $this->fieldsOf = $fieldsOf;
    }

    public function __invoke($attribute, $value, $fail)
    {
        $fields = Field::ofModel($this->fieldsOf)->get();
        foreach ($value as $key => $form_field) {
            $field = $fields->where('name', $key)->first();
            if ('checkbox' == $field->type) {
                $sel = false;
                foreach ($form_field as $opt) {
                    if ($opt) {
                        $sel = true;
                    }
                }
                $form_field = $sel;
            }

            $check = true;
            if (str($attribute)->contains('items.')) {
                $index = (string) str($attribute)->betweenFirst('.', '.');
                $check = 0 == $index || ($this->data['items'][$index]['name'] && $this->data['items'][$index]['quantity'] && $this->data['items'][$index]['price']);
            }

            if ($check && $field && $field->required && !$form_field) {
                $this->validator->getMessageBag()->add($attribute . '.' . $key, __('The :attribute is required.', ['attribute' =>  $key]));
            }
        }
    }

    public function setData($data)
    {
        $this->data = $data;

        return $this;
    }

    public function setValidator($validator)
    {
        $this->validator = $validator;

        return $this;
    }
}
