import { ref, watch, computed, onBeforeUnmount, onMounted, nextTick, resolveComponent, mergeProps, unref, useSSRContext } from "vue";
import { ssrRenderAttrs, ssrRenderComponent, ssrInterpolate, ssrRenderAttr, ssrIncludeBooleanAttr, ssrRenderClass, ssrRenderList } from "vue/server-renderer";
import axios from "axios";
import { useI18n } from "vue-i18n";
import { v4 } from "uuid";
import throttle from "lodash/throttle.js";
import { a as _sfc_main$1, b as _sfc_main$2 } from "./InputError-951c1c36.js";
const _sfc_main = {
  __name: "AutoComplete",
  __ssrInlineRender: true,
  props: {
    id: {
      type: String,
      default() {
        return v4();
      }
    },
    json: Boolean,
    label: String,
    error: String,
    position: String,
    selected: String,
    defaultText: String,
    placeholder: String,
    action: Function,
    actionText: String,
    addResult: Array,
    disable: [String, Number],
    modelValue: [String, Number],
    suggestions: [String, Array],
    valueKey: { type: String, default: "value" },
    labelKey: { type: String, default: "label" },
    multiple: { type: Boolean, default: false },
    clearable: { type: Boolean, default: false },
    searchable: { type: Boolean, default: true },
    keepFocus: { type: Boolean, default: false },
    resetSearch: { type: Boolean, default: false },
    placement: { type: String, default: "bottom" }
  },
  emits: ["update:modelValue"],
  setup(__props, { emit }) {
    const props = __props;
    const { t } = useI18n({});
    const auto_complete = ref(null);
    const search = ref("");
    const result = ref([]);
    const input = ref(null);
    const open = ref(false);
    const stop = ref(false);
    const search0 = ref("");
    const current = ref(null);
    const loading = ref(false);
    const selected = ref(null);
    const multi_current = ref([]);
    const multi_selected = ref([]);
    watch(
      () => props.modelValue,
      async (v) => {
        if (!v) {
          search.value = null;
          await hide();
        } else {
          let vl = multi_selected.value.map((s) => props.json ? s.value : s);
          if (v.toString() !== vl.toString()) {
            await initializeValue();
          }
        }
      }
    );
    watch(
      () => props.addResult,
      async (v) => {
        if (v && v.value) {
          result.value.push(v.value);
          current.value = v.value;
          selected.value = v.value;
          suggestionClick(current.value);
          setTimeout(() => {
            search.value = v.value.label;
            emit("update:modelValue", v.value);
          }, 100);
        }
      }
    );
    watch(search, (s) => {
      if (props.searchable) {
        open.value = true;
        if (Array.isArray(props.suggestions)) {
          result.value = s ? props.suggestions.filter((r) => cLabel(r, s)) : props.suggestions;
        } else if (s) {
          loading.value = true;
          getSuggestions(s);
        }
      }
    });
    const currentLabel = computed(() => cLabel(selected.value));
    const currentValue = computed(() => cValue(selected.value));
    onBeforeUnmount(() => {
      if (props.multiple) {
        window.removeEventListener("click", clickListener);
      }
    });
    onMounted(async () => {
      if (props.multiple) {
        window.addEventListener("click", clickListener);
      }
      await initializeValue();
    });
    const initializeValue = async () => {
      if (Array.isArray(props.suggestions)) {
        result.value = props.suggestions;
      }
      if (props.modelValue) {
        multi_current.value = [];
        if (Array.isArray(props.suggestions)) {
          if (props.multiple) {
            if (props.selected) {
              multi_selected.value = props.selected;
            } else {
              multi_selected.value = props.suggestions.filter(
                (s) => s == props.modelValue || s[props.valueKey] == props.modelValue || props.modelValue.filter((m) => m == s[props.valueKey])[0] || props.modelValue.filter((m) => m[props.valueKey] == s[props.valueKey])[0] || s.id == props.modelValue
              );
            }
            if (props.json) {
              props.suggestions.map((s, si) => {
                if (multi_selected.value.find((v) => v.value == s.value)) {
                  multi_current.value = [...multi_current.value, si];
                }
              });
            } else {
              props.suggestions.map((s, si) => {
                if (multi_selected.value.includes(s)) {
                  multi_current.value = [...multi_current.value, si];
                }
              });
            }
            search.value = multi_selected.value.map((v) => v.label).join(", ");
          } else {
            if (props.json) {
              selected.value = props.suggestions.find(
                (s) => s == props.modelValue || s[props.valueKey] == props.modelValue || s.value == props.modelValue || s.id == props.modelValue
              );
              current.value = props.suggestions.findIndex(
                (s) => s == props.modelValue || s[props.valueKey] == props.modelValue || s.value == props.modelValue || s.id == props.modelValue
              );
              search.value = currentLabel.value;
            } else {
              selected.value = props.modelValue;
            }
          }
          await nextTick();
          await hide();
        } else {
          if (!stop.value) {
            axios.post(props.suggestions, { id: props.modelValue }).then((res) => {
              current.value = 0;
              result.value = res.data;
              selected.value = res.data[0];
              search.value = cLabel(selected.value);
            }).finally(async () => {
              await hide();
              loading.value = false;
            });
          }
        }
      }
    };
    const clickListener = (e) => {
      if (e.target == auto_complete.value || e.composedPath().includes(auto_complete.value)) {
        return false;
      }
      hide(e, true);
    };
    const getSuggestions = throttle((s) => {
      let nr = result.value;
      (nr == null ? void 0 : nr.length) ? nr[0] : {};
      if (!stop.value && s && s !== currentLabel.value) {
        search0.value = s;
        axios.post(props.suggestions, { search: s }).then((res) => {
          result.value = res.data;
          if (result.value.length == 1) {
            suggestionClick(0);
          }
        }).finally(() => loading.value = false);
      } else {
        loading.value = false;
      }
      stop.value = false;
    }, 300);
    const cLabel = (r, s) => {
      if (r === null) {
        return null;
      } else if (typeof r !== "object") {
        return r;
      }
      let key = "";
      if (props.labelKey) {
        key = props.labelKey;
      } else if (r.label !== void 0) {
        key = "label";
      } else if (r.name !== void 0) {
        key = "name";
      }
      if (s) {
        return key ? r[key].toLowerCase().includes(s.toString().toLowerCase()) : r.toLowerCase().includes(s.toLowerCase());
      }
      return key ? r[key] : r;
    };
    const cValue = (r) => {
      if (r === null) {
        return null;
      } else if (typeof r !== "object") {
        return r;
      }
      let key = "";
      if (props.valueKey) {
        key = props.valueKey;
      } else if (r.value !== void 0) {
        key = "value";
      } else if (r.id !== void 0) {
        key = "id";
      }
      return key ? r[key] : r;
    };
    const hide = async (event, force) => {
      if (!props.multiple || force) {
        if (selected.value) {
          search.value = currentLabel.value;
        }
        await nextTick();
        setTimeout(() => open.value = false, 100);
      }
    };
    const isActive = (index) => {
      if (props.multiple) {
        return multi_current.value.includes(index);
      }
      return index == current.value;
    };
    const suggestionClick = async (index, reset = false) => {
      stop.value = true;
      if (index !== void 0) {
        if (props.multiple) {
          if (props.json && multi_selected.value.find((v) => v.value == result.value[index].value)) {
            multi_selected.value = multi_selected.value.filter((v) => v.value != result.value[index].value);
          } else {
            if (multi_selected.value.find((v) => v == result.value[index])) {
              multi_selected.value = multi_selected.value.filter((v) => v != result.value[index]);
            } else {
              multi_selected.value = [
                ...multi_selected.value,
                Array.isArray(index) ? result.value.find((v) => v == index[0]) : result.value[index]
              ];
            }
          }
          multi_current.value = [];
          props.suggestions.map((s, si) => {
            if (props.json && multi_selected.value.find((v) => v.value == s.value)) {
              multi_current.value = [...multi_current.value, si];
            } else if (multi_selected.value.includes(s)) {
              multi_current.value = [...multi_current.value, si];
            }
          });
          emit("update:modelValue", props.json ? multi_selected.value.map((v) => v.value) : multi_selected.value);
          search.value = multi_selected.value.map((v) => props.json ? v.label : v).join(", ");
          search.value = search.value || currentLabel.value;
        } else {
          current.value = index;
          selected.value = result.value[index];
          emit("update:modelValue", props.json ? currentValue.value : selected.value);
          search.value = props.resetSearch ? null : currentLabel.value;
          await hide();
        }
      }
      if (reset) {
        result.value = [];
      }
      if (props.resetSearch) {
        selected.value = null;
      }
      if (props.keepFocus) {
        input.value.focus();
      }
    };
    return (_ctx, _push, _parent, _attrs) => {
      const _component_icons = resolveComponent("icons");
      _push(`<div${ssrRenderAttrs(mergeProps({ class: "col-span-6 sm:col-span-4" }, _attrs))}><div class="flex items-center justify-between">`);
      if (__props.label) {
        _push(ssrRenderComponent(_sfc_main$1, {
          for: __props.id,
          value: __props.label,
          class: "flex-1"
        }, null, _parent));
      } else {
        _push(`<!---->`);
      }
      if (__props.actionText && __props.action) {
        _push(`<button type="button" class="link text-sm focus:ring-0">${ssrInterpolate(__props.actionText)}</button>`);
      } else {
        _push(`<!---->`);
      }
      _push(`</div><div class="relative mt-1 mb-2 flex items-center"><label${ssrRenderAttr("for", __props.id)} class="cursor-pointer absolute top-0 right-0 border border-transparent p-3 text-gray-500 dark:text-gray-400">`);
      _push(ssrRenderComponent(_component_icons, {
        name: "chevron-down",
        "class-name": "w-5 h-6"
      }, null, _parent));
      _push(`</label>`);
      if (__props.clearable && __props.modelValue) {
        _push(`<button type="button" class="cursor-pointer focus:outline-none absolute top-0 right-8 border border-transparent p-2 text-gray-500 hover:text-red-500">`);
        _push(ssrRenderComponent(_component_icons, {
          name: "cross",
          "class-name": "w-4 h-6"
        }, null, _parent));
        _push(`</button>`);
      } else {
        _push(`<!---->`);
      }
      _push(`<input${ssrRenderAttr("id", __props.id)}${ssrRenderAttr("value", search.value)} autocomplete="off"${ssrIncludeBooleanAttr(!__props.searchable) ? " readonly" : ""}${ssrRenderAttr("placeholder", __props.placeholder || __props.label)} class="${ssrRenderClass([{ "border-red-500": __props.error, "pr-8": !__props.clearable, "pr-16": __props.clearable }, "w-full block text-base py-2 pl-4 placeholder-gray-400 border border-gray-300 dark:border-gray-700 focus:outline-none focus:border-blue-300 focus:ring focus:ring-blue-200 focus:ring-opacity-50 rounded-md shadow-sm dark:bg-gray-800 placeholder:text-gray-400 dark:placeholder:text-gray-500"])}">`);
      if (open.value) {
        _push(`<div class="${ssrRenderClass([__props.placement == "top" ? "mb-2 bottom-full " + __props.position : "mt-2 top-full " + __props.position, "absolute w-full rounded-md z-20"])}"><ul class="max-h-56 rounded-md bg-white dark:bg-gray-900 border dark:border-gray-700 text-base overflow-auto focus:outline-none sm:text-sm">`);
        if (result.value && result.value.length) {
          _push(`<!--[-->`);
          ssrRenderList(result.value, (r, ri) => {
            _push(`<!--[-->`);
            if (!(__props.disable && __props.disable == cValue())) {
              _push(`<li><button type="button"${ssrRenderAttr("id", __props.id + "-" + ri)} class="${ssrRenderClass([
                isActive(ri) ? "bg-blue-600 text-white hover:bg-blue-200 hover:text-blue-800 " : "text-gray-900 dark:text-gray-100 hover:bg-gray-100 hover:text-gray-700 dark:hover:bg-gray-700 dark:hover:text-gray-100",
                "w-full text-left flex items-center select-none relative py-2 focus:outline-none focus:ring-0 focus:rounded-none"
              ])}"><span class="ml-3 block font-normal truncate">${ssrInterpolate(cLabel(r))}</span></button></li>`);
            } else {
              _push(`<!---->`);
            }
            _push(`<!--]-->`);
          });
          _push(`<!--]-->`);
        } else {
          _push(`<li class="bg-blue-600 text-white cursor-default select-none relative py-2"><div class="flex items-center"><span class="ml-3 block font-normal truncate">`);
          if (loading.value) {
            _push(`<span>${ssrInterpolate(unref(t)("Searching for results"))}...</span>`);
          } else if (result.value == null) {
            _push(`<span>${ssrInterpolate(unref(t)("Scan barcode or search items for next"))}</span>`);
          } else if (__props.json) {
            _push(`<span>${ssrInterpolate(__props.defaultText || unref(t)("Please type to search"))}</span>`);
          } else {
            _push(`<span>${ssrInterpolate(unref(t)("No result suggestions to list."))}</span>`);
          }
          _push(`</span></div></li>`);
        }
        _push(`</ul></div>`);
      } else {
        _push(`<!---->`);
      }
      _push(`</div>`);
      if (__props.error) {
        _push(ssrRenderComponent(_sfc_main$2, {
          message: __props.error,
          class: "mt-0"
        }, null, _parent));
      } else {
        _push(`<!---->`);
      }
      _push(`</div>`);
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Shared/AutoComplete.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};
export {
  _sfc_main as _
};
