import { ref, watch, onMounted, unref, useSSRContext } from "vue";
import { ssrRenderList, ssrRenderClass, ssrRenderComponent, ssrInterpolate, ssrRenderAttr, ssrIncludeBooleanAttr, ssrLooseEqual } from "vue/server-renderer";
import { useI18n } from "vue-i18n";
import debounce from "lodash/debounce.js";
import { C as CheckBox } from "./ActionMessage-cdce5426.js";
import { _ as _sfc_main$1 } from "./TextInput-f18b2e86.js";
import { _ as _sfc_main$2 } from "./AutoComplete-974a17ce.js";
import { _ as _sfc_main$3 } from "./TextareaInput-651f7dc6.js";
const _sfc_main = {
  __name: "CustomFields",
  __ssrInlineRender: true,
  props: {
    id: String,
    fields: Array,
    className: String,
    errors: { type: [Boolean, Object] },
    modelValue: { type: [Array, Object] }
  },
  emits: ["updated", "update:modelValue"],
  setup(__props, { emit }) {
    const props = __props;
    const { t } = useI18n({});
    const loading = ref(true);
    const extra_errors = ref({});
    const extra_attributes = ref({});
    watch(
      () => props.errors,
      debounce((errors) => {
        Object.keys(errors).map((e) => {
          if (e.includes("extra_attributes.")) {
            extra_errors.value[e.split(".").pop()] = errors[e];
          }
        });
      }, 50),
      { deep: true }
    );
    watch(
      extra_attributes,
      debounce((e) => {
        emit("updated", e);
        emit("update:modelValue", e);
      }, 500),
      { deep: true }
    );
    onMounted(() => {
      props.fields.map((f) => {
        var _a;
        if (f.type == "checkbox") {
          extra_attributes.value[f.name] = {};
          (_a = f.options.split(",")) == null ? void 0 : _a.map((item) => item.trim()).map((i) => {
            extra_attributes.value[f.name][i] = props.modelValue[f.name] || false;
          });
        } else {
          extra_attributes.value[f.name] = props.modelValue[f.name] || null;
        }
      });
      loading.value = false;
    });
    return (_ctx, _push, _parent, _attrs) => {
      if (!loading.value && __props.fields && __props.fields.length) {
        _push(`<!--[-->`);
        ssrRenderList(__props.fields, (field, fi) => {
          var _a, _b, _c;
          _push(`<div class="${ssrRenderClass(field.type == "textarea" ? "col-span-full w-full" : __props.className)}">`);
          if (field.type == "text" || field.type == "date" || field.type == "datetime") {
            _push(ssrRenderComponent(_sfc_main$1, {
              type: field.type,
              label: unref(t)(field.name),
              id: __props.id + "_extra_attr_" + fi,
              error: extra_errors.value[field.name],
              modelValue: extra_attributes.value[field.name],
              "onUpdate:modelValue": ($event) => extra_attributes.value[field.name] = $event
            }, null, _parent));
          } else if (field.type == "select" || field.type == "select_multiple") {
            _push(ssrRenderComponent(_sfc_main$2, {
              searchable: false,
              label: unref(t)(field.name),
              id: __props.id + "_extra_attr_" + fi,
              error: extra_errors.value[field.name],
              modelValue: extra_attributes.value[field.name],
              "onUpdate:modelValue": ($event) => extra_attributes.value[field.name] = $event,
              multiple: field.type == "select_multiple",
              suggestions: (_a = field.options.split(",")) == null ? void 0 : _a.map((item) => item.trim())
            }, null, _parent));
          } else if (field.type == "textarea") {
            _push(ssrRenderComponent(_sfc_main$3, {
              type: field.type,
              label: unref(t)(field.name),
              id: __props.id + "_extra_attr_" + fi,
              error: extra_errors.value[field.name],
              modelValue: extra_attributes.value[field.name],
              "onUpdate:modelValue": ($event) => extra_attributes.value[field.name] = $event
            }, null, _parent));
          } else if (field.type == "checkbox") {
            _push(`<!--[--><label class="block font-medium text-sm text-gray-700 dark:text-gray-300">${ssrInterpolate(unref(t)(field.name))}</label><div class="flex flex-col mt-2"><!--[-->`);
            ssrRenderList((_b = field.options.split(",")) == null ? void 0 : _b.map((item) => item.trim()), (opt, oi) => {
              _push(`<div class="relative flex items-center">`);
              _push(ssrRenderComponent(CheckBox, {
                label: unref(t)(opt),
                id: __props.id + "_extra_attr_" + fi + "_" + oi,
                checked: extra_attributes.value[field.name][opt],
                "onUpdate:checked": ($event) => extra_attributes.value[field.name][opt] = $event
              }, null, _parent));
              _push(`</div>`);
            });
            _push(`<!--]--></div>`);
            if (extra_errors.value[field.name]) {
              _push(`<span class="text-red-600 text-sm">${ssrInterpolate(extra_errors.value[field.name].replace("extra_attributes.", ""))}</span>`);
            } else {
              _push(`<!---->`);
            }
            _push(`<!--]-->`);
          } else if (field.type == "radio") {
            _push(`<!--[--><label class="block font-medium text-sm text-gray-700 dark:text-gray-300">${ssrInterpolate(unref(t)(field.name))}</label><div class="flex flex-col mt-2 gap-2"><!--[-->`);
            ssrRenderList((_c = field.options.split(",")) == null ? void 0 : _c.map((item) => item.trim()), (opt, oi) => {
              _push(`<div class="flex items-center"><div class="flex items-center gap-1"><input type="radio"${ssrRenderAttr("value", opt)}${ssrRenderAttr("name", field.name)}${ssrIncludeBooleanAttr(ssrLooseEqual(extra_attributes.value[field.name], opt)) ? " checked" : ""}${ssrRenderAttr("id", __props.id + "_extra_attr_" + fi + "_" + oi)} class="rounded-full border-gray-300 dark:border-gray-700 dark:bg-gray-700 text-blue-600 shadow-sm w-5 h-5 focus:rounded-full focus:ring-offset-0 focus:ring-blue-200 dark:focus:ring-opacity-50"><label${ssrRenderAttr("for", __props.id + "_extra_attr_" + fi + "_" + oi)} class="ml-2 block">${ssrInterpolate(opt)}</label></div></div>`);
            });
            _push(`<!--]-->`);
            if (extra_errors.value[field.name]) {
              _push(`<span class="text-red-600 text-sm">${ssrInterpolate(extra_errors.value[field.name].replace("extra_attributes.", ""))}</span>`);
            } else {
              _push(`<!---->`);
            }
            _push(`</div><!--]-->`);
          } else {
            _push(`<!---->`);
          }
          _push(`</div>`);
        });
        _push(`<!--]-->`);
      } else {
        _push(`<!---->`);
      }
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Shared/CustomFields.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};
export {
  _sfc_main as _
};
