import { ref, mergeProps, unref, withCtx, createTextVNode, toDisplayString, createVNode, openBlock, createBlock, createCommentVNode, withModifiers, useSSRContext } from "vue";
import { ssrRenderComponent, ssrInterpolate, ssrRenderAttr, ssrRenderStyle } from "vue/server-renderer";
import { useI18n } from "vue-i18n";
import { useForm } from "@inertiajs/vue3";
import { _ as _sfc_main$3, a as _sfc_main$4, b as _sfc_main$6 } from "./InputError-951c1c36.js";
import { _ as _sfc_main$7 } from "./TextInput-f18b2e86.js";
import { _ as _sfc_main$1 } from "./AppLayout-9f2f965f.js";
import { _ as _sfc_main$8 } from "./CustomFields-6004e621.js";
import { _ as _sfc_main$2 } from "./FormSection-d5f140fc.js";
import { _ as _sfc_main$9 } from "./ActionMessage-cdce5426.js";
import { _ as _sfc_main$5 } from "./SecondaryButton-910b0895.js";
import "../ssr.js";
import "@vue/server-renderer";
import "@inertiajs/vue3/server";
import "uuid";
import "./Input-fb927b71.js";
import "./Modal-4ced3d7d.js";
import "lodash/debounce.js";
import "./AutoComplete-974a17ce.js";
import "axios";
import "lodash/throttle.js";
import "./TextareaInput-651f7dc6.js";
const _sfc_main = {
  __name: "Form",
  __ssrInlineRender: true,
  props: ["edit", "fields"],
  setup(__props) {
    const props = __props;
    const { t } = useI18n({});
    const logoInput = ref(null);
    const logoPreview = ref(null);
    const form = useForm({
      _method: "post",
      name: null,
      contact_person: null,
      email: null,
      phone: null,
      address: null,
      city: null,
      postal_code: null,
      state: null,
      country: null,
      logo: null,
      ss_image: null,
      extra_attributes: {}
    });
    if (props.edit) {
      if (props.edit.data.extra_attributes && props.fields) {
        Object.keys(props.edit.data.extra_attributes).filter((k) => {
          var _a;
          return !((_a = props.fields) == null ? void 0 : _a.find((f) => f.name == k));
        }).map((k) => delete props.edit.data.extra_attributes[k]);
      }
      form.name = props.edit.data.name;
      form.contact_person = props.edit.data.contact_person;
      form.email = props.edit.data.email;
      form.phone = props.edit.data.phone;
      form.address = props.edit.data.address;
      form.city = props.edit.data.city;
      form.postal_code = props.edit.data.postal_code;
      form.state = props.edit.data.state;
      form.country = props.edit.data.country;
      form.logo = props.edit.data.logo;
      form.ss_image = props.edit.data.ss_image;
      form.extra_attributes = props.edit.data.extra_attributes || {};
    }
    const selectNewLogo = () => {
      logoInput.value.click();
    };
    const updateLogoPreview = () => {
      const photo = logoInput.value.files[0];
      if (!photo)
        return;
      const reader = new FileReader();
      reader.onload = (e) => {
        logoPreview.value = e.target.result;
      };
      reader.readAsDataURL(photo);
    };
    function submit() {
      if (logoInput.value) {
        form.logo = logoInput.value.files[0];
      }
      let url = route("companies.store");
      if (props.edit) {
        form._method = "put";
        url = route("companies.update", props.edit.data.id);
      }
      form.transform((data) => ({ ...data, extra_attributes: { ...data.extra_attributes } })).post(url, {
        preserveScroll: true,
        onSuccess: () => {
          props.edit ? "" : form.reset();
        },
        onError: () => {
          if (form.errors.company_id) {
            document.getElementById("company_id").focus();
          }
          if (form.errors.customer_id) {
            document.getElementById("customer_id").focus();
          }
          if (form.errors.email) {
            document.getElementById("email").focus();
          }
          if (form.errors.phone) {
            document.getElementById("phone").focus();
          }
        }
      });
    }
    return (_ctx, _push, _parent, _attrs) => {
      _push(ssrRenderComponent(_sfc_main$1, mergeProps({
        title: props.edit ? unref(t)("Edit Company") : unref(t)("Add New Company")
      }, _attrs), {
        default: withCtx((_, _push2, _parent2, _scopeId) => {
          if (_push2) {
            _push2(`<div class="max-w-7xl mx-auto py-10 sm:px-6 lg:px-8"${_scopeId}>`);
            _push2(ssrRenderComponent(_sfc_main$2, {
              onSubmitted: submit,
              autocomplete: "off"
            }, {
              title: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(`${ssrInterpolate(props.edit ? unref(t)("Edit Company") : unref(t)("Add New Company"))}`);
                } else {
                  return [
                    createTextVNode(toDisplayString(props.edit ? unref(t)("Edit Company") : unref(t)("Add New Company")), 1)
                  ];
                }
              }),
              description: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(`${ssrInterpolate(unref(t)("Please fill the form below to {x}.", {
                    x: props.edit ? unref(t)("update {x}", { x: unref(t)("company") }) : unref(t)("add {x}", { x: unref(t)("company") })
                  }))} <div${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$3, {
                    href: _ctx.route("companies.index"),
                    class: "mt-4"
                  }, {
                    default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                      if (_push4) {
                        _push4(`${ssrInterpolate(unref(t)("List Companies"))}`);
                      } else {
                        return [
                          createTextVNode(toDisplayString(unref(t)("List Companies")), 1)
                        ];
                      }
                    }),
                    _: 1
                  }, _parent3, _scopeId2));
                  _push3(`</div>`);
                } else {
                  return [
                    createTextVNode(toDisplayString(unref(t)("Please fill the form below to {x}.", {
                      x: props.edit ? unref(t)("update {x}", { x: unref(t)("company") }) : unref(t)("add {x}", { x: unref(t)("company") })
                    })) + " ", 1),
                    createVNode("div", null, [
                      createVNode(_sfc_main$3, {
                        href: _ctx.route("companies.index"),
                        class: "mt-4"
                      }, {
                        default: withCtx(() => [
                          createTextVNode(toDisplayString(unref(t)("List Companies")), 1)
                        ]),
                        _: 1
                      }, 8, ["href"])
                    ])
                  ];
                }
              }),
              form: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(`<div class="col-span-full"${_scopeId2}><input type="file" class="hidden" accept=".png,.jpg,.jpeg,.svg"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$4, {
                    for: "logo",
                    value: unref(t)("Logo")
                  }, null, _parent3, _scopeId2));
                  if (!logoPreview.value && unref(form).logo) {
                    _push3(`<div class="my-2 rounded-md bg-white p-2"${_scopeId2}><img${ssrRenderAttr("src", "/storage/" + unref(form).logo)}${ssrRenderAttr("alt", unref(form).name)} class="block rounded w-80 h-20 mx-auto bg-contain"${_scopeId2}></div>`);
                  } else {
                    _push3(`<!---->`);
                  }
                  if (logoPreview.value) {
                    _push3(`<div class="my-2 rounded-md bg-white p-2"${_scopeId2}><span class="block rounded w-80 h-20 mx-auto bg-contain bg-no-repeat bg-center" style="${ssrRenderStyle("background-image: url('" + logoPreview.value + "');")}"${_scopeId2}></span></div>`);
                  } else {
                    _push3(`<!---->`);
                  }
                  _push3(ssrRenderComponent(_sfc_main$5, {
                    class: "mt-2 mr-2",
                    type: "button",
                    onClick: selectNewLogo
                  }, {
                    default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                      if (_push4) {
                        _push4(`${ssrInterpolate(unref(t)("Select Logo"))}`);
                      } else {
                        return [
                          createTextVNode(toDisplayString(unref(t)("Select Logo")), 1)
                        ];
                      }
                    }),
                    _: 1
                  }, _parent3, _scopeId2));
                  _push3(ssrRenderComponent(_sfc_main$6, {
                    message: unref(form).errors.logo,
                    class: "mt-2"
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$7, {
                    modelValue: unref(form).name,
                    "onUpdate:modelValue": ($event) => unref(form).name = $event,
                    id: "name",
                    error: unref(form).errors.name,
                    label: unref(t)("Name")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$7, {
                    modelValue: unref(form).contact_person,
                    "onUpdate:modelValue": ($event) => unref(form).contact_person = $event,
                    id: "contact_person",
                    error: unref(form).errors.contact_person,
                    label: unref(t)("Contact Person")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$7, {
                    modelValue: unref(form).email,
                    "onUpdate:modelValue": ($event) => unref(form).email = $event,
                    id: "email",
                    error: unref(form).errors.email,
                    label: unref(t)("Email")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$7, {
                    modelValue: unref(form).phone,
                    "onUpdate:modelValue": ($event) => unref(form).phone = $event,
                    id: "phone",
                    error: unref(form).errors.phone,
                    label: unref(t)("Phone")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-full"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$7, {
                    modelValue: unref(form).address,
                    "onUpdate:modelValue": ($event) => unref(form).address = $event,
                    id: "address",
                    error: unref(form).errors.address,
                    label: unref(t)("Address")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$7, {
                    modelValue: unref(form).city,
                    "onUpdate:modelValue": ($event) => unref(form).city = $event,
                    id: "city",
                    error: unref(form).errors.city,
                    label: unref(t)("City")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$7, {
                    modelValue: unref(form).postal_code,
                    "onUpdate:modelValue": ($event) => unref(form).postal_code = $event,
                    id: "postal_code",
                    error: unref(form).errors.postal_code,
                    label: unref(t)("Postal Code")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$7, {
                    modelValue: unref(form).state,
                    "onUpdate:modelValue": ($event) => unref(form).state = $event,
                    id: "state",
                    error: unref(form).errors.state,
                    label: unref(t)("State")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$7, {
                    modelValue: unref(form).country,
                    "onUpdate:modelValue": ($event) => unref(form).country = $event,
                    id: "country",
                    error: unref(form).errors.country,
                    label: unref(t)("Country")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div>`);
                  _push3(ssrRenderComponent(_sfc_main$8, {
                    fields: __props.fields,
                    errors: unref(form).errors,
                    modelValue: unref(form).extra_attributes,
                    "onUpdate:modelValue": ($event) => unref(form).extra_attributes = $event,
                    className: "col-span-6 sm:col-span-3"
                  }, null, _parent3, _scopeId2));
                } else {
                  return [
                    createVNode("div", { class: "col-span-full" }, [
                      createVNode("input", {
                        ref_key: "logoInput",
                        ref: logoInput,
                        type: "file",
                        class: "hidden",
                        accept: ".png,.jpg,.jpeg,.svg",
                        onChange: updateLogoPreview
                      }, null, 544),
                      createVNode(_sfc_main$4, {
                        for: "logo",
                        value: unref(t)("Logo")
                      }, null, 8, ["value"]),
                      !logoPreview.value && unref(form).logo ? (openBlock(), createBlock("div", {
                        key: 0,
                        class: "my-2 rounded-md bg-white p-2"
                      }, [
                        createVNode("img", {
                          src: "/storage/" + unref(form).logo,
                          alt: unref(form).name,
                          class: "block rounded w-80 h-20 mx-auto bg-contain"
                        }, null, 8, ["src", "alt"])
                      ])) : createCommentVNode("", true),
                      logoPreview.value ? (openBlock(), createBlock("div", {
                        key: 1,
                        class: "my-2 rounded-md bg-white p-2"
                      }, [
                        createVNode("span", {
                          class: "block rounded w-80 h-20 mx-auto bg-contain bg-no-repeat bg-center",
                          style: "background-image: url('" + logoPreview.value + "');"
                        }, null, 4)
                      ])) : createCommentVNode("", true),
                      createVNode(_sfc_main$5, {
                        class: "mt-2 mr-2",
                        type: "button",
                        onClick: withModifiers(selectNewLogo, ["prevent"])
                      }, {
                        default: withCtx(() => [
                          createTextVNode(toDisplayString(unref(t)("Select Logo")), 1)
                        ]),
                        _: 1
                      }, 8, ["onClick"]),
                      createVNode(_sfc_main$6, {
                        message: unref(form).errors.logo,
                        class: "mt-2"
                      }, null, 8, ["message"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).name,
                        "onUpdate:modelValue": ($event) => unref(form).name = $event,
                        id: "name",
                        error: unref(form).errors.name,
                        label: unref(t)("Name")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).contact_person,
                        "onUpdate:modelValue": ($event) => unref(form).contact_person = $event,
                        id: "contact_person",
                        error: unref(form).errors.contact_person,
                        label: unref(t)("Contact Person")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).email,
                        "onUpdate:modelValue": ($event) => unref(form).email = $event,
                        id: "email",
                        error: unref(form).errors.email,
                        label: unref(t)("Email")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).phone,
                        "onUpdate:modelValue": ($event) => unref(form).phone = $event,
                        id: "phone",
                        error: unref(form).errors.phone,
                        label: unref(t)("Phone")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-full" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).address,
                        "onUpdate:modelValue": ($event) => unref(form).address = $event,
                        id: "address",
                        error: unref(form).errors.address,
                        label: unref(t)("Address")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).city,
                        "onUpdate:modelValue": ($event) => unref(form).city = $event,
                        id: "city",
                        error: unref(form).errors.city,
                        label: unref(t)("City")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).postal_code,
                        "onUpdate:modelValue": ($event) => unref(form).postal_code = $event,
                        id: "postal_code",
                        error: unref(form).errors.postal_code,
                        label: unref(t)("Postal Code")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).state,
                        "onUpdate:modelValue": ($event) => unref(form).state = $event,
                        id: "state",
                        error: unref(form).errors.state,
                        label: unref(t)("State")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).country,
                        "onUpdate:modelValue": ($event) => unref(form).country = $event,
                        id: "country",
                        error: unref(form).errors.country,
                        label: unref(t)("Country")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode(_sfc_main$8, {
                      fields: __props.fields,
                      errors: unref(form).errors,
                      modelValue: unref(form).extra_attributes,
                      "onUpdate:modelValue": ($event) => unref(form).extra_attributes = $event,
                      className: "col-span-6 sm:col-span-3"
                    }, null, 8, ["fields", "errors", "modelValue", "onUpdate:modelValue"])
                  ];
                }
              }),
              actions: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(ssrRenderComponent(_sfc_main$9, {
                    on: unref(form).recentlySuccessful,
                    class: "mr-3"
                  }, {
                    default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                      if (_push4) {
                        _push4(`${ssrInterpolate(unref(t)("Saved."))}`);
                      } else {
                        return [
                          createTextVNode(toDisplayString(unref(t)("Saved.")), 1)
                        ];
                      }
                    }),
                    _: 1
                  }, _parent3, _scopeId2));
                  _push3(ssrRenderComponent(_sfc_main$3, {
                    type: "submit",
                    loading: unref(form).processing
                  }, {
                    default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                      if (_push4) {
                        _push4(`${ssrInterpolate(unref(t)("Save"))}`);
                      } else {
                        return [
                          createTextVNode(toDisplayString(unref(t)("Save")), 1)
                        ];
                      }
                    }),
                    _: 1
                  }, _parent3, _scopeId2));
                } else {
                  return [
                    createVNode(_sfc_main$9, {
                      on: unref(form).recentlySuccessful,
                      class: "mr-3"
                    }, {
                      default: withCtx(() => [
                        createTextVNode(toDisplayString(unref(t)("Saved.")), 1)
                      ]),
                      _: 1
                    }, 8, ["on"]),
                    createVNode(_sfc_main$3, {
                      type: "submit",
                      loading: unref(form).processing
                    }, {
                      default: withCtx(() => [
                        createTextVNode(toDisplayString(unref(t)("Save")), 1)
                      ]),
                      _: 1
                    }, 8, ["loading"])
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
            _push2(`</div>`);
          } else {
            return [
              createVNode("div", { class: "max-w-7xl mx-auto py-10 sm:px-6 lg:px-8" }, [
                createVNode(_sfc_main$2, {
                  onSubmitted: submit,
                  autocomplete: "off"
                }, {
                  title: withCtx(() => [
                    createTextVNode(toDisplayString(props.edit ? unref(t)("Edit Company") : unref(t)("Add New Company")), 1)
                  ]),
                  description: withCtx(() => [
                    createTextVNode(toDisplayString(unref(t)("Please fill the form below to {x}.", {
                      x: props.edit ? unref(t)("update {x}", { x: unref(t)("company") }) : unref(t)("add {x}", { x: unref(t)("company") })
                    })) + " ", 1),
                    createVNode("div", null, [
                      createVNode(_sfc_main$3, {
                        href: _ctx.route("companies.index"),
                        class: "mt-4"
                      }, {
                        default: withCtx(() => [
                          createTextVNode(toDisplayString(unref(t)("List Companies")), 1)
                        ]),
                        _: 1
                      }, 8, ["href"])
                    ])
                  ]),
                  form: withCtx(() => [
                    createVNode("div", { class: "col-span-full" }, [
                      createVNode("input", {
                        ref_key: "logoInput",
                        ref: logoInput,
                        type: "file",
                        class: "hidden",
                        accept: ".png,.jpg,.jpeg,.svg",
                        onChange: updateLogoPreview
                      }, null, 544),
                      createVNode(_sfc_main$4, {
                        for: "logo",
                        value: unref(t)("Logo")
                      }, null, 8, ["value"]),
                      !logoPreview.value && unref(form).logo ? (openBlock(), createBlock("div", {
                        key: 0,
                        class: "my-2 rounded-md bg-white p-2"
                      }, [
                        createVNode("img", {
                          src: "/storage/" + unref(form).logo,
                          alt: unref(form).name,
                          class: "block rounded w-80 h-20 mx-auto bg-contain"
                        }, null, 8, ["src", "alt"])
                      ])) : createCommentVNode("", true),
                      logoPreview.value ? (openBlock(), createBlock("div", {
                        key: 1,
                        class: "my-2 rounded-md bg-white p-2"
                      }, [
                        createVNode("span", {
                          class: "block rounded w-80 h-20 mx-auto bg-contain bg-no-repeat bg-center",
                          style: "background-image: url('" + logoPreview.value + "');"
                        }, null, 4)
                      ])) : createCommentVNode("", true),
                      createVNode(_sfc_main$5, {
                        class: "mt-2 mr-2",
                        type: "button",
                        onClick: withModifiers(selectNewLogo, ["prevent"])
                      }, {
                        default: withCtx(() => [
                          createTextVNode(toDisplayString(unref(t)("Select Logo")), 1)
                        ]),
                        _: 1
                      }, 8, ["onClick"]),
                      createVNode(_sfc_main$6, {
                        message: unref(form).errors.logo,
                        class: "mt-2"
                      }, null, 8, ["message"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).name,
                        "onUpdate:modelValue": ($event) => unref(form).name = $event,
                        id: "name",
                        error: unref(form).errors.name,
                        label: unref(t)("Name")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).contact_person,
                        "onUpdate:modelValue": ($event) => unref(form).contact_person = $event,
                        id: "contact_person",
                        error: unref(form).errors.contact_person,
                        label: unref(t)("Contact Person")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).email,
                        "onUpdate:modelValue": ($event) => unref(form).email = $event,
                        id: "email",
                        error: unref(form).errors.email,
                        label: unref(t)("Email")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).phone,
                        "onUpdate:modelValue": ($event) => unref(form).phone = $event,
                        id: "phone",
                        error: unref(form).errors.phone,
                        label: unref(t)("Phone")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-full" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).address,
                        "onUpdate:modelValue": ($event) => unref(form).address = $event,
                        id: "address",
                        error: unref(form).errors.address,
                        label: unref(t)("Address")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).city,
                        "onUpdate:modelValue": ($event) => unref(form).city = $event,
                        id: "city",
                        error: unref(form).errors.city,
                        label: unref(t)("City")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).postal_code,
                        "onUpdate:modelValue": ($event) => unref(form).postal_code = $event,
                        id: "postal_code",
                        error: unref(form).errors.postal_code,
                        label: unref(t)("Postal Code")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).state,
                        "onUpdate:modelValue": ($event) => unref(form).state = $event,
                        id: "state",
                        error: unref(form).errors.state,
                        label: unref(t)("State")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$7, {
                        modelValue: unref(form).country,
                        "onUpdate:modelValue": ($event) => unref(form).country = $event,
                        id: "country",
                        error: unref(form).errors.country,
                        label: unref(t)("Country")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode(_sfc_main$8, {
                      fields: __props.fields,
                      errors: unref(form).errors,
                      modelValue: unref(form).extra_attributes,
                      "onUpdate:modelValue": ($event) => unref(form).extra_attributes = $event,
                      className: "col-span-6 sm:col-span-3"
                    }, null, 8, ["fields", "errors", "modelValue", "onUpdate:modelValue"])
                  ]),
                  actions: withCtx(() => [
                    createVNode(_sfc_main$9, {
                      on: unref(form).recentlySuccessful,
                      class: "mr-3"
                    }, {
                      default: withCtx(() => [
                        createTextVNode(toDisplayString(unref(t)("Saved.")), 1)
                      ]),
                      _: 1
                    }, 8, ["on"]),
                    createVNode(_sfc_main$3, {
                      type: "submit",
                      loading: unref(form).processing
                    }, {
                      default: withCtx(() => [
                        createTextVNode(toDisplayString(unref(t)("Save")), 1)
                      ]),
                      _: 1
                    }, 8, ["loading"])
                  ]),
                  _: 1
                })
              ])
            ];
          }
        }),
        _: 1
      }, _parent));
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Pages/Company/Form.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};
export {
  _sfc_main as default
};
