import { ref, onMounted, mergeProps, useSSRContext } from "vue";
import { ssrRenderAttrs, ssrRenderComponent, ssrRenderAttr, ssrRenderClass, ssrInterpolate } from "vue/server-renderer";
import { v4 } from "uuid";
import { a as _sfc_main$1, b as _sfc_main$2 } from "./InputError-951c1c36.js";
import "./Input-fb927b71.js";
const _sfc_main = {
  __name: "TextareaInput",
  __ssrInlineRender: true,
  props: {
    id: {
      type: String,
      default() {
        return v4();
      }
    },
    type: {
      type: String,
      default: "text"
    },
    modelValue: String,
    label: String,
    error: String
  },
  emits: ["update:modelValue"],
  setup(__props) {
    const props = __props;
    const input = ref(null);
    const textValue = ref("");
    onMounted(() => {
      textValue.value = props.modelValue;
      setTimeout(() => resize(textValue.value), 250);
    });
    const calcHeight = (value) => {
      let numberOfLineBreaks = ((value == null ? void 0 : value.match(/\n/g)) || []).length;
      let newHeight = 70 + numberOfLineBreaks * 23;
      return newHeight;
    };
    const resize = () => {
      input.value.style.height = calcHeight(textValue.value) + "px";
    };
    return (_ctx, _push, _parent, _attrs) => {
      _push(`<div${ssrRenderAttrs(mergeProps({ class: "col-span-6 sm:col-span-4" }, _attrs))}>`);
      _push(ssrRenderComponent(_sfc_main$1, {
        for: __props.id,
        value: __props.label
      }, null, _parent));
      _push(`<textarea${ssrRenderAttr("id", __props.id)}${ssrRenderAttr("type", __props.type)} class="${ssrRenderClass([__props.error ? "border-red-500" : "border-gray-300", "mt-1 block w-full rounded-md shadow-sm border dark:border-gray-700 focus:border-blue-300 focus:ring-2 focus:ring-blue-100 dark:bg-gray-800 dark:focus:border-gray-600 dark:focus:ring-opacity-50 placeholder:text-gray-400 dark:placeholder:text-gray-500"])}">${ssrInterpolate(textValue.value)}</textarea>`);
      if (__props.error) {
        _push(ssrRenderComponent(_sfc_main$2, {
          message: __props.error,
          class: "mt-1"
        }, null, _parent));
      } else {
        _push(`<!---->`);
      }
      _push(`</div>`);
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Shared/TextareaInput.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};
export {
  _sfc_main as _
};
