import { ref, computed, onBeforeMount, mergeProps, unref, withCtx, createVNode, useSSRContext } from "vue";
import { ssrRenderAttrs, ssrRenderClass, ssrInterpolate, ssrRenderAttr, ssrRenderList, ssrRenderStyle, ssrRenderComponent, ssrIncludeBooleanAttr } from "vue/server-renderer";
import { useI18n } from "vue-i18n";
import { loadScript } from "@paypal/paypal-js";
import { loadStripe } from "@stripe/stripe-js";
import { usePage, useForm } from "@inertiajs/vue3";
import { _ as _sfc_main$1 } from "./Attachments-86c51ade.js";
import { StripeElements, StripeElement } from "vue-stripe-js";
import "./DangerButton-933af61d.js";
import "./Modal-4ced3d7d.js";
import "./SecondaryButton-910b0895.js";
const _sfc_main = {
  __name: "Details",
  __ssrInlineRender: true,
  props: { invoice: Object, settings: Object, accept_payment: Boolean },
  emits: ["done"],
  setup(__props, { emit }) {
    const props = __props;
    const card = ref(null);
    const elms = ref(null);
    const error = ref(null);
    const { t } = useI18n({});
    const loading = ref(true);
    const stripe_fees = ref(0);
    const paypal_fees = ref(0);
    const stripePK = ref(null);
    const cardOptions = ref(null);
    const stripeLoaded = ref(false);
    const user = computed(() => usePage().props.auth.user);
    const form = useForm({ paypal: null, stripe: null, gateway: null });
    const impersonate = computed(() => usePage().props.is_impersonating ? usePage().props.user : null);
    onBeforeMount(() => {
      var _a, _b;
      if ((impersonate.value || props.accept_payment || user.value.roles.find((r) => r.name == "customer")) && props.invoice.status != "paid" && props.invoice.status != "canceled") {
        if ((_a = props.settings.stripe) == null ? void 0 : _a.enabled) {
          stripePK.value = props.settings.stripe.publishable_key;
          cardOptions.value = {
            style: {
              base: {
                fontFamily: 'Nunito, ui-sans-serif, system-ui, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto,Arial, "Noto Sans", sans-serif',
                fontSize: "18px"
              }
            },
            value: {
              postalCode: props.invoice.customer.postal_code || null
            }
          };
          const stripePromise = loadStripe(props.settings.stripe.publishable_key);
          stripePromise.then(() => {
            stripe_fees.value = 0;
            stripeLoaded.value = true;
            let amount = Number(props.invoice.grand_total) - Number(props.invoice.paid);
            if (props.settings.stripe.fixed) {
              stripe_fees.value += Number(props.settings.stripe.fixed);
            }
            if (props.invoice.company.country == props.invoice.customer.country && props.settings.stripe.same_country) {
              stripe_fees.value += amount * (Number(props.settings.stripe.same_country) / 100);
            }
            if (props.invoice.company.country != props.invoice.customer.country && props.settings.stripe.other_countries) {
              stripe_fees.value += amount * (Number(props.settings.stripe.other_countries) / 100);
            }
            setTimeout(() => loading.value = false, 1500);
          }).catch((err) => {
            console.error("Failed to load the Stripe JS SDK script", err);
          });
        }
        if ((_b = props.settings.paypal) == null ? void 0 : _b.enabled) {
          loadScript({ "client-id": props.settings.paypal.client_id, currency: props.settings.currency_code || "USD" }).then((paypal) => {
            paypal_fees.value = 0;
            let amount = Number(props.invoice.grand_total) - Number(props.invoice.paid);
            if (props.settings.paypal.fixed) {
              paypal_fees.value += Number(props.settings.paypal.fixed);
            }
            if (props.invoice.company.country == props.invoice.customer.country && props.settings.paypal.same_country) {
              paypal_fees.value += amount * (Number(props.settings.paypal.same_country) / 100);
            }
            if (props.invoice.company.country != props.invoice.customer.country && props.settings.paypal.other_countries) {
              paypal_fees.value += amount * (Number(props.settings.paypal.other_countries) / 100);
            }
            paypal.Buttons({
              style: { layout: "vertical", color: "blue", shape: "rect", label: "paypal" },
              createOrder: (data, actions) => {
                loading.value = true;
                amount = amount + Number(parseFloat(paypal_fees.value).toFixed(props.settings.fraction));
                return actions.order.create({
                  purchase_units: [
                    {
                      reference_id: props.invoice.reference,
                      amount: {
                        value: amount,
                        currency_code: props.settings.currency_code || "USD"
                      }
                    }
                  ]
                });
              },
              onCancel: (data) => {
                loading.value = false;
              },
              onError: (err) => {
                console.log(err);
                error.value = t("PayPal request has been failed, the error is logged to the console.");
                loading.value = false;
              },
              onApprove: (data, actions) => {
                return actions.order.capture().then((details) => {
                  form.paypal = {
                    invoice_id: props.invoice.id,
                    id: details.id,
                    fees: Number(parseFloat(paypal_fees.value).toFixed(props.settings.fraction)),
                    status: details.status,
                    email: details.payer.email_address,
                    payer_id: details.payer.payer_id,
                    amount: details.purchase_units[0].amount,
                    invoice_reference: details.purchase_units[0].reference_id,
                    payment: {
                      id: details.purchase_units[0].payments.captures[0].id,
                      status: details.purchase_units[0].payments.captures[0].status,
                      amount: details.purchase_units[0].payments.captures[0].amount
                    }
                  };
                  form.gateway = "PayPal";
                  form.submit("post", route("paypal.charge", { id: props.invoice.id, hash: props.invoice.hash }), {
                    preserveState: true,
                    preserveScroll: true,
                    onSuccess: () => {
                      emit("done");
                    },
                    onError: (errors) => {
                      error.value = errors.paypal;
                      loading.value = false;
                    }
                  });
                });
              }
            }).render("#paypal-button-container");
            setTimeout(() => loading.value = false, 1e3);
          }).catch((err) => {
            console.error("Failed to load the PayPal JS SDK script", err);
          });
        }
      }
    });
    return (_ctx, _push, _parent, _attrs) => {
      var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j;
      if (__props.invoice) {
        _push(`<div${ssrRenderAttrs(mergeProps({ class: "mt-auto max-w-4xl print:min-w-[700px] mx-auto h-full bg-gray-100 dark:bg-gray-800 -m-6 pt-3 pb-6 rounded-md leading-relaxed print:bg-white print:mt-0 print:pt-0 print:h-full print:overflow-visible" }, _attrs))}><div class="relative bg-white dark:bg-gray-900 p-4 rounded-md overflow-x-auto border dark:border-gray-700 print:border-0 print:shadow-none print:pt-0">`);
        if (__props.settings.invoice_status == "badge") {
          _push(`<div class="absolute left-6 top-6 w-24 h-24 text-center uppercase -rotate-45"><div class="${ssrRenderClass([{
            "bg-blue-200 text-blue-800 border-blue-800": __props.invoice.status == "pending",
            "bg-green-200 text-green-800 border-green-800": __props.invoice.status == "paid",
            "bg-yellow-200 text-yellow-800 border-yellow-800": __props.invoice.status == "overdue",
            "bg-red-200 text-red-800 border-red-800": __props.invoice.status == "canceled"
          }, "-mx-12 print:border-t-2 print:border-b-2"])}">${ssrInterpolate(__props.invoice.status)}</div></div>`);
        } else {
          _push(`<!---->`);
        }
        _push(`<div class="flex justify-end print:flex"><div class="text-left sm:text-right max-w-md print:text-right">`);
        if (__props.invoice.company.logo || _ctx.$page.props.logo) {
          _push(`<div class="h-20 mb-2 flex items-center justify-end">`);
          if (__props.invoice.company.logo) {
            _push(`<img${ssrRenderAttr("src", __props.invoice.company.logo)} alt="" class="h-full max-h-48">`);
          } else if (_ctx.$page.props.logo) {
            _push(`<img${ssrRenderAttr("src", _ctx.$page.props.logo)} alt="" class="h-full max-h-48">`);
          } else {
            _push(`<!---->`);
          }
          _push(`</div>`);
        } else {
          _push(`<!---->`);
        }
        _push(`<h2 class="text-2xl font-extrabold">${ssrInterpolate(__props.invoice.company.name)}</h2>`);
        if (__props.invoice.company.address) {
          _push(`<div>${ssrInterpolate(__props.invoice.company.address || "")} ${ssrInterpolate(__props.invoice.company.city || "")} ${ssrInterpolate(__props.invoice.company.postal_code || "")} ${ssrInterpolate(__props.invoice.company.state || "")} ${ssrInterpolate(__props.invoice.company.country || "")}</div>`);
        } else {
          _push(`<!---->`);
        }
        if (__props.invoice.company.phone) {
          _push(`<div>${ssrInterpolate(__props.invoice.company.phone)}</div>`);
        } else {
          _push(`<!---->`);
        }
        if (__props.invoice.company.email) {
          _push(`<div>${ssrInterpolate(__props.invoice.company.email)}</div>`);
        } else {
          _push(`<!---->`);
        }
        if (__props.invoice.customer.extra_attributes) {
          _push(`<!--[-->`);
          ssrRenderList(Object.keys(__props.invoice.company.extra_attributes), (field) => {
            _push(`<div><span class="text-gray-500 dark:text-gray-400">${ssrInterpolate(unref(t)(field))}:</span> ${ssrInterpolate(__props.invoice.company.extra_attributes[field])}</div>`);
          });
          _push(`<!--]-->`);
        } else {
          _push(`<!---->`);
        }
        _push(`</div></div><div class="mt-4 w-full"><h1 class="text-6xl uppercase font-extrabold">${ssrInterpolate(unref(t)("Invoice"))}</h1></div><div class="mt-6 block sm:flex print:flex gap-x-6 gap-y-2"><div class="w-full min-w-[250px]"><div class="flex gap-1"><div class="w-24 md:w-28 print:w-28">${ssrInterpolate(unref(t)("Invoice No."))}:</div> ${ssrInterpolate(__props.invoice.id)}</div><div class="flex gap-1"><div class="w-24 md:w-28 print:w-28">${ssrInterpolate(unref(t)("Reference"))}:</div> ${ssrInterpolate(__props.invoice.reference)}</div>`);
        if (__props.settings.invoice_status == "text") {
          _push(`<div class="flex gap-1"><div class="w-24 md:w-28 print:w-28">${ssrInterpolate(unref(t)("Status"))}:</div><span class="capitalize">${ssrInterpolate(unref(t)(__props.invoice.status))}</span></div>`);
        } else {
          _push(`<!---->`);
        }
        _push(`</div><div class="w-full min-w-[250px]"><div class="flex gap-1"><div class="w-24 md:w-28 print:w-28">${ssrInterpolate(unref(t)("Date"))}:</div> ${ssrInterpolate(_ctx.$date(__props.invoice.date))}</div><div class="flex gap-1"><div class="w-24 md:w-28 print:w-28">${ssrInterpolate(unref(t)("Created at"))}:</div> ${ssrInterpolate(_ctx.$datetime(__props.invoice.created_at))}</div>`);
        if (__props.invoice.due_date) {
          _push(`<div class="flex gap-1"><div class="w-24 md:w-28 print:w-28">${ssrInterpolate(unref(t)("Due Date"))}:</div> ${ssrInterpolate(_ctx.$date(__props.invoice.due_date))}</div>`);
        } else {
          _push(`<!---->`);
        }
        _push(`</div></div>`);
        if (__props.invoice.extra_attributes) {
          _push(`<div class="grid grid-cols-2 gap-x-6 gap-y-2"><!--[-->`);
          ssrRenderList(Object.keys(__props.invoice.extra_attributes), (field) => {
            _push(`<div class="flex gap-1"><div class="w-24 md:w-28 print:w-28">${ssrInterpolate(unref(t)(field))}:</div> ${ssrInterpolate(__props.invoice.extra_attributes[field])}</div>`);
          });
          _push(`<!--]--></div>`);
        } else {
          _push(`<!---->`);
        }
        _push(`<div class="mt-6 text-left w-full flex items-start"><div class="w-24 md:w-28 print:w-28">${ssrInterpolate(unref(t)("Bill to"))}:</div><div><div>${ssrInterpolate(__props.invoice.customer.name)}</div>`);
        if ((_a = __props.invoice.customer) == null ? void 0 : _a.company) {
          _push(`<div class="font-bold">${ssrInterpolate((_b = __props.invoice.customer) == null ? void 0 : _b.company)}</div>`);
        } else {
          _push(`<!---->`);
        }
        if ((_c = __props.invoice.customer) == null ? void 0 : _c.address) {
          _push(`<div>${ssrInterpolate(((_d = __props.invoice.customer) == null ? void 0 : _d.address) || "")} ${ssrInterpolate(((_e = __props.invoice.customer) == null ? void 0 : _e.city) || "")} ${ssrInterpolate(((_f = __props.invoice.customer) == null ? void 0 : _f.postal_code) || "")} ${ssrInterpolate(((_g = __props.invoice.customer) == null ? void 0 : _g.state) || "")} ${ssrInterpolate(((_h = __props.invoice.customer) == null ? void 0 : _h.country) || "")}</div>`);
        } else {
          _push(`<!---->`);
        }
        if (__props.invoice.customer.phone) {
          _push(`<div>${ssrInterpolate(unref(t)("Tel"))}: ${ssrInterpolate(__props.invoice.customer.phone)}</div>`);
        } else {
          _push(`<!---->`);
        }
        if (__props.invoice.customer.email) {
          _push(`<div>${ssrInterpolate(unref(t)("Email"))}: ${ssrInterpolate(__props.invoice.customer.email)}</div>`);
        } else {
          _push(`<!---->`);
        }
        if (__props.invoice.customer.extra_attributes) {
          _push(`<!--[-->`);
          ssrRenderList(Object.keys(__props.invoice.customer.extra_attributes), (field) => {
            _push(`<div><span class="text-gray-500 dark:text-gray-400">${ssrInterpolate(unref(t)(field))}:</span> ${ssrInterpolate(__props.invoice.customer.extra_attributes[field])}</div>`);
          });
          _push(`<!--]-->`);
        } else {
          _push(`<!---->`);
        }
        _push(`</div></div>`);
        if (__props.invoice.attachment) {
          _push(`<div class="print:hidden mt-4 p-4 w-full border dark:border-gray-700 rounded-md">${ssrInterpolate(unref(t)("This record has an attachment"))}, <a${ssrRenderAttr("href", __props.invoice.attachment)} target="_blank" class="link">${ssrInterpolate(unref(t)("click here to view"))}</a></div>`);
        } else {
          _push(`<!---->`);
        }
        _push(`<div class="overflow-x-auto"><table class="w-full mt-6 mb-4" style="${ssrRenderStyle({ "min-width": "650px" })}"><thead><tr class="border-t-2 border-b-2 dark:border-gray-700"><th class="px-4 print:px-2 py-3 text-left">${ssrInterpolate(unref(t)("Description"))}</th><th class="px-4 print:px-2 py-3 w-28 text-center">${ssrInterpolate(unref(t)("Quantity"))}</th><th class="px-4 print:px-2 py-3 w-28 text-center">${ssrInterpolate(unref(t)("Unit Price"))}</th><th class="px-4 print:px-2 py-3 w-32 text-center">${ssrInterpolate(unref(t)("Total"))}</th></tr></thead><tbody><!--[-->`);
        ssrRenderList(__props.invoice.items, (item, ii) => {
          _push(`<tr class="group avoid"><td class="${ssrRenderClass([{
            "pt-4 pb-2": ii == 0,
            "pb-4 pt-2": ii == __props.invoice.items.length - 1,
            "py-2": ii > 0 && ii + _ctx.i != __props.invoice.items.length
          }, "relative align-top px-4 print:px-2"])}"><span class="${ssrRenderClass([ii == 0 ? "top-4" : "top-2", "absolute mt-1.5 -ml-4 mr-1 text-xs print:hidden"])}">${ssrInterpolate(ii + 1)}.</span> ${ssrInterpolate(item.name)} `);
          if (item.details) {
            _push(`<div>${ssrInterpolate(item.details)}</div>`);
          } else {
            _push(`<!---->`);
          }
          if (item.extra_attributes) {
            _push(`<div class="flex flex-wrap gap-x-4"><!--[-->`);
            ssrRenderList(Object.keys(item.extra_attributes), (field) => {
              _push(`<div><span class="text-gray-500 dark:text-gray-400">${ssrInterpolate(unref(t)(field))}:</span> ${ssrInterpolate(item.extra_attributes[field])}</div>`);
            });
            _push(`<!--]--></div>`);
          } else {
            _push(`<!---->`);
          }
          _push(`</td><td class="${ssrRenderClass([{
            "pt-4 pb-2": ii == 0,
            "pb-4 pt-2": ii == __props.invoice.items.length - 1,
            "py-2": ii > 0 && ii + _ctx.i != __props.invoice.items.length
          }, "align-top px-4 print:px-2 w-28 text-right"])}">${ssrInterpolate(_ctx.$number(item.quantity))}</td><td class="${ssrRenderClass([{
            "pt-4 pb-2": ii == 0,
            "pb-4 pt-2": ii == __props.invoice.items.length - 1,
            "py-2": ii > 0 && ii + _ctx.i != __props.invoice.items.length
          }, "align-top px-4 print:px-2 w-28 text-right"])}">${ssrInterpolate(_ctx.$number(item.unit_price))}</td><td class="${ssrRenderClass([{
            "pt-4 pb-2": ii == 0,
            "pb-4 pt-2": ii == __props.invoice.items.length - 1,
            "py-2": ii > 0 && ii + _ctx.i != __props.invoice.items.length
          }, "align-top px-4 print:px-2 w-32 text-right"])}">${ssrInterpolate(_ctx.$number(item.total))}</td></tr>`);
        });
        _push(`<!--]--></tbody><tfoot><tr class="border-t-2 dark:border-gray-700"><th colspan="3" class="px-4 print:px-2 pt-4 pb-0.5 text-right">${ssrInterpolate(unref(t)("Total"))}</th><th class="px-4 print:px-2 pt-4 pb-0.5 w-32 text-right">${ssrInterpolate(_ctx.$currency(__props.invoice.total))}</th></tr>`);
        if (__props.invoice.product_discount_amount > 0) {
          _push(`<tr class=""><th colspan="3" class="px-4 print:px-2 py-0.5 text-right">${ssrInterpolate(unref(t)("Product Discount"))}</th><th class="px-4 print:px-2 py-0.5 w-32 text-right">${ssrInterpolate(_ctx.$currency(__props.invoice.product_discount_amount))}</th></tr>`);
        } else {
          _push(`<!---->`);
        }
        if (__props.invoice.product_tax_amount > 0) {
          _push(`<tr class=""><th colspan="3" class="px-4 print:px-2 py-0.5 text-right">${ssrInterpolate(unref(t)("Product Tax"))}</th><th class="px-4 print:px-2 py-0.5 w-32 text-right">${ssrInterpolate(_ctx.$currency(__props.invoice.product_tax_amount))}</th></tr>`);
        } else {
          _push(`<!---->`);
        }
        if (__props.invoice.order_discount_amount > 0) {
          _push(`<tr class=""><th colspan="3" class="px-4 print:px-2 py-0.5 text-right">${ssrInterpolate(unref(t)("Order Discount"))}</th><th class="px-4 print:px-2 py-0.5 w-32 text-right">${ssrInterpolate(_ctx.$currency(__props.invoice.order_discount_amount))}</th></tr>`);
        } else {
          _push(`<!---->`);
        }
        if (__props.invoice.order_tax_amount > 0) {
          _push(`<tr class=""><th colspan="3" class="px-4 print:px-2 py-0.5 text-right">${ssrInterpolate(unref(t)("Order Tax"))}</th><th class="px-4 print:px-2 py-0.5 w-32 text-right">${ssrInterpolate(_ctx.$currency(__props.invoice.order_tax_amount))}</th></tr>`);
        } else {
          _push(`<!---->`);
        }
        _push(`<tr class="text-lg"><th colspan="3" class="px-4 print:px-2 py-0.5 text-right">${ssrInterpolate(unref(t)("Grand Total"))}</th><th class="px-4 print:px-2 py-0.5 w-32 text-right">${ssrInterpolate(_ctx.$currency(__props.invoice.grand_total))}</th></tr><tr><th colspan="3" class="px-4 print:px-2 py-0.5 text-right">${ssrInterpolate(unref(t)("Paid"))}</th><th class="px-4 print:px-2 py-0.5 w-32 text-right">${ssrInterpolate(_ctx.$currency(__props.invoice.paid))}</th></tr><tr><th colspan="3" class="px-4 print:px-2 py-0.5 text-right">${ssrInterpolate(unref(t)("Balance"))}</th><th class="px-4 print:px-2 py-0.5 w-32 text-right">${ssrInterpolate(_ctx.$currency(__props.invoice.grand_total - __props.invoice.paid))}</th></tr></tfoot></table></div>`);
        if (__props.invoice.attachments && __props.invoice.attachments.length) {
          _push(`<div class="mt-6 py-4 w-full">`);
          _push(ssrRenderComponent(_sfc_main$1, {
            attachments: __props.invoice.attachments
          }, null, _parent));
          _push(`</div>`);
        } else {
          _push(`<!---->`);
        }
        if (__props.invoice.note) {
          _push(`<div class="mt-6 w-full">${ssrInterpolate(__props.invoice.note)}</div>`);
        } else {
          _push(`<!---->`);
        }
        _push(`</div>`);
        if ((impersonate.value || __props.accept_payment || ((_i = user.value) == null ? void 0 : _i.roles.find((r) => r.name == "customer"))) && __props.invoice.status != "paid" && __props.invoice.status != "canceled" && (__props.settings.paypal.enabled || __props.settings.stripe.enabled)) {
          _push(`<div class="relative mt-12 print:hidden w-full max-w-2xl mx-auto flex flex-col justify-center">`);
          if (error.value) {
            _push(`<div class="rounded-md bg-red-700 px-4 py-2 mb-4"><h3 class="text-sm font-medium text-red-100">${ssrInterpolate(((_j = error.value) == null ? void 0 : _j.message) || error.value)}</h3></div>`);
          } else {
            _push(`<!---->`);
          }
          if (paypal_fees.value > 0 || stripe_fees.value > 0) {
            _push(`<div class="rounded-md bg-blue-700 px-4 py-2 mb-4 flex gap-6 justify-between items-start"><div>`);
            if (stripe_fees.value > 0) {
              _push(`<h3 class="text-sm font-medium text-red-100">${ssrInterpolate(unref(t)("Stripe Gateway Fees"))}: ${ssrInterpolate(_ctx.$number(stripe_fees.value))}</h3>`);
            } else {
              _push(`<!---->`);
            }
            if (stripe_fees.value > 0) {
              _push(`<h3 class="text-sm font-medium text-red-100">${ssrInterpolate(unref(t)("Stripe Total Amount"))}: <strong>${ssrInterpolate(_ctx.$number(Number(__props.invoice.grand_total) - Number(__props.invoice.paid) + Number(stripe_fees.value)))}</strong></h3>`);
            } else {
              _push(`<!---->`);
            }
            _push(`</div><div>`);
            if (paypal_fees.value > 0) {
              _push(`<h3 class="text-sm font-medium text-red-100">${ssrInterpolate(unref(t)("PayPal Gateway Fees"))}: ${ssrInterpolate(_ctx.$number(paypal_fees.value))}</h3>`);
            } else {
              _push(`<!---->`);
            }
            if (paypal_fees.value > 0) {
              _push(`<h3 class="text-sm font-medium text-red-100">${ssrInterpolate(unref(t)("PayPal Total Amount"))}: <strong>${ssrInterpolate(_ctx.$number(Number(__props.invoice.grand_total) - Number(__props.invoice.paid) + Number(paypal_fees.value)))}</strong></h3>`);
            } else {
              _push(`<!---->`);
            }
            _push(`</div></div>`);
          } else {
            _push(`<!---->`);
          }
          if (stripeLoaded.value) {
            _push(`<!--[--><div class="${ssrRenderClass([_ctx.stripeError ? "border-red-700" : "", "bg-white py-3 px-6 mb-4 rounded-md border"])}">`);
            if (stripeLoaded.value) {
              _push(ssrRenderComponent(unref(StripeElements), {
                ref_key: "elms",
                ref: elms,
                "stripe-key": stripePK.value
              }, {
                default: withCtx(({ elements, instance }, _push2, _parent2, _scopeId) => {
                  if (_push2) {
                    _push2(ssrRenderComponent(unref(StripeElement), {
                      ref_key: "card",
                      ref: card,
                      elements,
                      options: cardOptions.value
                    }, null, _parent2, _scopeId));
                  } else {
                    return [
                      createVNode(unref(StripeElement), {
                        ref_key: "card",
                        ref: card,
                        elements,
                        options: cardOptions.value
                      }, null, 8, ["elements", "options"])
                    ];
                  }
                }),
                _: 1
              }, _parent));
            } else {
              _push(`<!---->`);
            }
            _push(`</div><input type="hidden" name="gateway" value="Stripe"><button type="button"${ssrIncludeBooleanAttr(loading.value) ? " disabled" : ""} class="relative mb-6 w-full flex flex-wrap items-center justify-center rounded-md text-base bg-blue-600 px-4 py-3 text-gray-200 hover:bg-blue-700 focus:z-10 focus:border-indigo-500 focus:outline-none focus:ring-1 focus:ring-indigo-500">${ssrInterpolate(unref(t)("Pay with Card"))} <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="ml-2 w-6 h-6"><path stroke-linecap="round" stroke-linejoin="round" d="M2.25 8.25h19.5M2.25 9h19.5m-16.5 5.25h6m-6 2.25h3m-3.75 3h15a2.25 2.25 0 002.25-2.25V6.75A2.25 2.25 0 0019.5 4.5h-15a2.25 2.25 0 00-2.25 2.25v10.5A2.25 2.25 0 004.5 19.5z"></path></svg><span class="ml-1 text-lg font-extrabold">${ssrInterpolate(unref(t)("Stripe"))}</span></button><!--]-->`);
          } else {
            _push(`<!---->`);
          }
          _push(`<div id="paypal-button-container" class="w-full z-10"></div>`);
          if (loading.value) {
            _push(`<div class="absolute inset-0 -mx-6 -mt-6"><div class="relative z-20 bg-gray-500 bg-opacity-50 w-full h-full flex items-center justify-center text-white rounded-md"><svg viewBox="0 0 38 38" xmlns="http://www.w3.org/2000/svg" class="stroke-current h-12 w-12"><g fill="none" fill-rule="evenodd"><g transform="translate(1 1)" stroke-width="2"><circle stroke-opacity=".5" cx="18" cy="18" r="18"></circle><path d="M36 18c0-9.94-8.06-18-18-18"><animateTransform attributeName="transform" type="rotate" from="0 18 18" to="360 18 18" dur="1s" repeatCount="indefinite"></animateTransform></path></g></g></svg></div></div>`);
          } else {
            _push(`<!---->`);
          }
          _push(`</div>`);
        } else {
          _push(`<!---->`);
        }
        _push(`<div class="mt-auto pt-4 w-full text-center text-sm text-gray-500 hidden print:block">${ssrInterpolate(unref(t)("This is computer generated document, no signature required."))}</div></div>`);
      } else {
        _push(`<!---->`);
      }
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Pages/Invoice/Details.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};
export {
  _sfc_main as default
};
