import { ref, resolveComponent, mergeProps, unref, withCtx, createTextVNode, toDisplayString, useSSRContext } from "vue";
import { ssrRenderAttrs, ssrInterpolate, ssrRenderComponent } from "vue/server-renderer";
import { useI18n } from "vue-i18n";
import { _ as _sfc_main$6 } from "./InputError-951c1c36.js";
import { _ as _sfc_main$1 } from "./TextInput-f18b2e86.js";
import "./AppLayout-9028b106.js";
import { _ as _sfc_main$2 } from "./CustomFields-6004e621.js";
import "./FormSection-d5f140fc.js";
import { _ as _sfc_main$3 } from "./TextareaInput-651f7dc6.js";
import { _ as _sfc_main$5 } from "./ActionMessage-cdce5426.js";
import { _ as _sfc_main$4 } from "./SecondaryButton-910b0895.js";
import "../ssr.js";
import "@vue/server-renderer";
import "@inertiajs/vue3";
import "@inertiajs/vue3/server";
import "uuid";
import "./Input-fb927b71.js";
import "./Modal-4ced3d7d.js";
import "lodash/debounce.js";
import "./AutoComplete-974a17ce.js";
import "axios";
import "lodash/throttle.js";
const _sfc_main = {
  __name: "Form",
  __ssrInlineRender: true,
  props: ["edit", "fields", "invoice"],
  emits: ["close", "done"],
  setup(__props, { emit }) {
    const props = __props;
    const form = ref({
      date: (/* @__PURE__ */ new Date()).toISOString().split("T").shift(),
      reference: null,
      amount: null,
      customer_id: null,
      company_id: null,
      invoice_id: null,
      method: null,
      note: null,
      attachment: null,
      extra_attributes: {},
      errors: {}
    });
    const { t } = useI18n({});
    if (props.invoice) {
      form.value.invoice_id = props.invoice.id;
      form.value.company_id = props.invoice.company_id;
      form.value.customer_id = props.invoice.customer_id;
      form.value.amount = Number(props.invoice.grand_total) - Number(props.invoice.paid);
    }
    if (props.edit) {
      if (props.edit.data.extra_attributes && props.fields) {
        Object.keys(props.edit.data.extra_attributes).filter((k) => {
          var _a;
          return !((_a = props.fields) == null ? void 0 : _a.find((f) => f.name == k));
        }).map((k) => delete props.edit.data.extra_attributes[k]);
      }
      form.value.date = props.edit.data.date;
      form.value.reference = props.edit.data.reference;
      form.value.due_date = props.edit.data.due_date;
      form.value.company_id = props.edit.data.company_id;
      form.value.customer_id = props.edit.data.customer_id;
      form.value.invoice_id = props.edit.data.invoice_id;
      form.value.amount = Number(props.edit.data.amount);
      form.value.method = props.edit.data.method;
      form.value.note = props.edit.data.note;
      form.value.attachment = null;
      form.value.extra_attributes = props.edit.data.extra_attributes || {};
    }
    return (_ctx, _push, _parent, _attrs) => {
      const _component_icons = resolveComponent("icons");
      _push(`<form${ssrRenderAttrs(mergeProps({ autocomplete: "off" }, _attrs))}><div class="bg-white dark:bg-gray-900"><div class="flex items-start justify-between print:hidden"><div class="p-6"><h3 class="text-lg font-bold text-gray-900 dark:text-gray-100">${ssrInterpolate(__props.edit ? unref(t)("Edit Payment") : unref(t)("Add New Payment"))}</h3><p class="mt-1 text-sm text-gray-600 dark:text-gray-400">${ssrInterpolate(unref(t)("Please fill the form below to {x}.", {
        x: __props.edit ? unref(t)("update {x}", { x: unref(t)("payment") }) : unref(t)("add {x}", { x: unref(t)("payment") })
      }))}</p></div><div class="m-2 gap-2"><button type="button" class="flex items-center justify-center h-8 w-8 rounded-full text-gray-600 hover:text-gray-800 hover:bg-gray-300 dark:text-gray-400 dark:hover:text-gray-200 dark:hover:bg-gray-700 focus:outline-none">`);
      _push(ssrRenderComponent(_component_icons, {
        name: "cross",
        class: "h-5 w-5"
      }, null, _parent));
      _push(`</button></div></div><div class="px-6 grid grid-cols-1 sm:grid-cols-6 gap-6"><div class="col-span-6 sm:col-span-3">`);
      _push(ssrRenderComponent(_sfc_main$1, {
        id: "date",
        type: "date",
        label: unref(t)("Date"),
        modelValue: form.value.date,
        "onUpdate:modelValue": ($event) => form.value.date = $event,
        error: form.value.errors.date ? form.value.errors.date.join() : null
      }, null, _parent));
      _push(`</div><div class="col-span-6 sm:col-span-3">`);
      _push(ssrRenderComponent(_sfc_main$1, {
        modelValue: form.value.reference,
        "onUpdate:modelValue": ($event) => form.value.reference = $event,
        id: "reference",
        error: form.value.errors.reference ? form.value.errors.reference.join() : null,
        label: unref(t)("Reference")
      }, null, _parent));
      _push(`</div><div class="col-span-6 sm:col-span-3">`);
      _push(ssrRenderComponent(_sfc_main$1, {
        id: "amount",
        type: "number",
        modelValue: form.value.amount,
        "onUpdate:modelValue": ($event) => form.value.amount = $event,
        error: form.value.errors.amount ? form.value.errors.amount.join() : null,
        label: unref(t)("Amount")
      }, null, _parent));
      _push(`</div><div class="col-span-6 sm:col-span-3">`);
      _push(ssrRenderComponent(_sfc_main$1, {
        modelValue: form.value.method,
        "onUpdate:modelValue": ($event) => form.value.method = $event,
        id: "method",
        error: form.value.errors.method ? form.value.errors.method.join() : null,
        label: unref(t)("Method")
      }, null, _parent));
      _push(`</div>`);
      _push(ssrRenderComponent(_sfc_main$2, {
        fields: __props.fields,
        errors: form.value.errors,
        modelValue: form.value.extra_attributes,
        "onUpdate:modelValue": ($event) => form.value.extra_attributes = $event,
        className: "col-span-6 sm:col-span-3"
      }, null, _parent));
      _push(`<div class="col-span-full">`);
      _push(ssrRenderComponent(_sfc_main$3, {
        modelValue: form.value.note,
        "onUpdate:modelValue": ($event) => form.value.note = $event,
        id: "note",
        error: form.value.errors.note,
        label: unref(t)("Note")
      }, null, _parent));
      _push(`</div></div><div class="p-6 pb-6 w-full col-span-full flex items-center justify-between"><div>`);
      _push(ssrRenderComponent(_sfc_main$4, {
        type: "button",
        onClick: ($event) => emit("close")
      }, {
        default: withCtx((_, _push2, _parent2, _scopeId) => {
          if (_push2) {
            _push2(`${ssrInterpolate(unref(t)("Cancel"))}`);
          } else {
            return [
              createTextVNode(toDisplayString(unref(t)("Cancel")), 1)
            ];
          }
        }),
        _: 1
      }, _parent));
      _push(`</div>`);
      _push(ssrRenderComponent(_sfc_main$5, {
        on: form.value.recentlySuccessful,
        class: "mr-3"
      }, {
        default: withCtx((_, _push2, _parent2, _scopeId) => {
          if (_push2) {
            _push2(`${ssrInterpolate(unref(t)("Saved."))}`);
          } else {
            return [
              createTextVNode(toDisplayString(unref(t)("Saved.")), 1)
            ];
          }
        }),
        _: 1
      }, _parent));
      _push(ssrRenderComponent(_sfc_main$6, {
        type: "submit",
        loading: form.value.processing
      }, {
        default: withCtx((_, _push2, _parent2, _scopeId) => {
          if (_push2) {
            _push2(`${ssrInterpolate(unref(t)("Save"))}`);
          } else {
            return [
              createTextVNode(toDisplayString(unref(t)("Save")), 1)
            ];
          }
        }),
        _: 1
      }, _parent));
      _push(`</div></div></form>`);
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Pages/Payment/Form.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};
export {
  _sfc_main as default
};
