import { ref, onMounted, computed, watch, resolveComponent, mergeProps, unref, withCtx, createTextVNode, toDisplayString, createVNode, openBlock, createBlock, createCommentVNode, Fragment, renderList, useSSRContext } from "vue";
import { ssrRenderComponent, ssrInterpolate, ssrRenderList, ssrRenderClass } from "vue/server-renderer";
import axios from "axios";
import { useI18n } from "vue-i18n";
import debounce from "lodash/debounce.js";
import { useForm, usePage } from "@inertiajs/vue3";
import { _ as _sfc_main$3 } from "./InputError-951c1c36.js";
import { _ as _sfc_main$b } from "./Modal-4ced3d7d.js";
import { _ as _sfc_main$a } from "./ActionMessage-cdce5426.js";
import { _ as _sfc_main$6 } from "./FileInput-d99860f3.js";
import { _ as _sfc_main$5 } from "./TextInput-f18b2e86.js";
import { _ as _sfc_main$1 } from "./AppLayout-9028b106.js";
import { _ as _sfc_main$9 } from "./Attachments-86c51ade.js";
import _sfc_main$c from "./Create-99a6cc6f.js";
import { _ as _sfc_main$8 } from "./CustomFields-6004e621.js";
import { _ as _sfc_main$4 } from "./AutoComplete-974a17ce.js";
import { _ as _sfc_main$2 } from "./FormSection-d5f140fc.js";
import { _ as _sfc_main$7 } from "./TextareaInput-651f7dc6.js";
import { n as number_format, c as calculateDiscount, a as calculateTax } from "./helpers-5a7f56c7.js";
import "../ssr.js";
import "@vue/server-renderer";
import "@inertiajs/vue3/server";
import "uuid";
import "./Input-fb927b71.js";
import "./DangerButton-933af61d.js";
import "./SecondaryButton-910b0895.js";
import "lodash/throttle.js";
const _sfc_main = {
  __name: "Form",
  __ssrInlineRender: true,
  props: ["edit", "companies", "tax_rates", "note", "fields", "customer_fields", "item_fields"],
  setup(__props) {
    const props = __props;
    const show = ref(false);
    const added = ref(false);
    const initial_rows = ref(2);
    const showNotes = ref(false);
    const showModal = ref(false);
    const searchIndex = ref(null);
    const item = {
      name: "",
      quantity: 1,
      price: null,
      taxes: [],
      tax_method: "exclusive",
      show_details: false,
      details: "",
      discount: null,
      discount_amount: null,
      tax_amount: null,
      total: null,
      discount_amount: 0,
      tax_amount: 0,
      net_price: 0,
      unit_price: 0,
      extra_attributes: {}
    };
    const notes = ref([]);
    const results = ref([]);
    const company = ref(null);
    const customer = ref(null);
    const addResult = ref(null);
    const searching = ref(false);
    const items = ref([]);
    const form = useForm({
      company_id: null,
      customer_id: null,
      date: (/* @__PURE__ */ new Date()).toISOString().split("T").shift(),
      reference: null,
      discount: null,
      taxes: [],
      expiry_date: null,
      shipping: null,
      status: "pending",
      attachment: null,
      items: [],
      attachments: null,
      note: null,
      tax_method: "exclusive",
      extra_attributes: {}
    });
    if (props.edit) {
      if (props.edit.data.extra_attributes && props.fields) {
        Object.keys(props.edit.data.extra_attributes).filter((k) => {
          var _a;
          return !((_a = props.fields) == null ? void 0 : _a.find((f) => f.name == k));
        }).map((k) => delete props.edit.data.extra_attributes[k]);
      }
      company.value = { value: props.edit.data.company.id, label: props.edit.data.company.name };
      customer.value = { value: props.edit.data.customer.id, label: props.edit.data.customer.name };
      form.date = props.edit.data.date;
      form.expiry_date = props.edit.data.expiry_date;
      form.reference = props.edit.data.reference;
      form.shipping = props.edit.data.shipping;
      form.company_id = props.edit.data.company_id;
      form.customer_id = props.edit.data.customer_id;
      form.discount = props.edit.data.order_discount;
      form.taxes = props.edit.data.taxes.map((t2) => t2.id);
      form.status = props.edit.data.status;
      form.items = props.edit.data.items.map((i2) => {
        i2.price = Number(i2.price);
        i2.quantity = Number(i2.quantity);
        i2.taxes = i2.taxes.map((t2) => t2.id);
        i2.show_details = i2.details ? true : false;
        return i2;
      });
      items.value = form.items;
      form.note = props.edit.data.note;
      form.attachments = [];
      form.extra_attributes = props.edit.data.extra_attributes || {};
    }
    const { t } = useI18n({});
    if (props.note) {
      form.note = props.note.details;
    }
    onMounted(() => {
      initial_rows.value = usePage().props.settings.initial_rows;
      if (initial_rows.value) {
        for (let index = items.value.length; index < initial_rows.value; index++) {
          items.value.push({ ...item });
        }
      }
    });
    const totals = computed(() => {
      let data = { total: 0, discount_amount: 0, tax_amount: 0, grand_total: 0 };
      for (const i2 of form.items) {
        data.total += Number(number_format(Number(i2.quantity) * Number(i2.unit_price)));
        data.discount_amount += Number(number_format(Number(i2.quantity) * Number(i2.discount_amount)));
        data.tax_amount += Number(number_format(Number(i2.quantity) * Number(i2.tax_amount)));
        data.grand_total += Number(number_format(Number(i2.quantity) * Number(i2.unit_price)));
      }
      form.discount_amount = 0;
      if (form.discount) {
        form.discount_amount = calculateDiscount(data.total, form.discount);
        data.grand_total -= form.discount_amount;
      }
      if (form.taxes && form.taxes.length) {
        let taxes = props.tax_rates.filter((t2) => form.taxes.includes(t2.id));
        form.tax_amount = calculateTax(data.grand_total, taxes, form.tax_method);
        if (form.tax_method == "exclusive") {
          data.grand_total += form.tax_amount;
        }
      }
      data.grand_total += form.shipping ? Number(form.shipping) : 0;
      return { ...data };
    });
    watch(
      items,
      debounce((newItems) => {
        form.items = newItems.map((i2) => {
          if (i2.quantity && i2.price) {
            let price = i2.price;
            if (i2.discount) {
              i2.discount_amount = calculateDiscount(price, i2.discount);
              price = price - i2.discount_amount;
            }
            if (i2.taxes && i2.taxes.length) {
              let taxes = props.tax_rates.filter((t2) => i2.taxes.includes(t2.id));
              i2.tax_amount = calculateTax(price, taxes, i2.tax_method);
            }
            if (i2.tax_method == "inclusive") {
              i2.net_price = Number(price) - Number(i2.tax_amount);
              i2.unit_price = Number(price);
            } else {
              i2.net_price = Number(price);
              i2.unit_price = Number(number_format(Number(price) + Number(i2.tax_amount)));
            }
          }
          i2.total = Number(number_format(i2.unit_price * i2.quantity));
          return i2;
        });
      }, 500),
      { deep: true }
    );
    const searchProduct = debounce((e, i2) => {
      searchIndex.value = i2;
      axios.post(route("search.products"), { search: e.target.value }).then((res) => {
        show.value = true;
        results.value = res.data;
        if (results.value.length == 1) {
          selectItem(results.value[0], i2);
        }
      }).finally(() => searching.value = false);
    }, 250);
    const searchNotes = debounce((e) => {
      showNotes.value = true;
      axios.post(route("search.notes"), { search: e.target.value }).then((res) => {
        notes.value = res.data;
        if (notes.value.length == 1) {
          selectItem(notes.value[0], i);
        }
      }).finally(() => searching.value = false);
    }, 250);
    const selectItem = (item2, index) => {
      let items2 = form.items.map((i2, ii) => {
        if (ii == index) {
          i2.code = item2.code;
          i2.name = item2.label;
          i2.price = item2.price;
          i2.details = item2.details;
          i2.product_id = item2.value;
          i2.tax_method = item2.tax_method;
          i2.taxes = item2.taxes.map((t2) => t2.id);
          i2.show_details = item2.details ? true : false;
        }
        return i2;
      });
      items2.value = [...items2];
      form.items = items2.value;
      show.value = false;
    };
    const itemDiscountFocused = (r) => {
      if (r + 1 == items.value.length) {
        addOrderItem();
      }
    };
    const hideResult = () => {
      setTimeout(() => show.value = false, 150);
    };
    const addCustomer = () => {
      showModal.value = true;
    };
    const selectCustomer = (nc) => {
      addResult.value = { value: { value: nc.id, label: nc.name } };
      showModal.value = false;
    };
    const addOrderItem = () => {
      items.value.push({ ...item });
      added.value = true;
      setTimeout(() => added.value = false, 1e3);
    };
    const removeOrderItem = (v) => {
      if (initial_rows.value < items.value.length) {
        items.value = items.value.filter((i2, ii) => ii != v);
      }
    };
    function submit() {
      form.errors = {};
      let method = props.edit ? "put" : "post";
      let url = props.edit ? route("quotations.update", props.edit.data.id) : route("quotations.store");
      form.transform((data) => {
        var _a;
        data._method = method;
        data.items = [...items.value];
        data.customer_id = ((_a = customer.value) == null ? void 0 : _a.value) || customer.value;
        data.extra_attributes = { ...data.extra_attributes };
        return data;
      });
      form.post(url, {
        preserveScroll: true,
        onSuccess: () => {
          props.edit ? "" : form.reset();
        },
        onError: () => {
          window.scroll(0, 0);
          if (form.errors.name) {
            document.getElementById("name").focus();
          }
          if (form.errors.company) {
            document.getElementById("company").focus();
          }
          if (form.errors.email) {
            document.getElementById("email").focus();
          }
          if (form.errors.phone) {
            document.getElementById("phone").focus();
          }
        }
      });
    }
    return (_ctx, _push, _parent, _attrs) => {
      const _component_icons = resolveComponent("icons");
      _push(ssrRenderComponent(_sfc_main$1, mergeProps({
        title: props.edit ? unref(t)("Edit Quotation") : unref(t)("Add New Quotation")
      }, _attrs), {
        default: withCtx((_, _push2, _parent2, _scopeId) => {
          if (_push2) {
            _push2(`<div class="max-w-7xl mx-auto py-10 sm:px-6 lg:px-8"${_scopeId}>`);
            _push2(ssrRenderComponent(_sfc_main$2, {
              onSubmitted: submit,
              autocomplete: "off"
            }, {
              title: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(`${ssrInterpolate(props.edit ? unref(t)("Edit Quotation") : unref(t)("Add New Quotation"))}`);
                } else {
                  return [
                    createTextVNode(toDisplayString(props.edit ? unref(t)("Edit Quotation") : unref(t)("Add New Quotation")), 1)
                  ];
                }
              }),
              description: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(`${ssrInterpolate(unref(t)("Please fill the form below to {x}.", {
                    x: props.edit ? unref(t)("update {x}", { x: unref(t)("quotation") }) : unref(t)("add {x}", { x: unref(t)("quotation") })
                  }))} <div${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$3, {
                    href: _ctx.route("quotations.index"),
                    class: "mt-4"
                  }, {
                    default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                      if (_push4) {
                        _push4(`${ssrInterpolate(unref(t)("List Quotations"))}`);
                      } else {
                        return [
                          createTextVNode(toDisplayString(unref(t)("List Quotations")), 1)
                        ];
                      }
                    }),
                    _: 1
                  }, _parent3, _scopeId2));
                  _push3(`</div>`);
                } else {
                  return [
                    createTextVNode(toDisplayString(unref(t)("Please fill the form below to {x}.", {
                      x: props.edit ? unref(t)("update {x}", { x: unref(t)("quotation") }) : unref(t)("add {x}", { x: unref(t)("quotation") })
                    })) + " ", 1),
                    createVNode("div", null, [
                      createVNode(_sfc_main$3, {
                        href: _ctx.route("quotations.index"),
                        class: "mt-4"
                      }, {
                        default: withCtx(() => [
                          createTextVNode(toDisplayString(unref(t)("List Quotations")), 1)
                        ]),
                        _: 1
                      }, 8, ["href"])
                    ])
                  ];
                }
              }),
              form: withCtx((_2, _push3, _parent3, _scopeId2) => {
                var _a, _b, _c, _d;
                if (_push3) {
                  _push3(`<div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$4, {
                    json: true,
                    id: "company_id",
                    searchable: true,
                    label: unref(t)("Company"),
                    suggestions: __props.companies,
                    modelValue: unref(form).company_id,
                    "onUpdate:modelValue": ($event) => unref(form).company_id = $event,
                    error: unref(form).errors.company_id
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$4, {
                    json: true,
                    id: "customer_id",
                    modelValue: customer.value,
                    "onUpdate:modelValue": ($event) => customer.value = $event,
                    searchable: true,
                    label: unref(t)("Customer"),
                    addResult: addResult.value,
                    "action-text": unref(t)("Create"),
                    selected: (_a = customer.value) == null ? void 0 : _a.value,
                    action: () => addCustomer(),
                    error: unref(form).errors.customer_id,
                    suggestions: _ctx.route("search.customers")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$5, {
                    type: "date",
                    modelValue: unref(form).date,
                    "onUpdate:modelValue": ($event) => unref(form).date = $event,
                    id: "date",
                    error: unref(form).errors.date,
                    label: unref(t)("Date")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$5, {
                    modelValue: unref(form).reference,
                    "onUpdate:modelValue": ($event) => unref(form).reference = $event,
                    id: "reference",
                    error: unref(form).errors.reference,
                    label: unref(t)("Reference")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$4, {
                    id: "status",
                    json: true,
                    searchable: false,
                    label: unref(t)("Status"),
                    modelValue: unref(form).status,
                    "onUpdate:modelValue": ($event) => unref(form).status = $event,
                    error: unref(form).errors.status,
                    suggestions: [
                      { value: "pending", label: "Pending" },
                      { value: "sent", label: "Sent" },
                      { value: "confirmed", label: "Confirmed" },
                      { value: "canceled", label: "Canceled" }
                    ]
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$6, {
                    multiple: "",
                    modelValue: unref(form).attachments,
                    "onUpdate:modelValue": ($event) => unref(form).attachments = $event,
                    id: "attachments",
                    error: unref(form).errors.attachments,
                    label: unref(t)("Attachments")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-full -mx-6"${_scopeId2}>`);
                  if (items.value && items.value.length) {
                    _push3(`<div class="flex flex-col"${_scopeId2}><div class="flex items-center justify-between mx-6 mb-3"${_scopeId2}><h2 class="text-lg font-extrabold"${_scopeId2}>${ssrInterpolate(unref(t)("Order Items"))}</h2><div class="flex items-center"${_scopeId2}>`);
                    if (added.value) {
                      _push3(`<span class="text-gray-500 dark:text-gray-400 mr-2"${_scopeId2}>${ssrInterpolate(unref(t)("Added"))}</span>`);
                    } else {
                      _push3(`<!---->`);
                    }
                    _push3(`<button type="button" class="py-1 px-2 border dark:border-gray-700 rounded-md hover:bg-gray-200 dark:hover:bg-gray-800"${_scopeId2}>${ssrInterpolate(unref(t)("Add Row"))}</button></div></div><div class="w-full flex flex-col divide-y dark:divide-gray-700 border-y dark:border-gray-700"${_scopeId2}><!--[-->`);
                    ssrRenderList(items.value, (i2, r) => {
                      _push3(`<div class="odd:bg-gray-50 dark:odd:bg-black/20 even:bg-neutral-50 dark:even:bg-black/50 w-full flex flex-col items-start gap-2 p-6"${_scopeId2}><div class="flex items-start gap-2"${_scopeId2}><div class="text-sm"${_scopeId2}>${ssrInterpolate(r + 1)}.</div><div class="w-full flex flex-col gap-2"${_scopeId2}><div class="text-sm font-medium flex gap-2 items-center justify-between"${_scopeId2}><div class="flex-1 relative"${_scopeId2}><div class="relative"${_scopeId2}>`);
                      _push3(ssrRenderComponent(_sfc_main$5, {
                        modelValue: i2.name,
                        "onUpdate:modelValue": ($event) => i2.name = $event,
                        onBlur: hideResult,
                        label: "Item Description",
                        onInput: (e) => unref(searchProduct)(e, r),
                        class: "text-gray-700 dark:text-gray-300"
                      }, null, _parent3, _scopeId2));
                      if (show.value && results.value && results.value.length && searchIndex.value == r) {
                        _push3(`<ul class="absolute top-full w-full z-20 max-h-64 scroll-py-2 overflow-y-auto p-2 mt-1 bg-white dark:bg-gray-800 border dark:border-gray-700 rounded-md"${_scopeId2}><!--[-->`);
                        ssrRenderList(results.value, (sitem, si) => {
                          _push3(`<li${_scopeId2}><button type="button" class="block text-left w-full select-none rounded-md px-3 py-2 hover:bg-blue-500 hover:text-white"${_scopeId2}><span class="ml-3 flex-auto truncate"${_scopeId2}>${ssrInterpolate(sitem.label)}</span></button></li>`);
                        });
                        _push3(`<!--]--></ul>`);
                      } else {
                        _push3(`<!---->`);
                      }
                      _push3(`</div>`);
                      if (_ctx.$page.props.errors["items." + r + ".name"]) {
                        _push3(`<div class="text-red-600 pt-1 rounded-md"${_scopeId2}>${ssrInterpolate(_ctx.$page.props.errors["items." + r + ".name"].replace("items." + r + ".", ""))}</div>`);
                      } else {
                        _push3(`<!---->`);
                      }
                      _push3(`<div class="absolute top-6 right-0 flex"${_scopeId2}><button type="button" class="${ssrRenderClass([i2.show_details ? "text-blue-500 dark:text-blue-400" : "text-gray-500 dark:text-gray-400", "inline-flex items-center rounded mt-px p-2 font-sans text-sm font-medium focus:ring-0"])}"${_scopeId2}><svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-6 h-6"${_scopeId2}><path stroke-linecap="round" stroke-linejoin="round" d="M7.5 8.25h9m-9 3H12m-9.75 1.51c0 1.6 1.123 2.994 2.707 3.227 1.129.166 2.27.293 3.423.379.35.026.67.21.865.501L12 21l2.755-4.133a1.14 1.14 0 01.865-.501 48.172 48.172 0 003.423-.379c1.584-.233 2.707-1.626 2.707-3.228V6.741c0-1.602-1.123-2.995-2.707-3.228A48.394 48.394 0 0012 3c-2.392 0-4.744.175-7.043.513C3.373 3.746 2.25 5.14 2.25 6.741v6.018z"${_scopeId2}></path></svg></button></div>`);
                      if (i2.show_details) {
                        _push3(ssrRenderComponent(_sfc_main$7, {
                          modelValue: i2.details,
                          "onUpdate:modelValue": ($event) => i2.details = $event,
                          class: "mt-2 text-gray-700 dark:text-gray-300"
                        }, null, _parent3, _scopeId2));
                      } else {
                        _push3(`<!---->`);
                      }
                      if (initial_rows.value < r + 1) {
                        _push3(`<button type="button" class="absolute right-0 top-0 text-sm text-red-500 rounded-md flex items-center focus:ring-0"${_scopeId2}>${ssrInterpolate(unref(t)("Remove"))}</button>`);
                      } else {
                        _push3(`<!---->`);
                      }
                      _push3(`</div></div><div class="grid grid-cols-2 xl:grid-cols-6 text-sm gap-x-4 gap-y-2"${_scopeId2}><div${_scopeId2}>`);
                      _push3(ssrRenderComponent(_sfc_main$5, {
                        type: "number",
                        selectOnFocus: "",
                        label: "Quantity",
                        modelValue: i2.quantity,
                        "onUpdate:modelValue": ($event) => i2.quantity = $event,
                        class: "text-gray-700 dark:text-gray-300"
                      }, null, _parent3, _scopeId2));
                      _push3(`</div><div${_scopeId2}>`);
                      _push3(ssrRenderComponent(_sfc_main$5, {
                        type: "number",
                        modelValue: i2.price,
                        "onUpdate:modelValue": ($event) => i2.price = $event,
                        label: "Price",
                        class: "text-gray-700 dark:text-gray-300"
                      }, null, _parent3, _scopeId2));
                      _push3(`</div><div class="col-span-2"${_scopeId2}>`);
                      _push3(ssrRenderComponent(_sfc_main$4, {
                        json: true,
                        id: "tax_rates",
                        multiple: true,
                        modelValue: i2.taxes,
                        "onUpdate:modelValue": ($event) => i2.taxes = $event,
                        searchable: false,
                        label: unref(t)("Tax Rates"),
                        suggestions: __props.tax_rates
                      }, null, _parent3, _scopeId2));
                      _push3(`</div><div${_scopeId2}>`);
                      _push3(ssrRenderComponent(_sfc_main$4, {
                        id: "tax_method",
                        searchable: false,
                        modelValue: i2.tax_method,
                        "onUpdate:modelValue": ($event) => i2.tax_method = $event,
                        label: unref(t)("Tax Method"),
                        suggestions: [
                          { value: "inclusive", label: unref(t)("inclusive") },
                          { value: "exclusive", label: unref(t)("exclusive") }
                        ]
                      }, null, _parent3, _scopeId2));
                      _push3(`</div><div${_scopeId2}>`);
                      _push3(ssrRenderComponent(_sfc_main$5, {
                        label: "Discount",
                        modelValue: i2.discount,
                        "onUpdate:modelValue": ($event) => i2.discount = $event,
                        onFocus: ($event) => itemDiscountFocused(r),
                        pattern: "[0-9]+(\\.[0-9]{1,2})?%?",
                        class: "text-gray-700 dark:text-gray-300",
                        title: unref(t)("please type number with or without percentage sign.")
                      }, null, _parent3, _scopeId2));
                      _push3(`</div></div><div class="text-sm -mt-4"${_scopeId2}>`);
                      if (_ctx.$page.props.errors["items." + r + ".quantity"]) {
                        _push3(`<div class="text-red-600 pt-1 rounded-md"${_scopeId2}>${ssrInterpolate(_ctx.$page.props.errors["items." + r + ".quantity"].replace("items." + r + ".", ""))}</div>`);
                      } else {
                        _push3(`<!---->`);
                      }
                      if (_ctx.$page.props.errors["items." + r + ".price"]) {
                        _push3(`<div class="text-red-600 pt-1 rounded-md"${_scopeId2}>${ssrInterpolate(_ctx.$page.props.errors["items." + r + ".price"].replace("items." + r + ".", ""))}</div>`);
                      } else {
                        _push3(`<!---->`);
                      }
                      _push3(`</div>`);
                      if (__props.item_fields && __props.item_fields.length) {
                        _push3(`<!--[--><div class="grid grid-cols-2 xl:grid-cols-3 text-sm gap-x-4 gap-y-2"${_scopeId2}>`);
                        _push3(ssrRenderComponent(_sfc_main$8, {
                          id: "item",
                          fields: __props.item_fields,
                          modelValue: i2.extra_attributes,
                          "onUpdate:modelValue": ($event) => i2.extra_attributes = $event
                        }, null, _parent3, _scopeId2));
                        _push3(`</div><div class="-mt-1 text-red-600 text-sm"${_scopeId2}><!--[-->`);
                        ssrRenderList(__props.item_fields, (field) => {
                          _push3(`<div${_scopeId2}>${ssrInterpolate(_ctx.$page.props.errors["items." + r + ".extra_attributes." + field.name])}</div>`);
                        });
                        _push3(`<!--]--></div><!--]-->`);
                      } else {
                        _push3(`<!---->`);
                      }
                      _push3(`</div></div></div>`);
                    });
                    _push3(`<!--]--><div class="odd:bg-gray-50 dark:odd:bg-black/20 even:bg-neutral-50 dark:even:bg-black/50 w-full flex items-start justify-end gap-y-2 gap-x-8 p-6"${_scopeId2}><div${_scopeId2}><div class="text-right h-6"${_scopeId2}>Total :</div>`);
                    if (totals.value.discount_amount) {
                      _push3(`<div class="text-right h-6"${_scopeId2}>Products Discount :</div>`);
                    } else {
                      _push3(`<!---->`);
                    }
                    if (totals.value.tax_amount) {
                      _push3(`<div class="text-right h-6"${_scopeId2}>Products Tax :</div>`);
                    } else {
                      _push3(`<!---->`);
                    }
                    if (unref(form).discount_amount) {
                      _push3(`<div class="text-right h-6"${_scopeId2}>Order Discount :</div>`);
                    } else {
                      _push3(`<!---->`);
                    }
                    if (unref(form).tax_amount) {
                      _push3(`<div class="text-right h-6"${_scopeId2}>Order Tax :</div>`);
                    } else {
                      _push3(`<!---->`);
                    }
                    if (unref(form).shipping) {
                      _push3(`<div class="text-right h-6"${_scopeId2}>Shipping :</div>`);
                    } else {
                      _push3(`<!---->`);
                    }
                    if (totals.value.grand_total && totals.value.grand_total != totals.value.total) {
                      _push3(`<div class="text-right h-6"${_scopeId2}>Grand Total :</div>`);
                    } else {
                      _push3(`<!---->`);
                    }
                    _push3(`</div><div${_scopeId2}><div class="text-right h-6 font-bold"${_scopeId2}>${ssrInterpolate(_ctx.$number(totals.value.total))}</div>`);
                    if (totals.value.discount_amount) {
                      _push3(`<div class="text-right h-6 font-bold"${_scopeId2}>${ssrInterpolate(_ctx.$number(totals.value.discount_amount))}</div>`);
                    } else {
                      _push3(`<!---->`);
                    }
                    if (totals.value.tax_amount) {
                      _push3(`<div class="text-right h-6 font-bold"${_scopeId2}>${ssrInterpolate(_ctx.$number(totals.value.tax_amount))}</div>`);
                    } else {
                      _push3(`<!---->`);
                    }
                    if (unref(form).discount_amount) {
                      _push3(`<div class="text-right h-6 font-bold"${_scopeId2}>${ssrInterpolate(_ctx.$number(unref(form).discount_amount))}</div>`);
                    } else {
                      _push3(`<!---->`);
                    }
                    if (unref(form).tax_amount) {
                      _push3(`<div class="text-right h-6 font-bold"${_scopeId2}>${ssrInterpolate(_ctx.$number(unref(form).tax_amount))}</div>`);
                    } else {
                      _push3(`<!---->`);
                    }
                    if (unref(form).shipping) {
                      _push3(`<div class="text-right h-6"${_scopeId2}>${ssrInterpolate(_ctx.$number(unref(form).shipping))}</div>`);
                    } else {
                      _push3(`<!---->`);
                    }
                    if (totals.value.grand_total && totals.value.grand_total != totals.value.total) {
                      _push3(`<div class="text-right h-6 font-bold"${_scopeId2}>${ssrInterpolate(_ctx.$number(totals.value.grand_total))}</div>`);
                    } else {
                      _push3(`<!---->`);
                    }
                    _push3(`</div></div></div></div>`);
                  } else {
                    _push3(`<!---->`);
                  }
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$4, {
                    json: true,
                    multiple: true,
                    searchable: false,
                    id: "order_tax_rates",
                    modelValue: unref(form).taxes,
                    "onUpdate:modelValue": ($event) => unref(form).taxes = $event,
                    label: unref(t)("Tax Rates"),
                    suggestions: __props.tax_rates,
                    error: unref(form).errors.taxes
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3 flex items-start gap-6"${_scopeId2}><div class="w-1/2"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$4, {
                    searchable: false,
                    id: "form_tax_method",
                    label: unref(t)("Tax Method"),
                    modelValue: unref(form).tax_method,
                    "onUpdate:modelValue": ($event) => unref(form).tax_method = $event,
                    suggestions: [
                      { value: "inclusive", label: unref(t)("inclusive") },
                      { value: "exclusive", label: unref(t)("exclusive") }
                    ]
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="w-1/2"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$5, {
                    id: "discount",
                    label: unref(t)("Discount"),
                    modelValue: unref(form).discount,
                    "onUpdate:modelValue": ($event) => unref(form).discount = $event,
                    error: unref(form).errors.discount,
                    pattern: "[0-9]+(\\.[0-9]{1,2})?%?",
                    title: unref(t)("please type number with or without percentage sign.")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div></div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$5, {
                    type: "date",
                    modelValue: unref(form).expiry_date,
                    "onUpdate:modelValue": ($event) => unref(form).expiry_date = $event,
                    id: "expiry_date",
                    error: unref(form).errors.expiry_date,
                    label: unref(t)("Expiry Date")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div><div class="col-span-6 sm:col-span-3"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$5, {
                    type: "number",
                    modelValue: unref(form).shipping,
                    "onUpdate:modelValue": ($event) => unref(form).shipping = $event,
                    id: "shipping",
                    error: unref(form).errors.shipping,
                    label: unref(t)("Shipping")
                  }, null, _parent3, _scopeId2));
                  _push3(`</div>`);
                  _push3(ssrRenderComponent(_sfc_main$8, {
                    fields: __props.fields,
                    errors: unref(form).errors,
                    modelValue: unref(form).extra_attributes,
                    "onUpdate:modelValue": ($event) => unref(form).extra_attributes = $event,
                    className: "col-span-6 sm:col-span-3"
                  }, null, _parent3, _scopeId2));
                  _push3(`<div class="col-span-full"${_scopeId2}><div class="relative"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$7, {
                    onInput: unref(searchNotes),
                    modelValue: unref(form).note,
                    "onUpdate:modelValue": ($event) => unref(form).note = $event,
                    id: "note",
                    error: unref(form).errors.note,
                    label: unref(t)("Note")
                  }, null, _parent3, _scopeId2));
                  if (showNotes.value && notes.value && notes.value.length) {
                    _push3(`<ul class="absolute top-full w-full z-20 max-h-64 scroll-py-2 overflow-y-auto p-2 mt-1 bg-white dark:bg-gray-800 border dark:border-gray-700 rounded-md"${_scopeId2}><!--[-->`);
                    ssrRenderList(notes.value, (n, ni) => {
                      _push3(`<li${_scopeId2}><button type="button" class="block text-left w-full select-none rounded-md px-3 py-2 hover:bg-blue-500 hover:text-white"${_scopeId2}><span class="ml-3 flex-auto truncate"${_scopeId2}>${ssrInterpolate(n.label)}</span></button></li>`);
                    });
                    _push3(`<!--]--></ul>`);
                  } else {
                    _push3(`<!---->`);
                  }
                  _push3(`</div></div><div class="col-span-full"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$9, {
                    attachments: __props.edit ? (_b = __props.edit.data) == null ? void 0 : _b.attachments : []
                  }, null, _parent3, _scopeId2));
                  _push3(`</div>`);
                } else {
                  return [
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$4, {
                        json: true,
                        id: "company_id",
                        searchable: true,
                        label: unref(t)("Company"),
                        suggestions: __props.companies,
                        modelValue: unref(form).company_id,
                        "onUpdate:modelValue": ($event) => unref(form).company_id = $event,
                        error: unref(form).errors.company_id
                      }, null, 8, ["label", "suggestions", "modelValue", "onUpdate:modelValue", "error"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$4, {
                        json: true,
                        id: "customer_id",
                        modelValue: customer.value,
                        "onUpdate:modelValue": ($event) => customer.value = $event,
                        searchable: true,
                        label: unref(t)("Customer"),
                        addResult: addResult.value,
                        "action-text": unref(t)("Create"),
                        selected: (_c = customer.value) == null ? void 0 : _c.value,
                        action: () => addCustomer(),
                        error: unref(form).errors.customer_id,
                        suggestions: _ctx.route("search.customers")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "label", "addResult", "action-text", "selected", "action", "error", "suggestions"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$5, {
                        type: "date",
                        modelValue: unref(form).date,
                        "onUpdate:modelValue": ($event) => unref(form).date = $event,
                        id: "date",
                        error: unref(form).errors.date,
                        label: unref(t)("Date")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$5, {
                        modelValue: unref(form).reference,
                        "onUpdate:modelValue": ($event) => unref(form).reference = $event,
                        id: "reference",
                        error: unref(form).errors.reference,
                        label: unref(t)("Reference")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$4, {
                        id: "status",
                        json: true,
                        searchable: false,
                        label: unref(t)("Status"),
                        modelValue: unref(form).status,
                        "onUpdate:modelValue": ($event) => unref(form).status = $event,
                        error: unref(form).errors.status,
                        suggestions: [
                          { value: "pending", label: "Pending" },
                          { value: "sent", label: "Sent" },
                          { value: "confirmed", label: "Confirmed" },
                          { value: "canceled", label: "Canceled" }
                        ]
                      }, null, 8, ["label", "modelValue", "onUpdate:modelValue", "error"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$6, {
                        multiple: "",
                        modelValue: unref(form).attachments,
                        "onUpdate:modelValue": ($event) => unref(form).attachments = $event,
                        id: "attachments",
                        error: unref(form).errors.attachments,
                        label: unref(t)("Attachments")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-full -mx-6" }, [
                      items.value && items.value.length ? (openBlock(), createBlock("div", {
                        key: 0,
                        class: "flex flex-col"
                      }, [
                        createVNode("div", { class: "flex items-center justify-between mx-6 mb-3" }, [
                          createVNode("h2", { class: "text-lg font-extrabold" }, toDisplayString(unref(t)("Order Items")), 1),
                          createVNode("div", { class: "flex items-center" }, [
                            added.value ? (openBlock(), createBlock("span", {
                              key: 0,
                              class: "text-gray-500 dark:text-gray-400 mr-2"
                            }, toDisplayString(unref(t)("Added")), 1)) : createCommentVNode("", true),
                            createVNode("button", {
                              type: "button",
                              onClick: ($event) => addOrderItem(),
                              class: "py-1 px-2 border dark:border-gray-700 rounded-md hover:bg-gray-200 dark:hover:bg-gray-800"
                            }, toDisplayString(unref(t)("Add Row")), 9, ["onClick"])
                          ])
                        ]),
                        createVNode("div", { class: "w-full flex flex-col divide-y dark:divide-gray-700 border-y dark:border-gray-700" }, [
                          (openBlock(true), createBlock(Fragment, null, renderList(items.value, (i2, r) => {
                            return openBlock(), createBlock("div", {
                              key: r,
                              class: "odd:bg-gray-50 dark:odd:bg-black/20 even:bg-neutral-50 dark:even:bg-black/50 w-full flex flex-col items-start gap-2 p-6"
                            }, [
                              createVNode("div", { class: "flex items-start gap-2" }, [
                                createVNode("div", { class: "text-sm" }, toDisplayString(r + 1) + ".", 1),
                                createVNode("div", { class: "w-full flex flex-col gap-2" }, [
                                  createVNode("div", { class: "text-sm font-medium flex gap-2 items-center justify-between" }, [
                                    createVNode("div", { class: "flex-1 relative" }, [
                                      createVNode("div", { class: "relative" }, [
                                        createVNode(_sfc_main$5, {
                                          modelValue: i2.name,
                                          "onUpdate:modelValue": ($event) => i2.name = $event,
                                          onBlur: hideResult,
                                          label: "Item Description",
                                          onInput: (e) => unref(searchProduct)(e, r),
                                          class: "text-gray-700 dark:text-gray-300"
                                        }, null, 8, ["modelValue", "onUpdate:modelValue", "onInput"]),
                                        show.value && results.value && results.value.length && searchIndex.value == r ? (openBlock(), createBlock("ul", {
                                          key: 0,
                                          class: "absolute top-full w-full z-20 max-h-64 scroll-py-2 overflow-y-auto p-2 mt-1 bg-white dark:bg-gray-800 border dark:border-gray-700 rounded-md"
                                        }, [
                                          (openBlock(true), createBlock(Fragment, null, renderList(results.value, (sitem, si) => {
                                            return openBlock(), createBlock("li", { key: si }, [
                                              createVNode("button", {
                                                type: "button",
                                                onClick: ($event) => selectItem(sitem, r),
                                                class: "block text-left w-full select-none rounded-md px-3 py-2 hover:bg-blue-500 hover:text-white"
                                              }, [
                                                createVNode("span", { class: "ml-3 flex-auto truncate" }, toDisplayString(sitem.label), 1)
                                              ], 8, ["onClick"])
                                            ]);
                                          }), 128))
                                        ])) : createCommentVNode("", true)
                                      ]),
                                      _ctx.$page.props.errors["items." + r + ".name"] ? (openBlock(), createBlock("div", {
                                        key: 0,
                                        class: "text-red-600 pt-1 rounded-md"
                                      }, toDisplayString(_ctx.$page.props.errors["items." + r + ".name"].replace("items." + r + ".", "")), 1)) : createCommentVNode("", true),
                                      createVNode("div", { class: "absolute top-6 right-0 flex" }, [
                                        createVNode("button", {
                                          type: "button",
                                          onClick: () => i2.show_details = !i2.show_details,
                                          class: [i2.show_details ? "text-blue-500 dark:text-blue-400" : "text-gray-500 dark:text-gray-400", "inline-flex items-center rounded mt-px p-2 font-sans text-sm font-medium focus:ring-0"]
                                        }, [
                                          (openBlock(), createBlock("svg", {
                                            xmlns: "http://www.w3.org/2000/svg",
                                            fill: "none",
                                            viewBox: "0 0 24 24",
                                            "stroke-width": "1.5",
                                            stroke: "currentColor",
                                            class: "w-6 h-6"
                                          }, [
                                            createVNode("path", {
                                              "stroke-linecap": "round",
                                              "stroke-linejoin": "round",
                                              d: "M7.5 8.25h9m-9 3H12m-9.75 1.51c0 1.6 1.123 2.994 2.707 3.227 1.129.166 2.27.293 3.423.379.35.026.67.21.865.501L12 21l2.755-4.133a1.14 1.14 0 01.865-.501 48.172 48.172 0 003.423-.379c1.584-.233 2.707-1.626 2.707-3.228V6.741c0-1.602-1.123-2.995-2.707-3.228A48.394 48.394 0 0012 3c-2.392 0-4.744.175-7.043.513C3.373 3.746 2.25 5.14 2.25 6.741v6.018z"
                                            })
                                          ]))
                                        ], 10, ["onClick"])
                                      ]),
                                      i2.show_details ? (openBlock(), createBlock(_sfc_main$7, {
                                        key: 1,
                                        modelValue: i2.details,
                                        "onUpdate:modelValue": ($event) => i2.details = $event,
                                        class: "mt-2 text-gray-700 dark:text-gray-300"
                                      }, null, 8, ["modelValue", "onUpdate:modelValue"])) : createCommentVNode("", true),
                                      initial_rows.value < r + 1 ? (openBlock(), createBlock("button", {
                                        key: 2,
                                        type: "button",
                                        onClick: ($event) => removeOrderItem(r),
                                        class: "absolute right-0 top-0 text-sm text-red-500 rounded-md flex items-center focus:ring-0"
                                      }, toDisplayString(unref(t)("Remove")), 9, ["onClick"])) : createCommentVNode("", true)
                                    ])
                                  ]),
                                  createVNode("div", { class: "grid grid-cols-2 xl:grid-cols-6 text-sm gap-x-4 gap-y-2" }, [
                                    createVNode("div", null, [
                                      createVNode(_sfc_main$5, {
                                        type: "number",
                                        selectOnFocus: "",
                                        label: "Quantity",
                                        modelValue: i2.quantity,
                                        "onUpdate:modelValue": ($event) => i2.quantity = $event,
                                        class: "text-gray-700 dark:text-gray-300"
                                      }, null, 8, ["modelValue", "onUpdate:modelValue"])
                                    ]),
                                    createVNode("div", null, [
                                      createVNode(_sfc_main$5, {
                                        type: "number",
                                        modelValue: i2.price,
                                        "onUpdate:modelValue": ($event) => i2.price = $event,
                                        label: "Price",
                                        class: "text-gray-700 dark:text-gray-300"
                                      }, null, 8, ["modelValue", "onUpdate:modelValue"])
                                    ]),
                                    createVNode("div", { class: "col-span-2" }, [
                                      createVNode(_sfc_main$4, {
                                        json: true,
                                        id: "tax_rates",
                                        multiple: true,
                                        modelValue: i2.taxes,
                                        "onUpdate:modelValue": ($event) => i2.taxes = $event,
                                        searchable: false,
                                        label: unref(t)("Tax Rates"),
                                        suggestions: __props.tax_rates
                                      }, null, 8, ["modelValue", "onUpdate:modelValue", "label", "suggestions"])
                                    ]),
                                    createVNode("div", null, [
                                      createVNode(_sfc_main$4, {
                                        id: "tax_method",
                                        searchable: false,
                                        modelValue: i2.tax_method,
                                        "onUpdate:modelValue": ($event) => i2.tax_method = $event,
                                        label: unref(t)("Tax Method"),
                                        suggestions: [
                                          { value: "inclusive", label: unref(t)("inclusive") },
                                          { value: "exclusive", label: unref(t)("exclusive") }
                                        ]
                                      }, null, 8, ["modelValue", "onUpdate:modelValue", "label", "suggestions"])
                                    ]),
                                    createVNode("div", null, [
                                      createVNode(_sfc_main$5, {
                                        label: "Discount",
                                        modelValue: i2.discount,
                                        "onUpdate:modelValue": ($event) => i2.discount = $event,
                                        onFocus: ($event) => itemDiscountFocused(r),
                                        pattern: "[0-9]+(\\.[0-9]{1,2})?%?",
                                        class: "text-gray-700 dark:text-gray-300",
                                        title: unref(t)("please type number with or without percentage sign.")
                                      }, null, 8, ["modelValue", "onUpdate:modelValue", "onFocus", "title"])
                                    ])
                                  ]),
                                  createVNode("div", { class: "text-sm -mt-4" }, [
                                    _ctx.$page.props.errors["items." + r + ".quantity"] ? (openBlock(), createBlock("div", {
                                      key: 0,
                                      class: "text-red-600 pt-1 rounded-md"
                                    }, toDisplayString(_ctx.$page.props.errors["items." + r + ".quantity"].replace("items." + r + ".", "")), 1)) : createCommentVNode("", true),
                                    _ctx.$page.props.errors["items." + r + ".price"] ? (openBlock(), createBlock("div", {
                                      key: 1,
                                      class: "text-red-600 pt-1 rounded-md"
                                    }, toDisplayString(_ctx.$page.props.errors["items." + r + ".price"].replace("items." + r + ".", "")), 1)) : createCommentVNode("", true)
                                  ]),
                                  __props.item_fields && __props.item_fields.length ? (openBlock(), createBlock(Fragment, { key: 0 }, [
                                    createVNode("div", { class: "grid grid-cols-2 xl:grid-cols-3 text-sm gap-x-4 gap-y-2" }, [
                                      createVNode(_sfc_main$8, {
                                        id: "item",
                                        fields: __props.item_fields,
                                        modelValue: i2.extra_attributes,
                                        "onUpdate:modelValue": ($event) => i2.extra_attributes = $event
                                      }, null, 8, ["fields", "modelValue", "onUpdate:modelValue"])
                                    ]),
                                    createVNode("div", { class: "-mt-1 text-red-600 text-sm" }, [
                                      (openBlock(true), createBlock(Fragment, null, renderList(__props.item_fields, (field) => {
                                        return openBlock(), createBlock("div", {
                                          key: field.slug
                                        }, toDisplayString(_ctx.$page.props.errors["items." + r + ".extra_attributes." + field.name]), 1);
                                      }), 128))
                                    ])
                                  ], 64)) : createCommentVNode("", true)
                                ])
                              ])
                            ]);
                          }), 128)),
                          createVNode("div", { class: "odd:bg-gray-50 dark:odd:bg-black/20 even:bg-neutral-50 dark:even:bg-black/50 w-full flex items-start justify-end gap-y-2 gap-x-8 p-6" }, [
                            createVNode("div", null, [
                              createVNode("div", { class: "text-right h-6" }, "Total :"),
                              totals.value.discount_amount ? (openBlock(), createBlock("div", {
                                key: 0,
                                class: "text-right h-6"
                              }, "Products Discount :")) : createCommentVNode("", true),
                              totals.value.tax_amount ? (openBlock(), createBlock("div", {
                                key: 1,
                                class: "text-right h-6"
                              }, "Products Tax :")) : createCommentVNode("", true),
                              unref(form).discount_amount ? (openBlock(), createBlock("div", {
                                key: 2,
                                class: "text-right h-6"
                              }, "Order Discount :")) : createCommentVNode("", true),
                              unref(form).tax_amount ? (openBlock(), createBlock("div", {
                                key: 3,
                                class: "text-right h-6"
                              }, "Order Tax :")) : createCommentVNode("", true),
                              unref(form).shipping ? (openBlock(), createBlock("div", {
                                key: 4,
                                class: "text-right h-6"
                              }, "Shipping :")) : createCommentVNode("", true),
                              totals.value.grand_total && totals.value.grand_total != totals.value.total ? (openBlock(), createBlock("div", {
                                key: 5,
                                class: "text-right h-6"
                              }, "Grand Total :")) : createCommentVNode("", true)
                            ]),
                            createVNode("div", null, [
                              createVNode("div", { class: "text-right h-6 font-bold" }, toDisplayString(_ctx.$number(totals.value.total)), 1),
                              totals.value.discount_amount ? (openBlock(), createBlock("div", {
                                key: 0,
                                class: "text-right h-6 font-bold"
                              }, toDisplayString(_ctx.$number(totals.value.discount_amount)), 1)) : createCommentVNode("", true),
                              totals.value.tax_amount ? (openBlock(), createBlock("div", {
                                key: 1,
                                class: "text-right h-6 font-bold"
                              }, toDisplayString(_ctx.$number(totals.value.tax_amount)), 1)) : createCommentVNode("", true),
                              unref(form).discount_amount ? (openBlock(), createBlock("div", {
                                key: 2,
                                class: "text-right h-6 font-bold"
                              }, toDisplayString(_ctx.$number(unref(form).discount_amount)), 1)) : createCommentVNode("", true),
                              unref(form).tax_amount ? (openBlock(), createBlock("div", {
                                key: 3,
                                class: "text-right h-6 font-bold"
                              }, toDisplayString(_ctx.$number(unref(form).tax_amount)), 1)) : createCommentVNode("", true),
                              unref(form).shipping ? (openBlock(), createBlock("div", {
                                key: 4,
                                class: "text-right h-6"
                              }, toDisplayString(_ctx.$number(unref(form).shipping)), 1)) : createCommentVNode("", true),
                              totals.value.grand_total && totals.value.grand_total != totals.value.total ? (openBlock(), createBlock("div", {
                                key: 5,
                                class: "text-right h-6 font-bold"
                              }, toDisplayString(_ctx.$number(totals.value.grand_total)), 1)) : createCommentVNode("", true)
                            ])
                          ])
                        ])
                      ])) : createCommentVNode("", true)
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$4, {
                        json: true,
                        multiple: true,
                        searchable: false,
                        id: "order_tax_rates",
                        modelValue: unref(form).taxes,
                        "onUpdate:modelValue": ($event) => unref(form).taxes = $event,
                        label: unref(t)("Tax Rates"),
                        suggestions: __props.tax_rates,
                        error: unref(form).errors.taxes
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "label", "suggestions", "error"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3 flex items-start gap-6" }, [
                      createVNode("div", { class: "w-1/2" }, [
                        createVNode(_sfc_main$4, {
                          searchable: false,
                          id: "form_tax_method",
                          label: unref(t)("Tax Method"),
                          modelValue: unref(form).tax_method,
                          "onUpdate:modelValue": ($event) => unref(form).tax_method = $event,
                          suggestions: [
                            { value: "inclusive", label: unref(t)("inclusive") },
                            { value: "exclusive", label: unref(t)("exclusive") }
                          ]
                        }, null, 8, ["label", "modelValue", "onUpdate:modelValue", "suggestions"])
                      ]),
                      createVNode("div", { class: "w-1/2" }, [
                        createVNode(_sfc_main$5, {
                          id: "discount",
                          label: unref(t)("Discount"),
                          modelValue: unref(form).discount,
                          "onUpdate:modelValue": ($event) => unref(form).discount = $event,
                          error: unref(form).errors.discount,
                          pattern: "[0-9]+(\\.[0-9]{1,2})?%?",
                          title: unref(t)("please type number with or without percentage sign.")
                        }, null, 8, ["label", "modelValue", "onUpdate:modelValue", "error", "title"])
                      ])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$5, {
                        type: "date",
                        modelValue: unref(form).expiry_date,
                        "onUpdate:modelValue": ($event) => unref(form).expiry_date = $event,
                        id: "expiry_date",
                        error: unref(form).errors.expiry_date,
                        label: unref(t)("Expiry Date")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                      createVNode(_sfc_main$5, {
                        type: "number",
                        modelValue: unref(form).shipping,
                        "onUpdate:modelValue": ($event) => unref(form).shipping = $event,
                        id: "shipping",
                        error: unref(form).errors.shipping,
                        label: unref(t)("Shipping")
                      }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                    ]),
                    createVNode(_sfc_main$8, {
                      fields: __props.fields,
                      errors: unref(form).errors,
                      modelValue: unref(form).extra_attributes,
                      "onUpdate:modelValue": ($event) => unref(form).extra_attributes = $event,
                      className: "col-span-6 sm:col-span-3"
                    }, null, 8, ["fields", "errors", "modelValue", "onUpdate:modelValue"]),
                    createVNode("div", { class: "col-span-full" }, [
                      createVNode("div", { class: "relative" }, [
                        createVNode(_sfc_main$7, {
                          onInput: unref(searchNotes),
                          modelValue: unref(form).note,
                          "onUpdate:modelValue": ($event) => unref(form).note = $event,
                          id: "note",
                          error: unref(form).errors.note,
                          label: unref(t)("Note")
                        }, null, 8, ["onInput", "modelValue", "onUpdate:modelValue", "error", "label"]),
                        showNotes.value && notes.value && notes.value.length ? (openBlock(), createBlock("ul", {
                          key: 0,
                          class: "absolute top-full w-full z-20 max-h-64 scroll-py-2 overflow-y-auto p-2 mt-1 bg-white dark:bg-gray-800 border dark:border-gray-700 rounded-md"
                        }, [
                          (openBlock(true), createBlock(Fragment, null, renderList(notes.value, (n, ni) => {
                            return openBlock(), createBlock("li", { key: ni }, [
                              createVNode("button", {
                                type: "button",
                                onClick: () => {
                                  unref(form).note = n.details;
                                  showNotes.value = false;
                                },
                                class: "block text-left w-full select-none rounded-md px-3 py-2 hover:bg-blue-500 hover:text-white"
                              }, [
                                createVNode("span", { class: "ml-3 flex-auto truncate" }, toDisplayString(n.label), 1)
                              ], 8, ["onClick"])
                            ]);
                          }), 128))
                        ])) : createCommentVNode("", true)
                      ])
                    ]),
                    createVNode("div", { class: "col-span-full" }, [
                      createVNode(_sfc_main$9, {
                        attachments: __props.edit ? (_d = __props.edit.data) == null ? void 0 : _d.attachments : []
                      }, null, 8, ["attachments"])
                    ])
                  ];
                }
              }),
              actions: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(ssrRenderComponent(_sfc_main$a, {
                    on: unref(form).recentlySuccessful,
                    class: "mr-3"
                  }, {
                    default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                      if (_push4) {
                        _push4(`${ssrInterpolate(unref(t)("Saved."))}`);
                      } else {
                        return [
                          createTextVNode(toDisplayString(unref(t)("Saved.")), 1)
                        ];
                      }
                    }),
                    _: 1
                  }, _parent3, _scopeId2));
                  _push3(ssrRenderComponent(_sfc_main$3, {
                    type: "submit",
                    loading: unref(form).processing
                  }, {
                    default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                      if (_push4) {
                        _push4(`${ssrInterpolate(unref(t)("Save"))}`);
                      } else {
                        return [
                          createTextVNode(toDisplayString(unref(t)("Save")), 1)
                        ];
                      }
                    }),
                    _: 1
                  }, _parent3, _scopeId2));
                } else {
                  return [
                    createVNode(_sfc_main$a, {
                      on: unref(form).recentlySuccessful,
                      class: "mr-3"
                    }, {
                      default: withCtx(() => [
                        createTextVNode(toDisplayString(unref(t)("Saved.")), 1)
                      ]),
                      _: 1
                    }, 8, ["on"]),
                    createVNode(_sfc_main$3, {
                      type: "submit",
                      loading: unref(form).processing
                    }, {
                      default: withCtx(() => [
                        createTextVNode(toDisplayString(unref(t)("Save")), 1)
                      ]),
                      _: 1
                    }, 8, ["loading"])
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
            _push2(`</div>`);
            _push2(ssrRenderComponent(_sfc_main$b, {
              show: showModal.value,
              "max-width": "xl",
              closeable: false,
              onClose: () => showModal.value = false
            }, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(`<div class="px-6 pt-3 pb-6 print:px-0 bg-gray-50 dark:bg-gray-900"${_scopeId2}><div class="flex items-start justify-between print:hidden"${_scopeId2}><div class="px-4 sm:px-0 mb-6"${_scopeId2}><h3 class="text-lg font-medium text-gray-900 dark:text-gray-100"${_scopeId2}>${ssrInterpolate(unref(t)("Add New Customer"))}</h3><p class="mt-1 text-sm text-gray-600 dark:text-gray-400"${_scopeId2}>${ssrInterpolate(unref(t)("Please fill the form below to {x}.", { x: unref(t)("add {x}", { x: unref(t)("customer") }) }))}</p></div><div class="-mr-2 flex items- gap-2"${_scopeId2}><button class="flex items-center justify-center h-8 w-8 rounded-full text-gray-600 hover:text-gray-800 hover:bg-gray-300 dark:text-gray-400 dark:hover:text-gray-200 dark:hover:bg-gray-700 focus:outline-none"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_component_icons, {
                    name: "cross",
                    class: "h-5 w-5"
                  }, null, _parent3, _scopeId2));
                  _push3(`</button></div></div><div class=""${_scopeId2}>`);
                  _push3(ssrRenderComponent(_sfc_main$c, {
                    fields: __props.customer_fields,
                    onClose: () => showModal.value = false,
                    onDone: selectCustomer
                  }, null, _parent3, _scopeId2));
                  _push3(`</div></div>`);
                } else {
                  return [
                    createVNode("div", { class: "px-6 pt-3 pb-6 print:px-0 bg-gray-50 dark:bg-gray-900" }, [
                      createVNode("div", { class: "flex items-start justify-between print:hidden" }, [
                        createVNode("div", { class: "px-4 sm:px-0 mb-6" }, [
                          createVNode("h3", { class: "text-lg font-medium text-gray-900 dark:text-gray-100" }, toDisplayString(unref(t)("Add New Customer")), 1),
                          createVNode("p", { class: "mt-1 text-sm text-gray-600 dark:text-gray-400" }, toDisplayString(unref(t)("Please fill the form below to {x}.", { x: unref(t)("add {x}", { x: unref(t)("customer") }) })), 1)
                        ]),
                        createVNode("div", { class: "-mr-2 flex items- gap-2" }, [
                          createVNode("button", {
                            onClick: ($event) => showModal.value = false,
                            class: "flex items-center justify-center h-8 w-8 rounded-full text-gray-600 hover:text-gray-800 hover:bg-gray-300 dark:text-gray-400 dark:hover:text-gray-200 dark:hover:bg-gray-700 focus:outline-none"
                          }, [
                            createVNode(_component_icons, {
                              name: "cross",
                              class: "h-5 w-5"
                            })
                          ], 8, ["onClick"])
                        ])
                      ]),
                      createVNode("div", { class: "" }, [
                        createVNode(_sfc_main$c, {
                          fields: __props.customer_fields,
                          onClose: () => showModal.value = false,
                          onDone: selectCustomer
                        }, null, 8, ["fields", "onClose"])
                      ])
                    ])
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
          } else {
            return [
              createVNode("div", { class: "max-w-7xl mx-auto py-10 sm:px-6 lg:px-8" }, [
                createVNode(_sfc_main$2, {
                  onSubmitted: submit,
                  autocomplete: "off"
                }, {
                  title: withCtx(() => [
                    createTextVNode(toDisplayString(props.edit ? unref(t)("Edit Quotation") : unref(t)("Add New Quotation")), 1)
                  ]),
                  description: withCtx(() => [
                    createTextVNode(toDisplayString(unref(t)("Please fill the form below to {x}.", {
                      x: props.edit ? unref(t)("update {x}", { x: unref(t)("quotation") }) : unref(t)("add {x}", { x: unref(t)("quotation") })
                    })) + " ", 1),
                    createVNode("div", null, [
                      createVNode(_sfc_main$3, {
                        href: _ctx.route("quotations.index"),
                        class: "mt-4"
                      }, {
                        default: withCtx(() => [
                          createTextVNode(toDisplayString(unref(t)("List Quotations")), 1)
                        ]),
                        _: 1
                      }, 8, ["href"])
                    ])
                  ]),
                  form: withCtx(() => {
                    var _a, _b;
                    return [
                      createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                        createVNode(_sfc_main$4, {
                          json: true,
                          id: "company_id",
                          searchable: true,
                          label: unref(t)("Company"),
                          suggestions: __props.companies,
                          modelValue: unref(form).company_id,
                          "onUpdate:modelValue": ($event) => unref(form).company_id = $event,
                          error: unref(form).errors.company_id
                        }, null, 8, ["label", "suggestions", "modelValue", "onUpdate:modelValue", "error"])
                      ]),
                      createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                        createVNode(_sfc_main$4, {
                          json: true,
                          id: "customer_id",
                          modelValue: customer.value,
                          "onUpdate:modelValue": ($event) => customer.value = $event,
                          searchable: true,
                          label: unref(t)("Customer"),
                          addResult: addResult.value,
                          "action-text": unref(t)("Create"),
                          selected: (_a = customer.value) == null ? void 0 : _a.value,
                          action: () => addCustomer(),
                          error: unref(form).errors.customer_id,
                          suggestions: _ctx.route("search.customers")
                        }, null, 8, ["modelValue", "onUpdate:modelValue", "label", "addResult", "action-text", "selected", "action", "error", "suggestions"])
                      ]),
                      createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                        createVNode(_sfc_main$5, {
                          type: "date",
                          modelValue: unref(form).date,
                          "onUpdate:modelValue": ($event) => unref(form).date = $event,
                          id: "date",
                          error: unref(form).errors.date,
                          label: unref(t)("Date")
                        }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                      ]),
                      createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                        createVNode(_sfc_main$5, {
                          modelValue: unref(form).reference,
                          "onUpdate:modelValue": ($event) => unref(form).reference = $event,
                          id: "reference",
                          error: unref(form).errors.reference,
                          label: unref(t)("Reference")
                        }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                      ]),
                      createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                        createVNode(_sfc_main$4, {
                          id: "status",
                          json: true,
                          searchable: false,
                          label: unref(t)("Status"),
                          modelValue: unref(form).status,
                          "onUpdate:modelValue": ($event) => unref(form).status = $event,
                          error: unref(form).errors.status,
                          suggestions: [
                            { value: "pending", label: "Pending" },
                            { value: "sent", label: "Sent" },
                            { value: "confirmed", label: "Confirmed" },
                            { value: "canceled", label: "Canceled" }
                          ]
                        }, null, 8, ["label", "modelValue", "onUpdate:modelValue", "error"])
                      ]),
                      createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                        createVNode(_sfc_main$6, {
                          multiple: "",
                          modelValue: unref(form).attachments,
                          "onUpdate:modelValue": ($event) => unref(form).attachments = $event,
                          id: "attachments",
                          error: unref(form).errors.attachments,
                          label: unref(t)("Attachments")
                        }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                      ]),
                      createVNode("div", { class: "col-span-full -mx-6" }, [
                        items.value && items.value.length ? (openBlock(), createBlock("div", {
                          key: 0,
                          class: "flex flex-col"
                        }, [
                          createVNode("div", { class: "flex items-center justify-between mx-6 mb-3" }, [
                            createVNode("h2", { class: "text-lg font-extrabold" }, toDisplayString(unref(t)("Order Items")), 1),
                            createVNode("div", { class: "flex items-center" }, [
                              added.value ? (openBlock(), createBlock("span", {
                                key: 0,
                                class: "text-gray-500 dark:text-gray-400 mr-2"
                              }, toDisplayString(unref(t)("Added")), 1)) : createCommentVNode("", true),
                              createVNode("button", {
                                type: "button",
                                onClick: ($event) => addOrderItem(),
                                class: "py-1 px-2 border dark:border-gray-700 rounded-md hover:bg-gray-200 dark:hover:bg-gray-800"
                              }, toDisplayString(unref(t)("Add Row")), 9, ["onClick"])
                            ])
                          ]),
                          createVNode("div", { class: "w-full flex flex-col divide-y dark:divide-gray-700 border-y dark:border-gray-700" }, [
                            (openBlock(true), createBlock(Fragment, null, renderList(items.value, (i2, r) => {
                              return openBlock(), createBlock("div", {
                                key: r,
                                class: "odd:bg-gray-50 dark:odd:bg-black/20 even:bg-neutral-50 dark:even:bg-black/50 w-full flex flex-col items-start gap-2 p-6"
                              }, [
                                createVNode("div", { class: "flex items-start gap-2" }, [
                                  createVNode("div", { class: "text-sm" }, toDisplayString(r + 1) + ".", 1),
                                  createVNode("div", { class: "w-full flex flex-col gap-2" }, [
                                    createVNode("div", { class: "text-sm font-medium flex gap-2 items-center justify-between" }, [
                                      createVNode("div", { class: "flex-1 relative" }, [
                                        createVNode("div", { class: "relative" }, [
                                          createVNode(_sfc_main$5, {
                                            modelValue: i2.name,
                                            "onUpdate:modelValue": ($event) => i2.name = $event,
                                            onBlur: hideResult,
                                            label: "Item Description",
                                            onInput: (e) => unref(searchProduct)(e, r),
                                            class: "text-gray-700 dark:text-gray-300"
                                          }, null, 8, ["modelValue", "onUpdate:modelValue", "onInput"]),
                                          show.value && results.value && results.value.length && searchIndex.value == r ? (openBlock(), createBlock("ul", {
                                            key: 0,
                                            class: "absolute top-full w-full z-20 max-h-64 scroll-py-2 overflow-y-auto p-2 mt-1 bg-white dark:bg-gray-800 border dark:border-gray-700 rounded-md"
                                          }, [
                                            (openBlock(true), createBlock(Fragment, null, renderList(results.value, (sitem, si) => {
                                              return openBlock(), createBlock("li", { key: si }, [
                                                createVNode("button", {
                                                  type: "button",
                                                  onClick: ($event) => selectItem(sitem, r),
                                                  class: "block text-left w-full select-none rounded-md px-3 py-2 hover:bg-blue-500 hover:text-white"
                                                }, [
                                                  createVNode("span", { class: "ml-3 flex-auto truncate" }, toDisplayString(sitem.label), 1)
                                                ], 8, ["onClick"])
                                              ]);
                                            }), 128))
                                          ])) : createCommentVNode("", true)
                                        ]),
                                        _ctx.$page.props.errors["items." + r + ".name"] ? (openBlock(), createBlock("div", {
                                          key: 0,
                                          class: "text-red-600 pt-1 rounded-md"
                                        }, toDisplayString(_ctx.$page.props.errors["items." + r + ".name"].replace("items." + r + ".", "")), 1)) : createCommentVNode("", true),
                                        createVNode("div", { class: "absolute top-6 right-0 flex" }, [
                                          createVNode("button", {
                                            type: "button",
                                            onClick: () => i2.show_details = !i2.show_details,
                                            class: [i2.show_details ? "text-blue-500 dark:text-blue-400" : "text-gray-500 dark:text-gray-400", "inline-flex items-center rounded mt-px p-2 font-sans text-sm font-medium focus:ring-0"]
                                          }, [
                                            (openBlock(), createBlock("svg", {
                                              xmlns: "http://www.w3.org/2000/svg",
                                              fill: "none",
                                              viewBox: "0 0 24 24",
                                              "stroke-width": "1.5",
                                              stroke: "currentColor",
                                              class: "w-6 h-6"
                                            }, [
                                              createVNode("path", {
                                                "stroke-linecap": "round",
                                                "stroke-linejoin": "round",
                                                d: "M7.5 8.25h9m-9 3H12m-9.75 1.51c0 1.6 1.123 2.994 2.707 3.227 1.129.166 2.27.293 3.423.379.35.026.67.21.865.501L12 21l2.755-4.133a1.14 1.14 0 01.865-.501 48.172 48.172 0 003.423-.379c1.584-.233 2.707-1.626 2.707-3.228V6.741c0-1.602-1.123-2.995-2.707-3.228A48.394 48.394 0 0012 3c-2.392 0-4.744.175-7.043.513C3.373 3.746 2.25 5.14 2.25 6.741v6.018z"
                                              })
                                            ]))
                                          ], 10, ["onClick"])
                                        ]),
                                        i2.show_details ? (openBlock(), createBlock(_sfc_main$7, {
                                          key: 1,
                                          modelValue: i2.details,
                                          "onUpdate:modelValue": ($event) => i2.details = $event,
                                          class: "mt-2 text-gray-700 dark:text-gray-300"
                                        }, null, 8, ["modelValue", "onUpdate:modelValue"])) : createCommentVNode("", true),
                                        initial_rows.value < r + 1 ? (openBlock(), createBlock("button", {
                                          key: 2,
                                          type: "button",
                                          onClick: ($event) => removeOrderItem(r),
                                          class: "absolute right-0 top-0 text-sm text-red-500 rounded-md flex items-center focus:ring-0"
                                        }, toDisplayString(unref(t)("Remove")), 9, ["onClick"])) : createCommentVNode("", true)
                                      ])
                                    ]),
                                    createVNode("div", { class: "grid grid-cols-2 xl:grid-cols-6 text-sm gap-x-4 gap-y-2" }, [
                                      createVNode("div", null, [
                                        createVNode(_sfc_main$5, {
                                          type: "number",
                                          selectOnFocus: "",
                                          label: "Quantity",
                                          modelValue: i2.quantity,
                                          "onUpdate:modelValue": ($event) => i2.quantity = $event,
                                          class: "text-gray-700 dark:text-gray-300"
                                        }, null, 8, ["modelValue", "onUpdate:modelValue"])
                                      ]),
                                      createVNode("div", null, [
                                        createVNode(_sfc_main$5, {
                                          type: "number",
                                          modelValue: i2.price,
                                          "onUpdate:modelValue": ($event) => i2.price = $event,
                                          label: "Price",
                                          class: "text-gray-700 dark:text-gray-300"
                                        }, null, 8, ["modelValue", "onUpdate:modelValue"])
                                      ]),
                                      createVNode("div", { class: "col-span-2" }, [
                                        createVNode(_sfc_main$4, {
                                          json: true,
                                          id: "tax_rates",
                                          multiple: true,
                                          modelValue: i2.taxes,
                                          "onUpdate:modelValue": ($event) => i2.taxes = $event,
                                          searchable: false,
                                          label: unref(t)("Tax Rates"),
                                          suggestions: __props.tax_rates
                                        }, null, 8, ["modelValue", "onUpdate:modelValue", "label", "suggestions"])
                                      ]),
                                      createVNode("div", null, [
                                        createVNode(_sfc_main$4, {
                                          id: "tax_method",
                                          searchable: false,
                                          modelValue: i2.tax_method,
                                          "onUpdate:modelValue": ($event) => i2.tax_method = $event,
                                          label: unref(t)("Tax Method"),
                                          suggestions: [
                                            { value: "inclusive", label: unref(t)("inclusive") },
                                            { value: "exclusive", label: unref(t)("exclusive") }
                                          ]
                                        }, null, 8, ["modelValue", "onUpdate:modelValue", "label", "suggestions"])
                                      ]),
                                      createVNode("div", null, [
                                        createVNode(_sfc_main$5, {
                                          label: "Discount",
                                          modelValue: i2.discount,
                                          "onUpdate:modelValue": ($event) => i2.discount = $event,
                                          onFocus: ($event) => itemDiscountFocused(r),
                                          pattern: "[0-9]+(\\.[0-9]{1,2})?%?",
                                          class: "text-gray-700 dark:text-gray-300",
                                          title: unref(t)("please type number with or without percentage sign.")
                                        }, null, 8, ["modelValue", "onUpdate:modelValue", "onFocus", "title"])
                                      ])
                                    ]),
                                    createVNode("div", { class: "text-sm -mt-4" }, [
                                      _ctx.$page.props.errors["items." + r + ".quantity"] ? (openBlock(), createBlock("div", {
                                        key: 0,
                                        class: "text-red-600 pt-1 rounded-md"
                                      }, toDisplayString(_ctx.$page.props.errors["items." + r + ".quantity"].replace("items." + r + ".", "")), 1)) : createCommentVNode("", true),
                                      _ctx.$page.props.errors["items." + r + ".price"] ? (openBlock(), createBlock("div", {
                                        key: 1,
                                        class: "text-red-600 pt-1 rounded-md"
                                      }, toDisplayString(_ctx.$page.props.errors["items." + r + ".price"].replace("items." + r + ".", "")), 1)) : createCommentVNode("", true)
                                    ]),
                                    __props.item_fields && __props.item_fields.length ? (openBlock(), createBlock(Fragment, { key: 0 }, [
                                      createVNode("div", { class: "grid grid-cols-2 xl:grid-cols-3 text-sm gap-x-4 gap-y-2" }, [
                                        createVNode(_sfc_main$8, {
                                          id: "item",
                                          fields: __props.item_fields,
                                          modelValue: i2.extra_attributes,
                                          "onUpdate:modelValue": ($event) => i2.extra_attributes = $event
                                        }, null, 8, ["fields", "modelValue", "onUpdate:modelValue"])
                                      ]),
                                      createVNode("div", { class: "-mt-1 text-red-600 text-sm" }, [
                                        (openBlock(true), createBlock(Fragment, null, renderList(__props.item_fields, (field) => {
                                          return openBlock(), createBlock("div", {
                                            key: field.slug
                                          }, toDisplayString(_ctx.$page.props.errors["items." + r + ".extra_attributes." + field.name]), 1);
                                        }), 128))
                                      ])
                                    ], 64)) : createCommentVNode("", true)
                                  ])
                                ])
                              ]);
                            }), 128)),
                            createVNode("div", { class: "odd:bg-gray-50 dark:odd:bg-black/20 even:bg-neutral-50 dark:even:bg-black/50 w-full flex items-start justify-end gap-y-2 gap-x-8 p-6" }, [
                              createVNode("div", null, [
                                createVNode("div", { class: "text-right h-6" }, "Total :"),
                                totals.value.discount_amount ? (openBlock(), createBlock("div", {
                                  key: 0,
                                  class: "text-right h-6"
                                }, "Products Discount :")) : createCommentVNode("", true),
                                totals.value.tax_amount ? (openBlock(), createBlock("div", {
                                  key: 1,
                                  class: "text-right h-6"
                                }, "Products Tax :")) : createCommentVNode("", true),
                                unref(form).discount_amount ? (openBlock(), createBlock("div", {
                                  key: 2,
                                  class: "text-right h-6"
                                }, "Order Discount :")) : createCommentVNode("", true),
                                unref(form).tax_amount ? (openBlock(), createBlock("div", {
                                  key: 3,
                                  class: "text-right h-6"
                                }, "Order Tax :")) : createCommentVNode("", true),
                                unref(form).shipping ? (openBlock(), createBlock("div", {
                                  key: 4,
                                  class: "text-right h-6"
                                }, "Shipping :")) : createCommentVNode("", true),
                                totals.value.grand_total && totals.value.grand_total != totals.value.total ? (openBlock(), createBlock("div", {
                                  key: 5,
                                  class: "text-right h-6"
                                }, "Grand Total :")) : createCommentVNode("", true)
                              ]),
                              createVNode("div", null, [
                                createVNode("div", { class: "text-right h-6 font-bold" }, toDisplayString(_ctx.$number(totals.value.total)), 1),
                                totals.value.discount_amount ? (openBlock(), createBlock("div", {
                                  key: 0,
                                  class: "text-right h-6 font-bold"
                                }, toDisplayString(_ctx.$number(totals.value.discount_amount)), 1)) : createCommentVNode("", true),
                                totals.value.tax_amount ? (openBlock(), createBlock("div", {
                                  key: 1,
                                  class: "text-right h-6 font-bold"
                                }, toDisplayString(_ctx.$number(totals.value.tax_amount)), 1)) : createCommentVNode("", true),
                                unref(form).discount_amount ? (openBlock(), createBlock("div", {
                                  key: 2,
                                  class: "text-right h-6 font-bold"
                                }, toDisplayString(_ctx.$number(unref(form).discount_amount)), 1)) : createCommentVNode("", true),
                                unref(form).tax_amount ? (openBlock(), createBlock("div", {
                                  key: 3,
                                  class: "text-right h-6 font-bold"
                                }, toDisplayString(_ctx.$number(unref(form).tax_amount)), 1)) : createCommentVNode("", true),
                                unref(form).shipping ? (openBlock(), createBlock("div", {
                                  key: 4,
                                  class: "text-right h-6"
                                }, toDisplayString(_ctx.$number(unref(form).shipping)), 1)) : createCommentVNode("", true),
                                totals.value.grand_total && totals.value.grand_total != totals.value.total ? (openBlock(), createBlock("div", {
                                  key: 5,
                                  class: "text-right h-6 font-bold"
                                }, toDisplayString(_ctx.$number(totals.value.grand_total)), 1)) : createCommentVNode("", true)
                              ])
                            ])
                          ])
                        ])) : createCommentVNode("", true)
                      ]),
                      createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                        createVNode(_sfc_main$4, {
                          json: true,
                          multiple: true,
                          searchable: false,
                          id: "order_tax_rates",
                          modelValue: unref(form).taxes,
                          "onUpdate:modelValue": ($event) => unref(form).taxes = $event,
                          label: unref(t)("Tax Rates"),
                          suggestions: __props.tax_rates,
                          error: unref(form).errors.taxes
                        }, null, 8, ["modelValue", "onUpdate:modelValue", "label", "suggestions", "error"])
                      ]),
                      createVNode("div", { class: "col-span-6 sm:col-span-3 flex items-start gap-6" }, [
                        createVNode("div", { class: "w-1/2" }, [
                          createVNode(_sfc_main$4, {
                            searchable: false,
                            id: "form_tax_method",
                            label: unref(t)("Tax Method"),
                            modelValue: unref(form).tax_method,
                            "onUpdate:modelValue": ($event) => unref(form).tax_method = $event,
                            suggestions: [
                              { value: "inclusive", label: unref(t)("inclusive") },
                              { value: "exclusive", label: unref(t)("exclusive") }
                            ]
                          }, null, 8, ["label", "modelValue", "onUpdate:modelValue", "suggestions"])
                        ]),
                        createVNode("div", { class: "w-1/2" }, [
                          createVNode(_sfc_main$5, {
                            id: "discount",
                            label: unref(t)("Discount"),
                            modelValue: unref(form).discount,
                            "onUpdate:modelValue": ($event) => unref(form).discount = $event,
                            error: unref(form).errors.discount,
                            pattern: "[0-9]+(\\.[0-9]{1,2})?%?",
                            title: unref(t)("please type number with or without percentage sign.")
                          }, null, 8, ["label", "modelValue", "onUpdate:modelValue", "error", "title"])
                        ])
                      ]),
                      createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                        createVNode(_sfc_main$5, {
                          type: "date",
                          modelValue: unref(form).expiry_date,
                          "onUpdate:modelValue": ($event) => unref(form).expiry_date = $event,
                          id: "expiry_date",
                          error: unref(form).errors.expiry_date,
                          label: unref(t)("Expiry Date")
                        }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                      ]),
                      createVNode("div", { class: "col-span-6 sm:col-span-3" }, [
                        createVNode(_sfc_main$5, {
                          type: "number",
                          modelValue: unref(form).shipping,
                          "onUpdate:modelValue": ($event) => unref(form).shipping = $event,
                          id: "shipping",
                          error: unref(form).errors.shipping,
                          label: unref(t)("Shipping")
                        }, null, 8, ["modelValue", "onUpdate:modelValue", "error", "label"])
                      ]),
                      createVNode(_sfc_main$8, {
                        fields: __props.fields,
                        errors: unref(form).errors,
                        modelValue: unref(form).extra_attributes,
                        "onUpdate:modelValue": ($event) => unref(form).extra_attributes = $event,
                        className: "col-span-6 sm:col-span-3"
                      }, null, 8, ["fields", "errors", "modelValue", "onUpdate:modelValue"]),
                      createVNode("div", { class: "col-span-full" }, [
                        createVNode("div", { class: "relative" }, [
                          createVNode(_sfc_main$7, {
                            onInput: unref(searchNotes),
                            modelValue: unref(form).note,
                            "onUpdate:modelValue": ($event) => unref(form).note = $event,
                            id: "note",
                            error: unref(form).errors.note,
                            label: unref(t)("Note")
                          }, null, 8, ["onInput", "modelValue", "onUpdate:modelValue", "error", "label"]),
                          showNotes.value && notes.value && notes.value.length ? (openBlock(), createBlock("ul", {
                            key: 0,
                            class: "absolute top-full w-full z-20 max-h-64 scroll-py-2 overflow-y-auto p-2 mt-1 bg-white dark:bg-gray-800 border dark:border-gray-700 rounded-md"
                          }, [
                            (openBlock(true), createBlock(Fragment, null, renderList(notes.value, (n, ni) => {
                              return openBlock(), createBlock("li", { key: ni }, [
                                createVNode("button", {
                                  type: "button",
                                  onClick: () => {
                                    unref(form).note = n.details;
                                    showNotes.value = false;
                                  },
                                  class: "block text-left w-full select-none rounded-md px-3 py-2 hover:bg-blue-500 hover:text-white"
                                }, [
                                  createVNode("span", { class: "ml-3 flex-auto truncate" }, toDisplayString(n.label), 1)
                                ], 8, ["onClick"])
                              ]);
                            }), 128))
                          ])) : createCommentVNode("", true)
                        ])
                      ]),
                      createVNode("div", { class: "col-span-full" }, [
                        createVNode(_sfc_main$9, {
                          attachments: __props.edit ? (_b = __props.edit.data) == null ? void 0 : _b.attachments : []
                        }, null, 8, ["attachments"])
                      ])
                    ];
                  }),
                  actions: withCtx(() => [
                    createVNode(_sfc_main$a, {
                      on: unref(form).recentlySuccessful,
                      class: "mr-3"
                    }, {
                      default: withCtx(() => [
                        createTextVNode(toDisplayString(unref(t)("Saved.")), 1)
                      ]),
                      _: 1
                    }, 8, ["on"]),
                    createVNode(_sfc_main$3, {
                      type: "submit",
                      loading: unref(form).processing
                    }, {
                      default: withCtx(() => [
                        createTextVNode(toDisplayString(unref(t)("Save")), 1)
                      ]),
                      _: 1
                    }, 8, ["loading"])
                  ]),
                  _: 1
                })
              ]),
              createVNode(_sfc_main$b, {
                show: showModal.value,
                "max-width": "xl",
                closeable: false,
                onClose: () => showModal.value = false
              }, {
                default: withCtx(() => [
                  createVNode("div", { class: "px-6 pt-3 pb-6 print:px-0 bg-gray-50 dark:bg-gray-900" }, [
                    createVNode("div", { class: "flex items-start justify-between print:hidden" }, [
                      createVNode("div", { class: "px-4 sm:px-0 mb-6" }, [
                        createVNode("h3", { class: "text-lg font-medium text-gray-900 dark:text-gray-100" }, toDisplayString(unref(t)("Add New Customer")), 1),
                        createVNode("p", { class: "mt-1 text-sm text-gray-600 dark:text-gray-400" }, toDisplayString(unref(t)("Please fill the form below to {x}.", { x: unref(t)("add {x}", { x: unref(t)("customer") }) })), 1)
                      ]),
                      createVNode("div", { class: "-mr-2 flex items- gap-2" }, [
                        createVNode("button", {
                          onClick: ($event) => showModal.value = false,
                          class: "flex items-center justify-center h-8 w-8 rounded-full text-gray-600 hover:text-gray-800 hover:bg-gray-300 dark:text-gray-400 dark:hover:text-gray-200 dark:hover:bg-gray-700 focus:outline-none"
                        }, [
                          createVNode(_component_icons, {
                            name: "cross",
                            class: "h-5 w-5"
                          })
                        ], 8, ["onClick"])
                      ])
                    ]),
                    createVNode("div", { class: "" }, [
                      createVNode(_sfc_main$c, {
                        fields: __props.customer_fields,
                        onClose: () => showModal.value = false,
                        onDone: selectCustomer
                      }, null, 8, ["fields", "onClose"])
                    ])
                  ])
                ]),
                _: 1
              }, 8, ["show", "onClose"])
            ];
          }
        }),
        _: 1
      }, _parent));
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Pages/Quotation/Form.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};
export {
  _sfc_main as default
};
