import { ref, computed, onMounted, resolveComponent, mergeProps, unref, withCtx, createTextVNode, toDisplayString, createVNode, openBlock, createBlock, createCommentVNode, Fragment, renderList, withModifiers, withDirectives, vModelCheckbox, useSSRContext } from "vue";
import { ssrRenderComponent, ssrInterpolate, ssrRenderAttr, ssrIncludeBooleanAttr, ssrRenderList, ssrRenderClass, ssrLooseContain } from "vue/server-renderer";
import route from "ziggy-js";
import { useI18n } from "vue-i18n";
import { useForm, router } from "@inertiajs/vue3";
import { _ as _sfc_main$2 } from "./InputError-951c1c36.js";
import { _ as _sfc_main$9 } from "./Modal-4ced3d7d.js";
import { _ as _sfc_main$1 } from "./AppLayout-9028b106.js";
import { _ as _sfc_main$3, a as _sfc_main$8 } from "./SearchFilter-afc75b14.js";
import { _ as _sfc_main$7 } from "./RowActions-ddcfd30f.js";
import { S as SelectInput } from "./SelectInput-0eee531e.js";
import _sfc_main$a from "./UserForm-b5611394.js";
import { _ as _sfc_main$4, a as _sfc_main$6 } from "./DangerButton-933af61d.js";
import { _ as _sfc_main$5 } from "./SecondaryButton-910b0895.js";
import "../ssr.js";
import "@vue/server-renderer";
import "@inertiajs/vue3/server";
import "uuid";
import "./ActionMessage-cdce5426.js";
import "./TextInput-f18b2e86.js";
import "./Input-fb927b71.js";
import "./CustomFields-6004e621.js";
import "lodash/debounce.js";
import "./AutoComplete-974a17ce.js";
import "axios";
import "lodash/throttle.js";
import "./TextareaInput-651f7dc6.js";
import "./FormSection-d5f140fc.js";
const _sfc_main = {
  __name: "List",
  __ssrInlineRender: true,
  props: ["customers"],
  setup(__props) {
    const props = __props;
    const { t } = useI18n({});
    const userModal = ref(false);
    const list_users = ref(false);
    const bulkDelete = ref(false);
    const selectedUser = ref(null);
    const selectedCustomer = ref(null);
    const form = useForm({ selection: [], force: false });
    const search = useForm({ search: "", trashed: null });
    const indeterminate = computed(() => form.selection.length > 0 && form.selection.length < props.customers.data.length);
    onMounted(() => {
      const queryString = window.location.search;
      const urlParams = new URLSearchParams(queryString);
      search.trashed = urlParams.has("trashed") ? urlParams.get("trashed") : null;
    });
    const deleteRow = (id, force = false) => {
      router.delete(route("customers.destroy" + (force ? ".permanently" : ""), id));
    };
    const restoreRow = (id) => {
      router.put(route("customers.restore", id));
    };
    const closeModal = () => {
      bulkDelete.value = false;
    };
    const addUser = (selected) => {
      selectedCustomer.value = selected;
      userModal.value = true;
    };
    const editUser = (selected) => {
      selectedUser.value = selected;
      list_users.value = false;
      userModal.value = true;
    };
    const viewUsers = (selected) => {
      selectedCustomer.value = selected;
      list_users.value = true;
    };
    const updatedUser = (selected) => {
      router.reload({ only: ["customers"] });
      userModal.value = false;
    };
    const closeUserModal = () => {
      userModal.value = false;
      selectedUser.value = null;
      selectedCustomer.value = null;
    };
    const confirmDelete = (force) => {
      form.force = force || false;
      bulkDelete.value = true;
    };
    const deleteSelected = (force) => {
      form.delete(route("customers.destroy.many"), {
        onSuccess: () => {
          form.reset();
        },
        onFinish: () => {
          bulkDelete.value = false;
        }
      });
    };
    const searchNow = () => {
      search.transform((data) => {
        let obj = {
          ...data,
          remember: data.remember ? "on" : ""
        };
        return Object.entries(obj).reduce((a, [k, v]) => v ? (a[k] = v, a) : a, {});
      }).get(route("customers.index"), { preserveState: true });
    };
    const resetSearch = () => {
      search.search = "";
      search.trashed = null;
      searchNow();
    };
    return (_ctx, _push, _parent, _attrs) => {
      const _component_Link = resolveComponent("Link");
      const _component_icons = resolveComponent("icons");
      _push(ssrRenderComponent(_sfc_main$1, mergeProps({
        title: unref(t)("List Customers")
      }, _attrs), {
        default: withCtx((_, _push2, _parent2, _scopeId) => {
          if (_push2) {
            _push2(`<div class="py-8"${_scopeId}><div class="max-w-7xl mx-auto sm:px-6 lg:px-8"${_scopeId}><div class="bg-white dark:bg-gray-900 shadow sm:rounded-lg"${_scopeId}><div class="sm:rounded-lg"${_scopeId}><div class="p-6 sm:rounded-t-lg border-b border-gray-200 dark:border-gray-700 block md:flex md:items-center md:justify-between"${_scopeId}><div${_scopeId}><div class="text-2xl"${_scopeId}>${ssrInterpolate(unref(t)("Customers"))} <span class="text-base"${_scopeId}>${ssrInterpolate({ with: "(" + unref(t)("With Trashed") + ")", only: "(" + unref(t)("Only Trashed") + ")" }[unref(search).trashed])}</span></div><div class="mt-1 text-gray-500 dark:text-gray-400"${_scopeId}>${ssrInterpolate(unref(t)("Please review the result below"))}</div></div><div class="mt-4 sm:mt-0 block sm:flex sm:items-center sm:gap-4"${_scopeId}>`);
            if (_ctx.$can("create-customers")) {
              _push2(ssrRenderComponent(_sfc_main$2, {
                href: unref(route)("customers.create")
              }, {
                default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                  if (_push3) {
                    _push3(`${ssrInterpolate(unref(t)("Add New Customer"))}`);
                  } else {
                    return [
                      createTextVNode(toDisplayString(unref(t)("Add New Customer")), 1)
                    ];
                  }
                }),
                _: 1
              }, _parent2, _scopeId));
            } else {
              _push2(`<!---->`);
            }
            _push2(`<form${_scopeId}>`);
            _push2(ssrRenderComponent(_sfc_main$3, {
              onReset: ($event) => resetSearch(),
              modelValue: unref(search).search,
              "onUpdate:modelValue": ($event) => unref(search).search = $event
            }, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(`<label class="block"${_scopeId2}>${ssrInterpolate(unref(t)("Trashed"))}:</label>`);
                  _push3(ssrRenderComponent(SelectInput, {
                    modelValue: unref(search).trashed,
                    "onUpdate:modelValue": ($event) => unref(search).trashed = $event,
                    onChange: ($event) => searchNow(),
                    class: "mt-1 w-full"
                  }, {
                    default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                      if (_push4) {
                        _push4(`<option${ssrRenderAttr("value", null)}${_scopeId3}>${ssrInterpolate(unref(t)("Not Trashed"))}</option><option value="with"${_scopeId3}>${ssrInterpolate(unref(t)("With Trashed"))}</option><option value="only"${_scopeId3}>${ssrInterpolate(unref(t)("Only Trashed"))}</option>`);
                      } else {
                        return [
                          createVNode("option", { value: null }, toDisplayString(unref(t)("Not Trashed")), 1),
                          createVNode("option", { value: "with" }, toDisplayString(unref(t)("With Trashed")), 1),
                          createVNode("option", { value: "only" }, toDisplayString(unref(t)("Only Trashed")), 1)
                        ];
                      }
                    }),
                    _: 1
                  }, _parent3, _scopeId2));
                } else {
                  return [
                    createVNode("label", { class: "block" }, toDisplayString(unref(t)("Trashed")) + ":", 1),
                    createVNode(SelectInput, {
                      modelValue: unref(search).trashed,
                      "onUpdate:modelValue": ($event) => unref(search).trashed = $event,
                      onChange: ($event) => searchNow(),
                      class: "mt-1 w-full"
                    }, {
                      default: withCtx(() => [
                        createVNode("option", { value: null }, toDisplayString(unref(t)("Not Trashed")), 1),
                        createVNode("option", { value: "with" }, toDisplayString(unref(t)("With Trashed")), 1),
                        createVNode("option", { value: "only" }, toDisplayString(unref(t)("Only Trashed")), 1)
                      ]),
                      _: 1
                    }, 8, ["modelValue", "onUpdate:modelValue", "onChange"])
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
            _push2(`</form></div></div><div class="bg-gray-50 dark:bg-black/50 border-b dark:border-gray-700 sm:rounded-b-lg"${_scopeId}>`);
            if (props.customers && props.customers.data && props.customers.data.length) {
              _push2(`<div${_scopeId}><div class="flex flex-col"${_scopeId}><div class="-my-2 overflow-x-auto sm:-mx-6 lg:-mx-8"${_scopeId}><div class="inline-block min-w-full py-2 align-middle sm:px-6 lg:px-8"${_scopeId}><div class="relative overflow-hidden ring-1 ring-black ring-opacity-5"${_scopeId}>`);
              if (unref(form).selection && unref(form).selection.length) {
                _push2(`<div class="absolute top-0 left-12 flex h-12 items-center space-x-3 sm:left-16"${_scopeId}><button type="button" class="inline-flex items-center rounded border text-white border-red-500 bg-red-500 px-2.5 py-1.5 text-xs font-medium shadow-sm hover:bg-red-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 disabled:cursor-not-allowed disabled:opacity-30"${_scopeId}>${ssrInterpolate(unref(t)("Move to Trash"))}</button><button type="button" class="inline-flex items-center rounded border text-white border-red-500 bg-red-500 px-2.5 py-1.5 text-xs font-medium shadow-sm hover:bg-red-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 disabled:cursor-not-allowed disabled:opacity-30"${_scopeId}>${ssrInterpolate(unref(t)("Delete Permanently"))}</button>`);
                _push2(ssrRenderComponent(_sfc_main$4, {
                  show: bulkDelete.value,
                  onClose: closeModal,
                  maxWidth: "sm"
                }, {
                  title: withCtx((_2, _push3, _parent3, _scopeId2) => {
                    if (_push3) {
                      _push3(`${ssrInterpolate(unref(t)("Delete bulk records"))}`);
                    } else {
                      return [
                        createTextVNode(toDisplayString(unref(t)("Delete bulk records")), 1)
                      ];
                    }
                  }),
                  content: withCtx((_2, _push3, _parent3, _scopeId2) => {
                    if (_push3) {
                      _push3(`<p${_scopeId2}>${ssrInterpolate(unref(t)("Please confirm that you would like to delete the records?"))}</p>`);
                      if (unref(form).force) {
                        _push3(`<p class="mt-2 text-red-500"${_scopeId2}>${ssrInterpolate(unref(t)("This action will delete the data permanently."))}</p>`);
                      } else {
                        _push3(`<!---->`);
                      }
                    } else {
                      return [
                        createVNode("p", null, toDisplayString(unref(t)("Please confirm that you would like to delete the records?")), 1),
                        unref(form).force ? (openBlock(), createBlock("p", {
                          key: 0,
                          class: "mt-2 text-red-500"
                        }, toDisplayString(unref(t)("This action will delete the data permanently.")), 1)) : createCommentVNode("", true)
                      ];
                    }
                  }),
                  footer: withCtx((_2, _push3, _parent3, _scopeId2) => {
                    if (_push3) {
                      _push3(ssrRenderComponent(_sfc_main$5, { onClick: closeModal }, {
                        default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                          if (_push4) {
                            _push4(`${ssrInterpolate(unref(t)("Cancel"))}`);
                          } else {
                            return [
                              createTextVNode(toDisplayString(unref(t)("Cancel")), 1)
                            ];
                          }
                        }),
                        _: 1
                      }, _parent3, _scopeId2));
                      _push3(ssrRenderComponent(_sfc_main$6, {
                        onClick: ($event) => deleteSelected()
                      }, {
                        default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                          if (_push4) {
                            _push4(`${ssrInterpolate(unref(t)("Yes, delete"))}`);
                          } else {
                            return [
                              createTextVNode(toDisplayString(unref(t)("Yes, delete")), 1)
                            ];
                          }
                        }),
                        _: 1
                      }, _parent3, _scopeId2));
                    } else {
                      return [
                        createVNode(_sfc_main$5, { onClick: closeModal }, {
                          default: withCtx(() => [
                            createTextVNode(toDisplayString(unref(t)("Cancel")), 1)
                          ]),
                          _: 1
                        }),
                        createVNode(_sfc_main$6, {
                          onClick: ($event) => deleteSelected()
                        }, {
                          default: withCtx(() => [
                            createTextVNode(toDisplayString(unref(t)("Yes, delete")), 1)
                          ]),
                          _: 1
                        }, 8, ["onClick"])
                      ];
                    }
                  }),
                  _: 1
                }, _parent2, _scopeId));
                _push2(`</div>`);
              } else {
                _push2(`<!---->`);
              }
              _push2(`<table class="min-w-full table-fixed divide-y divide-gray-300 dark:divide-gray-700"${_scopeId}><thead class="bg-gray-50 dark:bg-black/50"${_scopeId}><tr${_scopeId}><th scope="col" class="relative w-12 px-6 sm:w-16 sm:px-8"${_scopeId}><input type="checkbox"${ssrRenderAttr("indeterminate", indeterminate.value)}${ssrIncludeBooleanAttr(indeterminate.value || unref(form).selection.length === props.customers.data.length) ? " checked" : ""} class="absolute left-4 top-1/2 -mt-2 h-4 w-4 rounded border-gray-300 text-blue-600 focus:ring-blue-500 sm:left-6 dark:bg-gray-700 dark:border-gray-700"${_scopeId}></th><th scope="col" class="px-3 py-3.5 text-left text-sm font-semibold text-gray-900 dark:text-gray-100"${_scopeId}>${ssrInterpolate(unref(t)("Customer"))}</th><th scope="col" class="py-3.5 px-3 text-left text-sm font-semibold text-gray-900 dark:text-gray-100"${_scopeId}>${ssrInterpolate(unref(t)("Contact"))}</th><th scope="col" class="py-3.5 px-3 text-left text-sm font-semibold text-gray-900 dark:text-gray-100"${_scopeId}>${ssrInterpolate(unref(t)("Balance"))}</th><th scope="col" class="py-3.5 px-3 text-left text-sm font-semibold text-gray-900 dark:text-gray-100"${_scopeId}>${ssrInterpolate(unref(t)("Address"))}</th><th scope="col" class="py-3.5 px-3 text-left text-sm font-semibold text-gray-900 dark:text-gray-100"${_scopeId}>${ssrInterpolate(unref(t)("Custom Fields"))}</th><th scope="col" class="relative py-3.5 pl-3 pr-4 sm:pr-6"${_scopeId}><span class="sr-only"${_scopeId}>${ssrInterpolate(unref(t)("Actions"))}</span></th></tr></thead><tbody class="divide-y divide-gray-200 dark:divide-gray-700 bg-white dark:bg-gray-900"${_scopeId}><!--[-->`);
              ssrRenderList(props.customers.data, (customer, ci) => {
                _push2(`<tr class="${ssrRenderClass([
                  unref(form).selection.includes(customer.id) && "bg-gray-50 dark:bg-gray-800/50",
                  customer.deleted_at && "bg-red-100 dark:bg-red-900"
                ])}"${_scopeId}><td class="relative w-12 px-6 sm:w-16 sm:px-8"${_scopeId}>`);
                if (unref(form).selection.includes(customer.id)) {
                  _push2(`<div class="absolute inset-y-0 left-0 w-0.5 bg-blue-600"${_scopeId}></div>`);
                } else {
                  _push2(`<!---->`);
                }
                _push2(`<input type="checkbox"${ssrRenderAttr("value", customer.id)}${ssrIncludeBooleanAttr(Array.isArray(unref(form).selection) ? ssrLooseContain(unref(form).selection, customer.id) : unref(form).selection) ? " checked" : ""} class="absolute left-4 top-1/2 -mt-2 h-4 w-4 rounded border-gray-300 text-blue-600 focus:ring-blue-500 sm:left-6 dark:bg-gray-700 dark:border-gray-700"${_scopeId}></td><td class="whitespace-nowrap px-3 py-4 text-sm font-medium"${_scopeId}><div${_scopeId}>${ssrInterpolate(customer.name)}</div>`);
                if (customer.company) {
                  _push2(`<div${_scopeId}>${ssrInterpolate(customer.company)}</div>`);
                } else {
                  _push2(`<!---->`);
                }
                _push2(`</td><td class="whitespace-nowrap px-3 py-4 text-sm font-medium"${_scopeId}>`);
                if (customer.phone) {
                  _push2(`<div${_scopeId}>${ssrInterpolate(customer.phone)}</div>`);
                } else {
                  _push2(`<!---->`);
                }
                if (customer.email) {
                  _push2(`<div${_scopeId}>${ssrInterpolate(customer.email)}</div>`);
                } else {
                  _push2(`<!---->`);
                }
                _push2(`</td><td class="whitespace-nowrap px-3 py-4 text-sm font-bold text-right"${_scopeId}>`);
                _push2(ssrRenderComponent(_component_Link, {
                  href: unref(route)("customer.transactions", { customer: customer.id }),
                  class: "balance-" + ci
                }, {
                  default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                    if (_push3) {
                      _push3(`${ssrInterpolate(_ctx.$currency(customer.balance))}`);
                    } else {
                      return [
                        createTextVNode(toDisplayString(_ctx.$currency(customer.balance)), 1)
                      ];
                    }
                  }),
                  _: 2
                }, _parent2, _scopeId));
                _push2(`</td><td class="px-3 py-4 text-sm min-w-[200px] max-w-xs"${_scopeId}>${ssrInterpolate(customer.address || "")} ${ssrInterpolate(customer.city || "")} ${ssrInterpolate(customer.postal_code || "")} ${ssrInterpolate(customer.state || "")} ${ssrInterpolate(customer.country || "")}</td><td class="px-3 py-4 text-sm"${_scopeId}><div class="flex items-center flex-wrap gap-x-4 gap-y-2 min-w-[200px] max-w-xs"${_scopeId}>${_ctx.$extra_attributes(customer.extra_attributes)}</div></td><td class="whitespace-nowrap py-4 pl-3 pr-4 text-right text-sm font-medium sm:pr-6 w-20"${_scopeId}><div class="flex flex-col items-center justify-end gap-3"${_scopeId}><div class="flex items-center justify-end gap-3"${_scopeId}><button type="button" class="text-gray-500 hover:text-gray-800 dark:text-gray-400 dark:hover:text-gray-200"${_scopeId}><svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-6 h-6"${_scopeId}><path stroke-linecap="round" stroke-linejoin="round" d="M19 7.5v3m0 0v3m0-3h3m-3 0h-3m-2.25-4.125a3.375 3.375 0 11-6.75 0 3.375 3.375 0 016.75 0zM4 19.235v-.11a6.375 6.375 0 0112.75 0v.109A12.318 12.318 0 0110.374 21c-2.331 0-4.512-.645-6.374-1.766z"${_scopeId}></path></svg></button><button type="button" class="text-gray-500 hover:text-gray-800 dark:text-gray-400 dark:hover:text-gray-200"${_scopeId}><svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-6 h-6"${_scopeId}><path stroke-linecap="round" stroke-linejoin="round" d="M15 19.128a9.38 9.38 0 002.625.372 9.337 9.337 0 004.121-.952 4.125 4.125 0 00-7.533-2.493M15 19.128v-.003c0-1.113-.285-2.16-.786-3.07M15 19.128v.106A12.318 12.318 0 018.624 21c-2.331 0-4.512-.645-6.374-1.766l-.001-.109a6.375 6.375 0 0111.964-3.07M12 6.375a3.375 3.375 0 11-6.75 0 3.375 3.375 0 016.75 0zm8.25 2.25a2.625 2.625 0 11-5.25 0 2.625 2.625 0 015.25 0z"${_scopeId}></path></svg></button></div>`);
                _push2(ssrRenderComponent(_sfc_main$7, {
                  pm: "customers",
                  property: "name",
                  row: customer,
                  deleteFn: deleteRow,
                  restoreFn: restoreRow,
                  editStr: unref(route)("customers.edit", customer.id)
                }, null, _parent2, _scopeId));
                _push2(`</div></td></tr>`);
              });
              _push2(`<!--]--></tbody></table></div></div></div>`);
              _push2(ssrRenderComponent(_sfc_main$8, {
                class: "m-4",
                meta: props.customers.meta,
                links: props.customers.links
              }, null, _parent2, _scopeId));
              _push2(`</div></div>`);
            } else {
              _push2(`<div class="py-4 px-6"${_scopeId}>${ssrInterpolate(unref(t)("There is no data to display."))}</div>`);
            }
            _push2(`</div></div></div></div></div>`);
            _push2(ssrRenderComponent(_sfc_main$9, {
              show: list_users.value,
              closeable: true,
              onClose: () => list_users.value = false,
              "max-width": selectedCustomer.value && selectedCustomer.value.users && selectedCustomer.value.users.length ? "2xl" : "xl"
            }, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  _push3(`<div class="p-4 flex items-start justify-between print:hidden"${_scopeId2}><div${_scopeId2}><div class="text-lg"${_scopeId2}>${ssrInterpolate(unref(t)("Users"))} (${ssrInterpolate(selectedCustomer.value.name)})</div><div${_scopeId2}>${ssrInterpolate(unref(t)("Please review the result below"))}</div></div><div class="-mr-2 flex items- gap-2"${_scopeId2}><button class="flex items-center justify-center h-8 w-8 rounded-full text-gray-600 hover:text-gray-800 hover:bg-gray-300 dark:text-gray-400 dark:hover:text-gray-200 dark:hover:bg-gray-700 focus:outline-none"${_scopeId2}>`);
                  _push3(ssrRenderComponent(_component_icons, {
                    name: "cross",
                    class: "h-5 w-5"
                  }, null, _parent3, _scopeId2));
                  _push3(`</button></div></div><div class=""${_scopeId2}>`);
                  if (selectedCustomer.value && selectedCustomer.value.users && selectedCustomer.value.users.length) {
                    _push3(`<ul role="list" class="divide-y divide-gray-200 dark:divide-gray-700"${_scopeId2}><!--[-->`);
                    ssrRenderList(selectedCustomer.value.users, (user) => {
                      var _a;
                      _push3(`<li${_scopeId2}><div class="w-full block text-left hover:bg-gray-50 dark:hover:bg-gray-900"${_scopeId2}><div class="flex items-center px-4 py-3 sm:px-6"${_scopeId2}><div class="flex min-w-0 flex-1 items-center"${_scopeId2}><div class="flex-shrink-0"${_scopeId2}><img class="h-8 w-8 rounded-full"${ssrRenderAttr("src", user.profile_photo_url)}${ssrRenderAttr("alt", user.name)}${_scopeId2}></div><div class="min-w-0 flex-1 px-4 md:grid md:grid-cols-2 md:gap-4"${_scopeId2}><div${_scopeId2}><p class="truncate text-sm font-bold text-gray-600 dark:text-gray-400"${_scopeId2}>${ssrInterpolate(user.name)}</p>`);
                      if (((_a = _ctx.$page.props.settings) == null ? void 0 : _a.impersonation) == 1 && _ctx.$page.props.can_impersonate) {
                        _push3(ssrRenderComponent(_component_Link, {
                          href: unref(route)("impersonate", user.id),
                          class: "text-sm text-blue-600 hover:text-blue-800 dark:text-blue-400 dark:hover:text-blue-200"
                        }, {
                          default: withCtx((_3, _push4, _parent4, _scopeId3) => {
                            if (_push4) {
                              _push4(`${ssrInterpolate(unref(t)("Impersonate"))}`);
                            } else {
                              return [
                                createTextVNode(toDisplayString(unref(t)("Impersonate")), 1)
                              ];
                            }
                          }),
                          _: 2
                        }, _parent3, _scopeId2));
                      } else {
                        _push3(`<!---->`);
                      }
                      _push3(`</div><p class="hidden md:flex items-center text-sm text-gray-600 dark:text-gray-400"${_scopeId2}><svg class="mr-1.5 h-4 w-4 flex-shrink-0 text-gray-500" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" fill="currentColor" aria-hidden="true"${_scopeId2}><path d="M3 4a2 2 0 00-2 2v1.161l8.441 4.221a1.25 1.25 0 001.118 0L19 7.162V6a2 2 0 00-2-2H3z"${_scopeId2}></path><path d="M19 8.839l-7.77 3.885a2.75 2.75 0 01-2.46 0L1 8.839V14a2 2 0 002 2h14a2 2 0 002-2V8.839z"${_scopeId2}></path></svg><span class="truncate"${_scopeId2}>${ssrInterpolate(user.email)}</span></p></div></div><button type="button"${_scopeId2}><svg class="h-5 w-5 text-gray-400" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" fill="currentColor" aria-hidden="true"${_scopeId2}><path fill-rule="evenodd" d="M7.21 14.77a.75.75 0 01.02-1.06L11.168 10 7.23 6.29a.75.75 0 111.04-1.08l4.5 4.25a.75.75 0 010 1.08l-4.5 4.25a.75.75 0 01-1.06-.02z" clip-rule="evenodd"${_scopeId2}></path></svg></button></div></div></li>`);
                    });
                    _push3(`<!--]--></ul>`);
                  } else {
                    _push3(`<div class="p-4 text-lg font-light"${_scopeId2}>${ssrInterpolate(unref(t)("Customer do not have any user yet."))}</div>`);
                  }
                  _push3(`</div>`);
                } else {
                  return [
                    createVNode("div", { class: "p-4 flex items-start justify-between print:hidden" }, [
                      createVNode("div", null, [
                        createVNode("div", { class: "text-lg" }, toDisplayString(unref(t)("Users")) + " (" + toDisplayString(selectedCustomer.value.name) + ")", 1),
                        createVNode("div", null, toDisplayString(unref(t)("Please review the result below")), 1)
                      ]),
                      createVNode("div", { class: "-mr-2 flex items- gap-2" }, [
                        createVNode("button", {
                          onClick: () => list_users.value = false,
                          class: "flex items-center justify-center h-8 w-8 rounded-full text-gray-600 hover:text-gray-800 hover:bg-gray-300 dark:text-gray-400 dark:hover:text-gray-200 dark:hover:bg-gray-700 focus:outline-none"
                        }, [
                          createVNode(_component_icons, {
                            name: "cross",
                            class: "h-5 w-5"
                          })
                        ], 8, ["onClick"])
                      ])
                    ]),
                    createVNode("div", { class: "" }, [
                      selectedCustomer.value && selectedCustomer.value.users && selectedCustomer.value.users.length ? (openBlock(), createBlock("ul", {
                        key: 0,
                        role: "list",
                        class: "divide-y divide-gray-200 dark:divide-gray-700"
                      }, [
                        (openBlock(true), createBlock(Fragment, null, renderList(selectedCustomer.value.users, (user) => {
                          var _a;
                          return openBlock(), createBlock("li", {
                            key: user.id
                          }, [
                            createVNode("div", { class: "w-full block text-left hover:bg-gray-50 dark:hover:bg-gray-900" }, [
                              createVNode("div", { class: "flex items-center px-4 py-3 sm:px-6" }, [
                                createVNode("div", { class: "flex min-w-0 flex-1 items-center" }, [
                                  createVNode("div", { class: "flex-shrink-0" }, [
                                    createVNode("img", {
                                      class: "h-8 w-8 rounded-full",
                                      src: user.profile_photo_url,
                                      alt: user.name
                                    }, null, 8, ["src", "alt"])
                                  ]),
                                  createVNode("div", { class: "min-w-0 flex-1 px-4 md:grid md:grid-cols-2 md:gap-4" }, [
                                    createVNode("div", null, [
                                      createVNode("p", { class: "truncate text-sm font-bold text-gray-600 dark:text-gray-400" }, toDisplayString(user.name), 1),
                                      ((_a = _ctx.$page.props.settings) == null ? void 0 : _a.impersonation) == 1 && _ctx.$page.props.can_impersonate ? (openBlock(), createBlock(_component_Link, {
                                        key: 0,
                                        href: unref(route)("impersonate", user.id),
                                        class: "text-sm text-blue-600 hover:text-blue-800 dark:text-blue-400 dark:hover:text-blue-200"
                                      }, {
                                        default: withCtx(() => [
                                          createTextVNode(toDisplayString(unref(t)("Impersonate")), 1)
                                        ]),
                                        _: 2
                                      }, 1032, ["href"])) : createCommentVNode("", true)
                                    ]),
                                    createVNode("p", { class: "hidden md:flex items-center text-sm text-gray-600 dark:text-gray-400" }, [
                                      (openBlock(), createBlock("svg", {
                                        class: "mr-1.5 h-4 w-4 flex-shrink-0 text-gray-500",
                                        xmlns: "http://www.w3.org/2000/svg",
                                        viewBox: "0 0 20 20",
                                        fill: "currentColor",
                                        "aria-hidden": "true"
                                      }, [
                                        createVNode("path", { d: "M3 4a2 2 0 00-2 2v1.161l8.441 4.221a1.25 1.25 0 001.118 0L19 7.162V6a2 2 0 00-2-2H3z" }),
                                        createVNode("path", { d: "M19 8.839l-7.77 3.885a2.75 2.75 0 01-2.46 0L1 8.839V14a2 2 0 002 2h14a2 2 0 002-2V8.839z" })
                                      ])),
                                      createVNode("span", { class: "truncate" }, toDisplayString(user.email), 1)
                                    ])
                                  ])
                                ]),
                                createVNode("button", {
                                  type: "button",
                                  onClick: ($event) => editUser(user)
                                }, [
                                  (openBlock(), createBlock("svg", {
                                    class: "h-5 w-5 text-gray-400",
                                    xmlns: "http://www.w3.org/2000/svg",
                                    viewBox: "0 0 20 20",
                                    fill: "currentColor",
                                    "aria-hidden": "true"
                                  }, [
                                    createVNode("path", {
                                      "fill-rule": "evenodd",
                                      d: "M7.21 14.77a.75.75 0 01.02-1.06L11.168 10 7.23 6.29a.75.75 0 111.04-1.08l4.5 4.25a.75.75 0 010 1.08l-4.5 4.25a.75.75 0 01-1.06-.02z",
                                      "clip-rule": "evenodd"
                                    })
                                  ]))
                                ], 8, ["onClick"])
                              ])
                            ])
                          ]);
                        }), 128))
                      ])) : (openBlock(), createBlock("div", {
                        key: 1,
                        class: "p-4 text-lg font-light"
                      }, toDisplayString(unref(t)("Customer do not have any user yet.")), 1))
                    ])
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
            _push2(ssrRenderComponent(_sfc_main$9, {
              show: userModal.value,
              closeable: true,
              onClose: closeUserModal
            }, {
              default: withCtx((_2, _push3, _parent3, _scopeId2) => {
                if (_push3) {
                  if (userModal.value) {
                    _push3(ssrRenderComponent(_sfc_main$a, {
                      onDone: updatedUser,
                      edit: selectedUser.value,
                      customer: selectedCustomer.value,
                      onClose: closeUserModal
                    }, null, _parent3, _scopeId2));
                  } else {
                    _push3(`<!---->`);
                  }
                } else {
                  return [
                    userModal.value ? (openBlock(), createBlock(_sfc_main$a, {
                      key: 0,
                      onDone: updatedUser,
                      edit: selectedUser.value,
                      customer: selectedCustomer.value,
                      onClose: closeUserModal
                    }, null, 8, ["edit", "customer"])) : createCommentVNode("", true)
                  ];
                }
              }),
              _: 1
            }, _parent2, _scopeId));
          } else {
            return [
              createVNode("div", { class: "py-8" }, [
                createVNode("div", { class: "max-w-7xl mx-auto sm:px-6 lg:px-8" }, [
                  createVNode("div", { class: "bg-white dark:bg-gray-900 shadow sm:rounded-lg" }, [
                    createVNode("div", { class: "sm:rounded-lg" }, [
                      createVNode("div", { class: "p-6 sm:rounded-t-lg border-b border-gray-200 dark:border-gray-700 block md:flex md:items-center md:justify-between" }, [
                        createVNode("div", null, [
                          createVNode("div", { class: "text-2xl" }, [
                            createTextVNode(toDisplayString(unref(t)("Customers")) + " ", 1),
                            createVNode("span", { class: "text-base" }, toDisplayString({ with: "(" + unref(t)("With Trashed") + ")", only: "(" + unref(t)("Only Trashed") + ")" }[unref(search).trashed]), 1)
                          ]),
                          createVNode("div", { class: "mt-1 text-gray-500 dark:text-gray-400" }, toDisplayString(unref(t)("Please review the result below")), 1)
                        ]),
                        createVNode("div", { class: "mt-4 sm:mt-0 block sm:flex sm:items-center sm:gap-4" }, [
                          _ctx.$can("create-customers") ? (openBlock(), createBlock(_sfc_main$2, {
                            key: 0,
                            href: unref(route)("customers.create")
                          }, {
                            default: withCtx(() => [
                              createTextVNode(toDisplayString(unref(t)("Add New Customer")), 1)
                            ]),
                            _: 1
                          }, 8, ["href"])) : createCommentVNode("", true),
                          createVNode("form", {
                            onSubmit: withModifiers(searchNow, ["prevent"])
                          }, [
                            createVNode(_sfc_main$3, {
                              onReset: ($event) => resetSearch(),
                              modelValue: unref(search).search,
                              "onUpdate:modelValue": ($event) => unref(search).search = $event
                            }, {
                              default: withCtx(() => [
                                createVNode("label", { class: "block" }, toDisplayString(unref(t)("Trashed")) + ":", 1),
                                createVNode(SelectInput, {
                                  modelValue: unref(search).trashed,
                                  "onUpdate:modelValue": ($event) => unref(search).trashed = $event,
                                  onChange: ($event) => searchNow(),
                                  class: "mt-1 w-full"
                                }, {
                                  default: withCtx(() => [
                                    createVNode("option", { value: null }, toDisplayString(unref(t)("Not Trashed")), 1),
                                    createVNode("option", { value: "with" }, toDisplayString(unref(t)("With Trashed")), 1),
                                    createVNode("option", { value: "only" }, toDisplayString(unref(t)("Only Trashed")), 1)
                                  ]),
                                  _: 1
                                }, 8, ["modelValue", "onUpdate:modelValue", "onChange"])
                              ]),
                              _: 1
                            }, 8, ["onReset", "modelValue", "onUpdate:modelValue"])
                          ], 40, ["onSubmit"])
                        ])
                      ]),
                      createVNode("div", { class: "bg-gray-50 dark:bg-black/50 border-b dark:border-gray-700 sm:rounded-b-lg" }, [
                        props.customers && props.customers.data && props.customers.data.length ? (openBlock(), createBlock("div", { key: 0 }, [
                          createVNode("div", { class: "flex flex-col" }, [
                            createVNode("div", { class: "-my-2 overflow-x-auto sm:-mx-6 lg:-mx-8" }, [
                              createVNode("div", { class: "inline-block min-w-full py-2 align-middle sm:px-6 lg:px-8" }, [
                                createVNode("div", { class: "relative overflow-hidden ring-1 ring-black ring-opacity-5" }, [
                                  unref(form).selection && unref(form).selection.length ? (openBlock(), createBlock("div", {
                                    key: 0,
                                    class: "absolute top-0 left-12 flex h-12 items-center space-x-3 sm:left-16"
                                  }, [
                                    createVNode("button", {
                                      type: "button",
                                      onClick: ($event) => confirmDelete(),
                                      class: "inline-flex items-center rounded border text-white border-red-500 bg-red-500 px-2.5 py-1.5 text-xs font-medium shadow-sm hover:bg-red-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 disabled:cursor-not-allowed disabled:opacity-30"
                                    }, toDisplayString(unref(t)("Move to Trash")), 9, ["onClick"]),
                                    createVNode("button", {
                                      type: "button",
                                      onClick: ($event) => confirmDelete(true),
                                      class: "inline-flex items-center rounded border text-white border-red-500 bg-red-500 px-2.5 py-1.5 text-xs font-medium shadow-sm hover:bg-red-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 disabled:cursor-not-allowed disabled:opacity-30"
                                    }, toDisplayString(unref(t)("Delete Permanently")), 9, ["onClick"]),
                                    createVNode(_sfc_main$4, {
                                      show: bulkDelete.value,
                                      onClose: closeModal,
                                      maxWidth: "sm"
                                    }, {
                                      title: withCtx(() => [
                                        createTextVNode(toDisplayString(unref(t)("Delete bulk records")), 1)
                                      ]),
                                      content: withCtx(() => [
                                        createVNode("p", null, toDisplayString(unref(t)("Please confirm that you would like to delete the records?")), 1),
                                        unref(form).force ? (openBlock(), createBlock("p", {
                                          key: 0,
                                          class: "mt-2 text-red-500"
                                        }, toDisplayString(unref(t)("This action will delete the data permanently.")), 1)) : createCommentVNode("", true)
                                      ]),
                                      footer: withCtx(() => [
                                        createVNode(_sfc_main$5, { onClick: closeModal }, {
                                          default: withCtx(() => [
                                            createTextVNode(toDisplayString(unref(t)("Cancel")), 1)
                                          ]),
                                          _: 1
                                        }),
                                        createVNode(_sfc_main$6, {
                                          onClick: ($event) => deleteSelected()
                                        }, {
                                          default: withCtx(() => [
                                            createTextVNode(toDisplayString(unref(t)("Yes, delete")), 1)
                                          ]),
                                          _: 1
                                        }, 8, ["onClick"])
                                      ]),
                                      _: 1
                                    }, 8, ["show"])
                                  ])) : createCommentVNode("", true),
                                  createVNode("table", { class: "min-w-full table-fixed divide-y divide-gray-300 dark:divide-gray-700" }, [
                                    createVNode("thead", { class: "bg-gray-50 dark:bg-black/50" }, [
                                      createVNode("tr", null, [
                                        createVNode("th", {
                                          scope: "col",
                                          class: "relative w-12 px-6 sm:w-16 sm:px-8"
                                        }, [
                                          createVNode("input", {
                                            type: "checkbox",
                                            indeterminate: indeterminate.value,
                                            checked: indeterminate.value || unref(form).selection.length === props.customers.data.length,
                                            onChange: ($event) => unref(form).selection = $event.target.checked ? props.customers.data.map((p) => p.id) : [],
                                            class: "absolute left-4 top-1/2 -mt-2 h-4 w-4 rounded border-gray-300 text-blue-600 focus:ring-blue-500 sm:left-6 dark:bg-gray-700 dark:border-gray-700"
                                          }, null, 40, ["indeterminate", "checked", "onChange"])
                                        ]),
                                        createVNode("th", {
                                          scope: "col",
                                          class: "px-3 py-3.5 text-left text-sm font-semibold text-gray-900 dark:text-gray-100"
                                        }, toDisplayString(unref(t)("Customer")), 1),
                                        createVNode("th", {
                                          scope: "col",
                                          class: "py-3.5 px-3 text-left text-sm font-semibold text-gray-900 dark:text-gray-100"
                                        }, toDisplayString(unref(t)("Contact")), 1),
                                        createVNode("th", {
                                          scope: "col",
                                          class: "py-3.5 px-3 text-left text-sm font-semibold text-gray-900 dark:text-gray-100"
                                        }, toDisplayString(unref(t)("Balance")), 1),
                                        createVNode("th", {
                                          scope: "col",
                                          class: "py-3.5 px-3 text-left text-sm font-semibold text-gray-900 dark:text-gray-100"
                                        }, toDisplayString(unref(t)("Address")), 1),
                                        createVNode("th", {
                                          scope: "col",
                                          class: "py-3.5 px-3 text-left text-sm font-semibold text-gray-900 dark:text-gray-100"
                                        }, toDisplayString(unref(t)("Custom Fields")), 1),
                                        createVNode("th", {
                                          scope: "col",
                                          class: "relative py-3.5 pl-3 pr-4 sm:pr-6"
                                        }, [
                                          createVNode("span", { class: "sr-only" }, toDisplayString(unref(t)("Actions")), 1)
                                        ])
                                      ])
                                    ]),
                                    createVNode("tbody", { class: "divide-y divide-gray-200 dark:divide-gray-700 bg-white dark:bg-gray-900" }, [
                                      (openBlock(true), createBlock(Fragment, null, renderList(props.customers.data, (customer, ci) => {
                                        return openBlock(), createBlock("tr", {
                                          key: customer.id,
                                          class: [
                                            unref(form).selection.includes(customer.id) && "bg-gray-50 dark:bg-gray-800/50",
                                            customer.deleted_at && "bg-red-100 dark:bg-red-900"
                                          ]
                                        }, [
                                          createVNode("td", { class: "relative w-12 px-6 sm:w-16 sm:px-8" }, [
                                            unref(form).selection.includes(customer.id) ? (openBlock(), createBlock("div", {
                                              key: 0,
                                              class: "absolute inset-y-0 left-0 w-0.5 bg-blue-600"
                                            })) : createCommentVNode("", true),
                                            withDirectives(createVNode("input", {
                                              type: "checkbox",
                                              value: customer.id,
                                              "onUpdate:modelValue": ($event) => unref(form).selection = $event,
                                              class: "absolute left-4 top-1/2 -mt-2 h-4 w-4 rounded border-gray-300 text-blue-600 focus:ring-blue-500 sm:left-6 dark:bg-gray-700 dark:border-gray-700"
                                            }, null, 8, ["value", "onUpdate:modelValue"]), [
                                              [vModelCheckbox, unref(form).selection]
                                            ])
                                          ]),
                                          createVNode("td", { class: "whitespace-nowrap px-3 py-4 text-sm font-medium" }, [
                                            createVNode("div", null, toDisplayString(customer.name), 1),
                                            customer.company ? (openBlock(), createBlock("div", { key: 0 }, toDisplayString(customer.company), 1)) : createCommentVNode("", true)
                                          ]),
                                          createVNode("td", { class: "whitespace-nowrap px-3 py-4 text-sm font-medium" }, [
                                            customer.phone ? (openBlock(), createBlock("div", { key: 0 }, toDisplayString(customer.phone), 1)) : createCommentVNode("", true),
                                            customer.email ? (openBlock(), createBlock("div", { key: 1 }, toDisplayString(customer.email), 1)) : createCommentVNode("", true)
                                          ]),
                                          createVNode("td", { class: "whitespace-nowrap px-3 py-4 text-sm font-bold text-right" }, [
                                            createVNode(_component_Link, {
                                              href: unref(route)("customer.transactions", { customer: customer.id }),
                                              class: "balance-" + ci
                                            }, {
                                              default: withCtx(() => [
                                                createTextVNode(toDisplayString(_ctx.$currency(customer.balance)), 1)
                                              ]),
                                              _: 2
                                            }, 1032, ["href", "class"])
                                          ]),
                                          createVNode("td", { class: "px-3 py-4 text-sm min-w-[200px] max-w-xs" }, toDisplayString(customer.address || "") + " " + toDisplayString(customer.city || "") + " " + toDisplayString(customer.postal_code || "") + " " + toDisplayString(customer.state || "") + " " + toDisplayString(customer.country || ""), 1),
                                          createVNode("td", { class: "px-3 py-4 text-sm" }, [
                                            createVNode("div", {
                                              class: "flex items-center flex-wrap gap-x-4 gap-y-2 min-w-[200px] max-w-xs",
                                              innerHTML: _ctx.$extra_attributes(customer.extra_attributes)
                                            }, null, 8, ["innerHTML"])
                                          ]),
                                          createVNode("td", { class: "whitespace-nowrap py-4 pl-3 pr-4 text-right text-sm font-medium sm:pr-6 w-20" }, [
                                            createVNode("div", { class: "flex flex-col items-center justify-end gap-3" }, [
                                              createVNode("div", { class: "flex items-center justify-end gap-3" }, [
                                                createVNode("button", {
                                                  type: "button",
                                                  onClick: ($event) => addUser(customer),
                                                  class: "text-gray-500 hover:text-gray-800 dark:text-gray-400 dark:hover:text-gray-200"
                                                }, [
                                                  (openBlock(), createBlock("svg", {
                                                    xmlns: "http://www.w3.org/2000/svg",
                                                    fill: "none",
                                                    viewBox: "0 0 24 24",
                                                    "stroke-width": "1.5",
                                                    stroke: "currentColor",
                                                    class: "w-6 h-6"
                                                  }, [
                                                    createVNode("path", {
                                                      "stroke-linecap": "round",
                                                      "stroke-linejoin": "round",
                                                      d: "M19 7.5v3m0 0v3m0-3h3m-3 0h-3m-2.25-4.125a3.375 3.375 0 11-6.75 0 3.375 3.375 0 016.75 0zM4 19.235v-.11a6.375 6.375 0 0112.75 0v.109A12.318 12.318 0 0110.374 21c-2.331 0-4.512-.645-6.374-1.766z"
                                                    })
                                                  ]))
                                                ], 8, ["onClick"]),
                                                createVNode("button", {
                                                  type: "button",
                                                  onClick: ($event) => viewUsers(customer),
                                                  class: "text-gray-500 hover:text-gray-800 dark:text-gray-400 dark:hover:text-gray-200"
                                                }, [
                                                  (openBlock(), createBlock("svg", {
                                                    xmlns: "http://www.w3.org/2000/svg",
                                                    fill: "none",
                                                    viewBox: "0 0 24 24",
                                                    "stroke-width": "1.5",
                                                    stroke: "currentColor",
                                                    class: "w-6 h-6"
                                                  }, [
                                                    createVNode("path", {
                                                      "stroke-linecap": "round",
                                                      "stroke-linejoin": "round",
                                                      d: "M15 19.128a9.38 9.38 0 002.625.372 9.337 9.337 0 004.121-.952 4.125 4.125 0 00-7.533-2.493M15 19.128v-.003c0-1.113-.285-2.16-.786-3.07M15 19.128v.106A12.318 12.318 0 018.624 21c-2.331 0-4.512-.645-6.374-1.766l-.001-.109a6.375 6.375 0 0111.964-3.07M12 6.375a3.375 3.375 0 11-6.75 0 3.375 3.375 0 016.75 0zm8.25 2.25a2.625 2.625 0 11-5.25 0 2.625 2.625 0 015.25 0z"
                                                    })
                                                  ]))
                                                ], 8, ["onClick"])
                                              ]),
                                              createVNode(_sfc_main$7, {
                                                pm: "customers",
                                                property: "name",
                                                row: customer,
                                                deleteFn: deleteRow,
                                                restoreFn: restoreRow,
                                                editStr: unref(route)("customers.edit", customer.id)
                                              }, null, 8, ["row", "editStr"])
                                            ])
                                          ])
                                        ], 2);
                                      }), 128))
                                    ])
                                  ])
                                ])
                              ])
                            ]),
                            createVNode(_sfc_main$8, {
                              class: "m-4",
                              meta: props.customers.meta,
                              links: props.customers.links
                            }, null, 8, ["meta", "links"])
                          ])
                        ])) : (openBlock(), createBlock("div", {
                          key: 1,
                          class: "py-4 px-6"
                        }, toDisplayString(unref(t)("There is no data to display.")), 1))
                      ])
                    ])
                  ])
                ])
              ]),
              createVNode(_sfc_main$9, {
                show: list_users.value,
                closeable: true,
                onClose: () => list_users.value = false,
                "max-width": selectedCustomer.value && selectedCustomer.value.users && selectedCustomer.value.users.length ? "2xl" : "xl"
              }, {
                default: withCtx(() => [
                  createVNode("div", { class: "p-4 flex items-start justify-between print:hidden" }, [
                    createVNode("div", null, [
                      createVNode("div", { class: "text-lg" }, toDisplayString(unref(t)("Users")) + " (" + toDisplayString(selectedCustomer.value.name) + ")", 1),
                      createVNode("div", null, toDisplayString(unref(t)("Please review the result below")), 1)
                    ]),
                    createVNode("div", { class: "-mr-2 flex items- gap-2" }, [
                      createVNode("button", {
                        onClick: () => list_users.value = false,
                        class: "flex items-center justify-center h-8 w-8 rounded-full text-gray-600 hover:text-gray-800 hover:bg-gray-300 dark:text-gray-400 dark:hover:text-gray-200 dark:hover:bg-gray-700 focus:outline-none"
                      }, [
                        createVNode(_component_icons, {
                          name: "cross",
                          class: "h-5 w-5"
                        })
                      ], 8, ["onClick"])
                    ])
                  ]),
                  createVNode("div", { class: "" }, [
                    selectedCustomer.value && selectedCustomer.value.users && selectedCustomer.value.users.length ? (openBlock(), createBlock("ul", {
                      key: 0,
                      role: "list",
                      class: "divide-y divide-gray-200 dark:divide-gray-700"
                    }, [
                      (openBlock(true), createBlock(Fragment, null, renderList(selectedCustomer.value.users, (user) => {
                        var _a;
                        return openBlock(), createBlock("li", {
                          key: user.id
                        }, [
                          createVNode("div", { class: "w-full block text-left hover:bg-gray-50 dark:hover:bg-gray-900" }, [
                            createVNode("div", { class: "flex items-center px-4 py-3 sm:px-6" }, [
                              createVNode("div", { class: "flex min-w-0 flex-1 items-center" }, [
                                createVNode("div", { class: "flex-shrink-0" }, [
                                  createVNode("img", {
                                    class: "h-8 w-8 rounded-full",
                                    src: user.profile_photo_url,
                                    alt: user.name
                                  }, null, 8, ["src", "alt"])
                                ]),
                                createVNode("div", { class: "min-w-0 flex-1 px-4 md:grid md:grid-cols-2 md:gap-4" }, [
                                  createVNode("div", null, [
                                    createVNode("p", { class: "truncate text-sm font-bold text-gray-600 dark:text-gray-400" }, toDisplayString(user.name), 1),
                                    ((_a = _ctx.$page.props.settings) == null ? void 0 : _a.impersonation) == 1 && _ctx.$page.props.can_impersonate ? (openBlock(), createBlock(_component_Link, {
                                      key: 0,
                                      href: unref(route)("impersonate", user.id),
                                      class: "text-sm text-blue-600 hover:text-blue-800 dark:text-blue-400 dark:hover:text-blue-200"
                                    }, {
                                      default: withCtx(() => [
                                        createTextVNode(toDisplayString(unref(t)("Impersonate")), 1)
                                      ]),
                                      _: 2
                                    }, 1032, ["href"])) : createCommentVNode("", true)
                                  ]),
                                  createVNode("p", { class: "hidden md:flex items-center text-sm text-gray-600 dark:text-gray-400" }, [
                                    (openBlock(), createBlock("svg", {
                                      class: "mr-1.5 h-4 w-4 flex-shrink-0 text-gray-500",
                                      xmlns: "http://www.w3.org/2000/svg",
                                      viewBox: "0 0 20 20",
                                      fill: "currentColor",
                                      "aria-hidden": "true"
                                    }, [
                                      createVNode("path", { d: "M3 4a2 2 0 00-2 2v1.161l8.441 4.221a1.25 1.25 0 001.118 0L19 7.162V6a2 2 0 00-2-2H3z" }),
                                      createVNode("path", { d: "M19 8.839l-7.77 3.885a2.75 2.75 0 01-2.46 0L1 8.839V14a2 2 0 002 2h14a2 2 0 002-2V8.839z" })
                                    ])),
                                    createVNode("span", { class: "truncate" }, toDisplayString(user.email), 1)
                                  ])
                                ])
                              ]),
                              createVNode("button", {
                                type: "button",
                                onClick: ($event) => editUser(user)
                              }, [
                                (openBlock(), createBlock("svg", {
                                  class: "h-5 w-5 text-gray-400",
                                  xmlns: "http://www.w3.org/2000/svg",
                                  viewBox: "0 0 20 20",
                                  fill: "currentColor",
                                  "aria-hidden": "true"
                                }, [
                                  createVNode("path", {
                                    "fill-rule": "evenodd",
                                    d: "M7.21 14.77a.75.75 0 01.02-1.06L11.168 10 7.23 6.29a.75.75 0 111.04-1.08l4.5 4.25a.75.75 0 010 1.08l-4.5 4.25a.75.75 0 01-1.06-.02z",
                                    "clip-rule": "evenodd"
                                  })
                                ]))
                              ], 8, ["onClick"])
                            ])
                          ])
                        ]);
                      }), 128))
                    ])) : (openBlock(), createBlock("div", {
                      key: 1,
                      class: "p-4 text-lg font-light"
                    }, toDisplayString(unref(t)("Customer do not have any user yet.")), 1))
                  ])
                ]),
                _: 1
              }, 8, ["show", "onClose", "max-width"]),
              createVNode(_sfc_main$9, {
                show: userModal.value,
                closeable: true,
                onClose: closeUserModal
              }, {
                default: withCtx(() => [
                  userModal.value ? (openBlock(), createBlock(_sfc_main$a, {
                    key: 0,
                    onDone: updatedUser,
                    edit: selectedUser.value,
                    customer: selectedCustomer.value,
                    onClose: closeUserModal
                  }, null, 8, ["edit", "customer"])) : createCommentVNode("", true)
                ]),
                _: 1
              }, 8, ["show"])
            ];
          }
        }),
        _: 1
      }, _parent));
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Pages/Customer/List.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};
export {
  _sfc_main as default
};
