import { resolveComponent, mergeProps, unref, withCtx, createTextVNode, toDisplayString, useSSRContext } from "vue";
import { ssrRenderAttrs, ssrInterpolate, ssrRenderComponent } from "vue/server-renderer";
import { useI18n } from "vue-i18n";
import { useForm } from "@inertiajs/vue3";
import { _ as _sfc_main$4 } from "./InputError-951c1c36.js";
import { _ as _sfc_main$3 } from "./ActionMessage-cdce5426.js";
import { _ as _sfc_main$1 } from "./TextInput-f18b2e86.js";
import "./AppLayout-9028b106.js";
import { _ as _sfc_main$2 } from "./CustomFields-6004e621.js";
import "./FormSection-d5f140fc.js";
import "../ssr.js";
import "@vue/server-renderer";
import "@inertiajs/vue3/server";
import "uuid";
import "./Input-fb927b71.js";
import "./Modal-4ced3d7d.js";
import "lodash/debounce.js";
import "./AutoComplete-974a17ce.js";
import "axios";
import "lodash/throttle.js";
import "./TextareaInput-651f7dc6.js";
const _sfc_main = {
  __name: "UserForm",
  __ssrInlineRender: true,
  props: ["edit", "roles", "fields", "customer"],
  emits: ["close", "done"],
  setup(__props, { emit }) {
    var _a;
    const props = __props;
    const form = useForm({
      name: null,
      email: null,
      password: null,
      roles: ["customer"],
      extra_attributes: {},
      password_confirmation: null,
      customer_id: (_a = props.customer) == null ? void 0 : _a.id
    });
    if (props.edit) {
      if (props.edit.extra_attributes && props.fields) {
        Object.keys(props.edit.extra_attributes).filter((k) => {
          var _a2;
          return !((_a2 = props.fields) == null ? void 0 : _a2.find((f) => f.name == k));
        }).map((k) => delete props.edit.extra_attributes[k]);
      }
      form.name = props.edit.name;
      form.email = props.edit.email;
      form.password = props.edit.password;
      form.roles = props.edit.roles.map((r) => r.name);
      form.password_confirmation = props.edit.password_confirmation;
      form.extra_attributes = props.edit.extra_attributes || {};
    }
    const { t } = useI18n({});
    function submit() {
      let method = props.edit ? "put" : "post";
      let url = props.edit ? route("customer.users.update", { customer: props.customer.id, user: props.edit.id }) : route("customer.users.store", props.customer.id);
      form.transform((data) => ({ ...data, extra_attributes: { ...data.extra_attributes } }))[method](url, {
        preserveScroll: true,
        onSuccess: () => {
          props.edit ? "" : form.reset();
          emit("done");
        },
        onError: () => {
          if (form.errors.phone) {
            document.getElementById("phone").focus();
          }
          if (form.errors.email) {
            document.getElementById("email").focus();
          }
          if (form.errors.name) {
            document.getElementById("name").focus();
          }
        }
      });
    }
    return (_ctx, _push, _parent, _attrs) => {
      const _component_icons = resolveComponent("icons");
      if (__props.customer) {
        _push(`<div${ssrRenderAttrs(mergeProps({ class: "px-6 pt-3 pb-6 print:px-0 bg-white dark:bg-gray-900" }, _attrs))}><div class="flex items-start justify-between print:hidden"><div><div class="text-lg">${ssrInterpolate(props.edit ? unref(t)("Edit User") : unref(t)("Add New User"))} (${ssrInterpolate(__props.customer.name)})</div><div>${ssrInterpolate(unref(t)("Please fill the form below to {x}.", {
          x: props.edit ? unref(t)("update {x}", { x: unref(t)("user") }) : unref(t)("add {x}", { x: unref(t)("user") })
        }))}</div></div><div class="-mr-2 flex items- gap-2"><button class="flex items-center justify-center h-8 w-8 rounded-full text-gray-600 hover:text-gray-800 hover:bg-gray-300 dark:text-gray-400 dark:hover:text-gray-200 dark:hover:bg-gray-700 focus:outline-none">`);
        _push(ssrRenderComponent(_component_icons, {
          name: "cross",
          class: "h-5 w-5"
        }, null, _parent));
        _push(`</button></div></div><div class="mt-4"><div class="grid grid-cols-6 gap-6"><div class="col-span-6 sm:col-span-3">`);
        _push(ssrRenderComponent(_sfc_main$1, {
          modelValue: unref(form).name,
          "onUpdate:modelValue": ($event) => unref(form).name = $event,
          id: "name",
          error: unref(form).errors.name,
          label: unref(t)("Name")
        }, null, _parent));
        _push(`</div><div class="col-span-6 sm:col-span-3">`);
        _push(ssrRenderComponent(_sfc_main$1, {
          modelValue: unref(form).email,
          "onUpdate:modelValue": ($event) => unref(form).email = $event,
          id: "email",
          type: "email",
          error: unref(form).errors.email,
          label: unref(t)("Email")
        }, null, _parent));
        _push(`</div><div class="col-span-6 sm:col-span-3">`);
        _push(ssrRenderComponent(_sfc_main$1, {
          modelValue: unref(form).password,
          "onUpdate:modelValue": ($event) => unref(form).password = $event,
          id: "password",
          type: "password",
          error: unref(form).errors.password,
          label: unref(t)("Password")
        }, null, _parent));
        _push(`</div><div class="col-span-6 sm:col-span-3">`);
        _push(ssrRenderComponent(_sfc_main$1, {
          type: "password",
          id: "password_confirmation",
          label: unref(t)("Confirm Password"),
          modelValue: unref(form).password_confirmation,
          "onUpdate:modelValue": ($event) => unref(form).password_confirmation = $event,
          error: unref(form).errors.password_confirmation
        }, null, _parent));
        _push(`</div>`);
        if (__props.fields && __props.fields.length) {
          _push(ssrRenderComponent(_sfc_main$2, {
            fields: __props.fields,
            errors: unref(form).errors,
            modelValue: unref(form).extra_attributes,
            "onUpdate:modelValue": ($event) => unref(form).extra_attributes = $event,
            className: "col-span-6 sm:col-span-3"
          }, null, _parent));
        } else {
          _push(`<!---->`);
        }
        _push(`<div class="col-span-full mt-2">`);
        _push(ssrRenderComponent(_sfc_main$3, {
          on: unref(form).recentlySuccessful,
          class: "mr-3"
        }, {
          default: withCtx((_, _push2, _parent2, _scopeId) => {
            if (_push2) {
              _push2(`${ssrInterpolate(unref(t)("Saved."))}`);
            } else {
              return [
                createTextVNode(toDisplayString(unref(t)("Saved.")), 1)
              ];
            }
          }),
          _: 1
        }, _parent));
        _push(ssrRenderComponent(_sfc_main$4, {
          type: "button",
          onClick: submit,
          loading: unref(form).processing
        }, {
          default: withCtx((_, _push2, _parent2, _scopeId) => {
            if (_push2) {
              _push2(`${ssrInterpolate(unref(t)("Save"))}`);
            } else {
              return [
                createTextVNode(toDisplayString(unref(t)("Save")), 1)
              ];
            }
          }),
          _: 1
        }, _parent));
        _push(`</div></div></div></div>`);
      } else {
        _push(`<!---->`);
      }
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("resources/js/Pages/Customer/UserForm.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : void 0;
};
export {
  _sfc_main as default
};
